@@ -2,7 +2,7 @@ package GCBackend::GCBackendXmlCommon;
 
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -29,6 +29,9 @@ use filetest 'access';
 {
     package GCBackend::GCBeXmlBase;
     
+    use File::Temp qw/ tempfile /;
+    use File::Copy;
+
     my %xmlConv = (
                    '&' => '&amp;',
                    '"' => '&quot;',
@@ -130,13 +133,16 @@ use filetest 'access';
     sub save
     {
         my ($self, $data, $info, $splash) = @_;
-        if (!open DATA, '>'.$self->{file})
+
+        # Save into a new file to prevent crashes during saving
+        (my ($tmpFd, $tmpFile)) = tempfile();
+        if (!$tmpFd)
         {
             my @error = ('SaveError', '');
             return {error => \@error};
         }
-        
-        binmode(DATA, ':utf8');
+
+        binmode($tmpFd, ':utf8');
 
         my $xmlModel = '';
         my $xmlPreferences = '';
@@ -207,7 +213,7 @@ use filetest 'access';
         my $number = 0;
         $number = scalar @$data;
 
-        print DATA '<?xml version="1.0" encoding="UTF-8"?>
+        print $tmpFd '<?xml version="1.0" encoding="UTF-8"?>
 <collection type="',$collectionType,'" items="',$number,'"', $versionString,'>
 ',$information,'
 ',$xmlModel,'
@@ -224,7 +230,7 @@ use filetest 'access';
                     = $self->{modelLoader}->transformPicturePath($_->{$pic}, undef, $_, $pic);
             }
 
-            print DATA ' <item
+            print $tmpFd ' <item
 ';
             my @complexFields;
             my @longFields;
@@ -247,11 +253,11 @@ use filetest 'access';
                     #$data =~ s/"/&quot;/g;
                     (my $data = $_->{$field}) =~ s/([$toBeReplaced])/$xmlConv{$1}/go;
                     #"
-                    print DATA '  ', $field, '="', $data, '"
+                    print $tmpFd '  ', $field, '="', $data, '"
 ';
                 }
             }
-            print DATA ' >
+            print $tmpFd ' >
 ';
             foreach my $field(@longFields)
             {
@@ -261,17 +267,17 @@ use filetest 'access';
                 #$data =~ s/"/&quot;/g;
                 (my $data = $_->{$field}) =~ s/([$toBeReplaced])/$xmlConv{$1}/go;
                 #"
-                print DATA '  <', $field, '>', $data, '</', $field, '>
+                print $tmpFd '  <', $field, '>', $data, '</', $field, '>
 ';
             }
             foreach my $field(@complexFields)
             {
-                print DATA '  <', $field, '>
+                print $tmpFd '  <', $field, '>
 ', listToXml($_->{$field}), '  </', $field, '>
 ';
             }
 
-            print DATA ' </item>
+            print $tmpFd ' </item>
 ';
             $splash->setProgressForItemsDisplay($i) if $splash;
 
@@ -280,9 +286,16 @@ use filetest 'access';
 
             $i++;
         }
-        print DATA '</collection>
+        print $tmpFd '</collection>
 ';
-        close DATA;
+        close $tmpFd;
+
+        # Now everything is OK, we move the temporary file over the correct one
+        if (!move($tmpFile, $self->{file}))
+        {
+            my @error = ('SaveError', $!);
+            return {error => \@error};
+        }
 
         return {error => undef};
     }
