@@ -2,7 +2,7 @@ package GCBackend::GCBackendXmlParser;
 
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -25,12 +25,14 @@ package GCBackend::GCBackendXmlParser;
 use strict;
 use utf8;
 use filetest 'access';
-
 use GCBackend::GCBackendXmlCommon;
 
 {
     package GCBackend::GCBeXmlParser;
 
+    use File::Temp qw/ tempfile /;
+    use File::Copy;
+
     use base 'GCBackend::GCBeXmlBase';
     
     my $globalInstance;
@@ -74,15 +76,49 @@ use GCBackend::GCBackendXmlCommon;
         # re-entrant. Then when we begin parsing, we cannot parse the model
         $self->prepareModel($self->{file});
         my $error = undef;
-        eval {
-            $parser->parsefile($self->{file});
-        };
-        if ($@)
+        while (1)
         {
-            my $errorDesc = $@;
-            $errorDesc =~ s/^\n*//;
-            my @errorArray = ('OpenFormatError', $errorDesc);
-            $error = \@errorArray;
+            eval {
+                $parser->parsefile($self->{file});
+            };
+            if ($@)
+            {
+                my $errorDesc = $@;
+
+                # Here we will fix the collection if an invalid character was found by trying to remove it.
+                # There should be room for optimisation here
+
+                if ($errorDesc =~ /not\s*well-formed\s*\(invalid\s*token\)\s*.*?byte\s*(\d+)/)
+                {
+                    my $charPosition = $1;
+                    # We would have failed before if it cannot be opened, so we don't check that.
+                    open COL, $self->{file};
+                    seek COL, $charPosition, 0;
+                    my $badChar;
+                    read COL, $badChar, 1;
+                    seek COL, 0, 0;
+                    (my ($newCol, $tmpFile)) = tempfile();
+                    while (<COL>)
+                    {
+                        s/$badChar//g;
+                        print $newCol $_;
+                    }
+                    close $newCol;
+                    close COL;
+                    move($tmpFile, $self->{file});
+                }
+                else
+                {
+                    $errorDesc =~ s/^\n*//;
+                    my @errorArray = ('OpenFormatError', $errorDesc);
+                    $error = \@errorArray;
+                    last;
+                }
+            }
+            else
+            {
+                last;
+            }
         }
 
         # TODO : Compare performances with and without the compact below because the duplicates are checked
