@@ -2,7 +2,7 @@ package GCBorrowings;
 
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -458,7 +458,7 @@ use GCUtils;
         my ($self, $data, $model) = @_;
 
         $self->setModel($model);
-        my $items = $data->getItemsList;
+        my $items = $data->getItemsListFiltered;
         $self->{data} = $data;
  
         $self->{itemsList} = [];
