@@ -2,7 +2,7 @@ package GCData;
 
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -27,7 +27,9 @@ use strict;
 
 {
     package GCItems;
-    
+    #
+    # This is seen as $main->{items}
+    #    
     use XML::Parser;
     use Storable;
     use File::Copy;
@@ -61,9 +63,11 @@ use strict;
 
     sub initModel
     {
-        my ($self, $model) = @_;
+        #if $modelChanged is set, that means we updated the currently used model
+        # and not that we changed the model 
+        my ($self, $model, $modelUpdated) = @_;
         $self->{model} = $model;
-        $self->{parent}->notifyModelChange;
+        $self->{parent}->notifyModelChange($modelUpdated);
     }
 
     sub setPanel
@@ -79,16 +83,16 @@ use strict;
         $self->{currentItem} = -1;
     }
 
-    sub updateCurrentFromPanel
+    sub updateSelectedItemInfoFromGivenPanel
     {
         my ($self, $panel) = @_;
         my $previousPanel = $self->{panel};
         $self->{panel} = $panel;
-        $self->updateCurrent(1);
+        $self->updateSelectedItemInfoFromPanel(1);
         $self->{panel} = $previousPanel;
     }
 
-    sub updateCurrent
+    sub updateSelectedItemInfoFromPanel
     {
         my ($self, $withSelect, $forced) = @_;
         my $selectedChanged = 0;
@@ -101,7 +105,7 @@ use strict;
         }
         else
         {
-            $info = ($self->getItemsList)->[$self->{currentItem}];
+            $info = ($self->getItemsListFiltered)->[$self->{currentItem}];
         }
 
         my $idField = $self->{model}->{commonFields}->{id};
@@ -145,8 +149,8 @@ use strict;
                 # Propagate the changes to all the items
                 foreach (@{$self->{multipleCurrentItems}})
                 {
-                    my $previous = Storable::dclone(($self->getItemsList)->[$_]);
-                    my $item = ($self->getItemsList)->[$_];
+                    my $previous = Storable::dclone(($self->getItemsListFiltered)->[$_]);
+                    my $item = ($self->getItemsListFiltered)->[$_];
                     for my $field (keys %$info)
                     {
                         $item->{$field} = $info->{$field};
@@ -197,7 +201,7 @@ use strict;
 
         my $realIdx = $idx;
         $realIdx = $self->{currentItem} if ! defined $idx;
-        return ($self->getItemsList)->[$realIdx]->{$self->{model}->{commonFields}->{title}};
+        return ($self->getItemsListFiltered)->[$realIdx]->{$self->{model}->{commonFields}->{title}};
     }
 
     sub getCurrent
@@ -222,7 +226,7 @@ use strict;
             my %fields = map {$_ => 1} @{$self->{model}->{fieldsNotFormatted}};
             foreach (@{$self->{multipleCurrentItems}})
             {
-                my $item = ($self->getItemsList)->[$_];
+                my $item = ($self->getItemsListFiltered)->[$_];
                 for my $field (keys %fields)
                 {
                     if (exists $info->{$field})
@@ -250,7 +254,7 @@ use strict;
         {
             $idx = $self->{currentItem} if ! defined $idx;
             return if $self->{currentItem} < 0;
-            $info = ($self->getItemsList)->[$idx];
+            $info = ($self->getItemsListFiltered)->[$idx];
         }
         for my $field (@{$self->{model}->{fieldsNotFormatted}})
         {
@@ -292,7 +296,7 @@ use strict;
 
         if ((!$noUpdate) && ($self->{currentItem} > -1) && !($self->{hasBeenDeleted}))
         {
-            ($selectedHasChanged, $filtered) = $self->updateCurrent($withSelect);
+            ($selectedHasChanged, $filtered) = $self->updateSelectedItemInfoFromPanel($withSelect);
         }
         else
         {
@@ -310,7 +314,10 @@ use strict;
     sub valueToDisplayed
     {
         my ($self, $value, $field) = @_;
-        return $self->{model}->getDisplayedValue($self->{model}->{fieldsInfo}->{$field}->{values}, $value);
+        my $displayed = $self->{model}->getDisplayedValue($self->{model}->{fieldsInfo}->{$field}->{values}, $value);
+        return $displayed if $displayed;
+        # For personal models, it won't return a value. Then we keep the original one.
+        return $value;
     }
                 
     sub transformValue
@@ -331,14 +338,14 @@ use strict;
     {
         my ($self, $idx, $field) = @_;
         
-        return ($self->getItemsList)->[$idx]->{$field};
+        return ($self->getItemsListFiltered)->[$idx]->{$field};
     }
     
     sub setValue
     {
         my ($self, $idx, $field, $value) = @_;
 
-        ($self->getItemsList)->[$idx]->{$field} = $value;
+        ($self->getItemsListFiltered)->[$idx]->{$field} = $value;
         if ($idx == $self->{currentItem})
         {
             $self->{panel}->$field($value);
@@ -346,7 +353,7 @@ use strict;
         }
     }
 
-    sub getItemsList
+    sub getItemsListFiltered
     {
         my ($self, $filter) = @_;
         
@@ -738,6 +745,13 @@ use strict;
             return (0, $self->{loaded}->{error});
         }
 
+        # Perform Models Change if needed
+        if(!$self->{model}->{isInline} && ($backend->getVersion() ne $backend->{version}))
+        {
+            my $modelFormatUpdater=GCModelsChanges->new($self,$self->{model}->{collection}->{name});
+            $modelFormatUpdater->applyChanges($self->{itemArray}, $backend->getVersion(), $backend->{version});
+        }
+
         # Hide the panel if no item
         if (! scalar @{$self->{itemArray}})
         {
@@ -786,7 +800,7 @@ use strict;
             mkpath $self->{newImagesDirectory};
             my $file;
             my $dataFile = $self->{previousFile} ? $self->{previousFile}  : $self->{options}->file;
-            foreach (@{$self->getItemsList})
+            foreach (@{$self->getItemsListFiltered})
             {
                 foreach my $pic(@{$self->{model}->{fieldsImage}})
                 {
@@ -834,7 +848,7 @@ use strict;
             eval '$initTime = [Time::HiRes::gettimeofday()]';
         }
 
-        $self->updateCurrent if ($self->{currentItem} > -1);
+        $self->updateSelectedItemInfoFromPanel if ($self->{currentItem} > -1);
 
         # TODO : Use progress bar for this operation also
         my $moveError = $self->movePictures
