@@ -2,7 +2,7 @@ package GCDialogs;
 
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -46,7 +46,13 @@ $hasAboutDialog = 0 if $@;
     sub activateOkButton
     {
         my ($self, $value) = @_;
-        ($self->action_area->get_children)[0]->set_sensitive($value);
+        ($self->action_area->get_children)[$self->{okPosition}]->set_sensitive($value);
+    }
+
+    sub activateExtraButton
+    {
+        my ($self, $value) = @_;
+        ($self->action_area->get_children)[$self->{extraPosition}]->set_sensitive($value);
     }
 
     sub setOkLabel
@@ -73,10 +79,21 @@ $hasAboutDialog = 0 if $@;
         {
             @buttons = @GCDialogs::okCancelButtons;
         }
+        my ($okPosition, $extraPosition) = (0, -1);
         if (@extraButtons)
         {
-            push @buttons, @extraButtons if $extraAfter;
-            unshift @buttons, @extraButtons if !$extraAfter;
+            if ($extraAfter)
+            {
+                $okPosition = 1;
+                $extraPosition = 0;
+                push @buttons, @extraButtons;
+            }
+            else
+            {
+                $okPosition = 0;
+                $extraPosition = 2;
+                unshift @buttons, @extraButtons;
+            }
         }
         my $self  = $class->SUPER::new($title,
                               $parent,
@@ -84,7 +101,9 @@ $hasAboutDialog = 0 if $@;
                               @buttons
                               );
         bless ($self, $class);
-        
+
+        ($self->{okPosition}, $self->{extraPosition}) = ($okPosition, $extraPosition);
+
         $self->setOkLabel($okLabel) if $okLabel;
         $self->set_default_response('ok');
         
@@ -264,6 +283,18 @@ $hasAboutDialog = 0 if $@;
         $self->SUPER::show();
         $self->show_all;
         $self->set_position('center-always');
+        $self->{scrollArea}->signal_connect('size-allocate' => sub {
+            return if !$self->{scrollArea};
+            my ($width, $height) = $self->get_size;
+            return if ($width == $self->{width}) && ($height == $self->{height});
+            my $allocation = $self->{scrollArea}->allocation;
+            return if $allocation->height < 10;
+            $self->{image}->parent->set_size_request(-1, -1);
+            $self->set_position('center');
+            my $pixbuf = GCUtils::scaleMaxPixbuf($self->{originalPixbuf}, $allocation->width, $allocation->height);
+            $self->{image}->set_from_pixbuf($pixbuf);
+            ($self->{width}, $self->{height}) = ($width, $height);
+        }) if $self->{scrollArea};
         my $code = $self->run;
         $self->hide;
     }
@@ -283,8 +314,55 @@ $hasAboutDialog = 0 if $@;
 
         if (-f $file)
         {
-            my $image = Gtk2::Image->new_from_file($file);
-            $self->vbox->pack_start($image,0,0,0);
+            $self->{image} = Gtk2::Image->new;
+            $self->{originalPixbuf} = Gtk2::Gdk::Pixbuf->new_from_file($file);            
+            $self->{image}->set_from_pixbuf($self->{originalPixbuf});
+            $self->{image}->set_size_request(0,0);
+            $self->{scrollArea} = new Gtk2::ScrolledWindow;
+            $self->{scrollArea}->set_policy ('automatic', 'automatic');
+            $self->{scrollArea}->set_shadow_type('none');
+            $self->{scrollArea}->add_with_viewport($self->{image});
+            $self->vbox->pack_start($self->{scrollArea},1,1,0);
+            my ($screenWidth, $screenHeight) = ($self->get_screen->get_width, $self->get_screen->get_height);
+            my ($pixWidth, $pixHeight) = ($self->{originalPixbuf}->get_width, $self->{originalPixbuf}->get_height);
+            
+            # Minimum amount of spacing we want to leave for panels, window decorations, borders, etc
+            my $heightMargin = 150;
+            my $widthMargin = 30;
+            
+            my $ratio = $pixWidth / $pixHeight;
+            
+            # Check if picture will fit into screen, or if we'll need to resize
+            if (($pixHeight > ($screenHeight - $heightMargin)) && ($pixWidth <= ($screenWidth - $widthMargin)))
+            {
+                # Image is higher than vertical space we have available, but not wider
+                $pixHeight = $screenHeight - $heightMargin;
+                $pixWidth = $pixHeight * $ratio;
+            }
+            elsif (($pixHeight <= ($screenHeight - $heightMargin)) && ($pixWidth > ($screenWidth - $widthMargin)))
+            {
+                # Image is wider than horizontal space we have available, but not taller
+                $pixWidth = $screenWidth - $widthMargin;
+                $pixHeight = $pixWidth / $ratio;            
+            }
+            elsif (($pixHeight > ($screenHeight - $heightMargin)) && ($pixWidth > ($screenWidth - $widthMargin)))
+            {
+                # Image is both too high and too wide for space we have, so see which direction will be
+                # affected the most
+                if ($screenHeight - $heightMargin - $pixHeight < $screenWidth - $widthMargin - $pixWidth)
+                {
+                    # Constrained by vertical height
+                    $pixHeight = $screenHeight - $heightMargin;
+                    $pixWidth = $pixHeight * $ratio;               
+                }
+                else
+                {
+                    # Constrained by horizontal width
+                    $pixWidth = $screenWidth - $widthMargin;
+                    $pixHeight = $pixWidth / $ratio;                   
+                }
+            }
+            $self->{image}->parent->set_size_request($pixWidth, $pixHeight);
         }
         else
         {
