@@ -2,7 +2,7 @@ package GCDisplay;
 
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -153,8 +153,10 @@ use GCUtils;
     sub getComparisonFunction
     {
         my ($self, $type) = @_;
-        
         my ($comparison, $numeric) = @$type;
+        $numeric = 1 if $numeric eq 'true';
+        $numeric = 0 if $numeric eq 'false';
+
         if ($comparison eq 'eq')
         {
             return \&compareExact;
@@ -169,28 +171,28 @@ use GCUtils;
         }
         elsif ($comparison eq 'lt')
         {
-            return \&compareLessStrings if ($numeric ne 'true');
-            return \&compareLessNumbers if ($numeric eq 'true');
+            return \&compareLessStrings if (!$numeric);
+            return \&compareLessNumbers if ($numeric);
         }
         elsif ($comparison eq 'le')
         {
-            return \&compareLessOrEqualStrings if ($numeric ne 'true');
-            return \&compareLessOrEqualNumbers if ($numeric eq 'true');
+            return \&compareLessOrEqualStrings if (!$numeric);
+            return \&compareLessOrEqualNumbers if ($numeric);
         }
         elsif ($comparison eq 'gt')
         {
-            return \&compareGreaterStrings if ($numeric ne 'true');
-            return \&compareGreaterNumbers if ($numeric eq 'true');
+            return \&compareGreaterStrings if (!$numeric);
+            return \&compareGreaterNumbers if ($numeric);
         }
         elsif ($comparison eq 'ge')
         {
-            return \&compareGreaterOrEqualStrings if ($numeric ne 'true');
-            return \&compareGreaterOrEqualNumbers if ($numeric eq 'true');
+            return \&compareGreaterOrEqualStrings if (!$numeric);
+            return \&compareGreaterOrEqualNumbers if ($numeric);
         }
         elsif ($comparison eq 'range')
         {
-            return \&compareRangeStrings if ($numeric ne 'true');
-            return \&compareRangeNumbers if ($numeric eq 'true');
+            return \&compareRangeStrings if (!$numeric);
+            return \&compareRangeNumbers if ($numeric);
         }
         elsif ($comparison eq 'regexp')
         {
@@ -271,6 +273,7 @@ use GCUtils;
         my ($self, $info) = @_;
         return 1 if $self->{cleared};
         my $testAnd = $self->{mode} eq 'and';
+
         foreach my $field(keys %{$self->{info}})
         {
             my $value = '';
@@ -434,6 +437,8 @@ use Gtk2;
         $self->initValues;
         $self->SUPER::show();
         $self->show_all;
+        $self->activateOkButton($self->{notEmpty});
+        $self->activateExtraButton($self->{notEmpty});
         $self->{search} = undef;
         my $ended = 0;
         while (!$ended)
@@ -538,8 +543,17 @@ use Gtk2;
         my @filtersTotal = @{$model->{filters}};
 
         my $row = 0;
-        return if ($#filtersTotal + (2 * $#filtersGroup)) <= 0;
-        $self->{layoutTable}->resize($#filtersTotal + (2 * $#filtersGroup), 3);
+        my $nbLines = @filtersTotal + (2 * @filtersGroup);
+        if ($nbLines <= 0)
+        {
+            $self->{notEmpty} = 0;
+            $self->{layoutTable}->resize(1, 1);
+            my $label = new GCLabel($self->{parent}->{lang}->{SearchNoField});
+            $self->{layoutTable}->attach($label, 0, 1, 0, 1, 'expand', 'expand', $GCUtils::margin, $GCUtils::margin);
+            return;
+        }
+        $self->{notEmpty} = 1;
+        $self->{layoutTable}->resize($nbLines, 3);
 
         $self->{fields} = [];
         foreach my $group(@filtersGroup)
@@ -636,6 +650,7 @@ use Gtk2;
         $self->{layoutTable}->remove(pop @{$self->{fields}});
         $self->{layoutTable}->remove(pop @{$self->{comps}});
         $self->{layoutTable}->remove(pop @{$self->{values}});
+        delete $self->{isNumeric}->[$self->{nbFields}];
         $self->{layoutTable}->resize(--$self->{nbFields}, 3);
         $self->{remove}->set_sensitive(0) if $self->{nbFields} < 2;
     }
@@ -649,11 +664,21 @@ use Gtk2;
         {
             my $field = $_->getValue;
             next if !$field;
+            my $numeric = 'false';
+            if ($self->{model}->{fieldsInfo}->{$field}->{type} eq 'number')
+            {
+                $numeric = 'true';
+            }
+            # We check we still have the same field in case it was changed
+            elsif ($self->{isNumeric}->[$i]->[0] eq $field)
+            {
+                $numeric = $self->{isNumeric}->[$i]->[1];
+            }
             push @info, {
                 field => $field,
                 value => $self->{values}->[$i]->getValue,
                 filter => [$self->{comps}->[$i]->getValue,
-                           $self->{model}->{fieldsInfo}->{$field}->{type} eq 'number',
+                           $numeric,
                            undef]
             }
                 if ! $self->{values}->[$i]->isEmpty;
@@ -665,10 +690,18 @@ use Gtk2;
     sub initSearch
     {
         my ($self, $filter) = @_;
-        $self->{testAnd}->set_active(($filter->{mode} eq 'and') ? 1 : 0);
+        if ($filter->{mode} eq 'and')
+        {
+            $self->{testAnd}->set_active(1);
+        }
+        elsif ($filter->{mode} eq 'or')
+        {
+            $self->{testOr}->set_active(1);       
+        }
         $self->{useCase}->set_active($filter->{case});
         $self->{ignoreDiacritics}->set_active($filter->{ignoreDiacritics});
         $self->removeItem while $self->{nbFields} > 1;
+        $self->{isNumeric} = [];
         my $first = 1;
         foreach my $line(@{$filter->{info}})
         {
@@ -677,6 +710,8 @@ use Gtk2;
             $self->{fields}->[-1]->setValue($line->{field});
             $self->{comps}->[-1]->setValue($line->{filter}->[0]);
             $self->{values}->[-1]->setValue($line->{value});
+            # We also add the field name to be able to check it later
+            push @{$self->{isNumeric}}, [$line->{field}, $line->{filter}->[1]];
         }
     }
 
@@ -875,7 +910,7 @@ use Gtk2;
 
         $self->vbox->pack_start($allTable,1,1,0);
         
-        $self->set_size_request(-1, 450);
+        $self->set_size_request(-1, 400);
         return $self;
     }
     
