@@ -2,7 +2,7 @@ package GCExport;
 
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -63,7 +63,7 @@ use GCExportImport;
     {
         my ($self, $options) = @_;
         my $filter = ($self->{filter}->get_active) ? 1 : 0;
-        $options->{items} = $self->{parent}->{items}->getItemsList($filter);
+        $options->{items} = $self->{parent}->{items}->getItemsListFiltered($filter);
         $options->{collection} = $self->{parent}->{options}->file;
         $options->{defaultImage} = $self->{parent}->{defaultImage};
         $options->{sorter} = $self->{sorter}->getValue;
