@@ -2,7 +2,7 @@ package GCExportImport;
 
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -252,12 +252,18 @@ use GCDialogs;
             {
                 $widget = new GCCheckBox($label);
                 $self->{optionsTable}->attach($widget, 0, 2, $row, $row + 1, 'fill', 'fill', 0, 0);
+                if ($option->{changedCallback})
+                {
+                    $widget->signal_connect('toggled' => $option->{changedCallback}, [$self,$widget]);
+                    push @widgetSignals, [$widget, 'toggled'];
+                }
             }
             elsif ( ($type eq 'short text') || 
                       ($type eq 'long text') ||
                       ($type eq 'number') ||
                       ($type eq 'options') ||
-                      ($type eq 'file'))
+                      ($type eq 'file') ||
+                      ($type eq 'history text'))
             {
                 my $labelWidget = GCLabel->new($label);
                 $self->{optionsTable}->attach($labelWidget, 0, 1, $row, $row + 1, 'fill', 'fill', 0, 0);
@@ -275,6 +281,7 @@ use GCDialogs;
                 elsif ($type eq 'number')
                 {
                     $widget = new GCNumeric($value, $option->{min}, $option->{max}, $option->{step});
+                    
                 }
                 elsif ($type eq 'file')
                 {
@@ -284,16 +291,35 @@ use GCDialogs;
                 {
                     $widget = new GCMenuList;
                     my @valuesList;
-                    my @values = split m/,/, $option->{valuesList};
-                    foreach (@values)
+                    if (UNIVERSAL::isa( $option->{valuesList}, "HASH" ))
                     {
-                        my $item = {
-                                       value => $_,
-                                       displayed => $_
-                                   };
-                        $item->{displayed} = $module->getLang->{$_}
-                            if ($module->getLang->{$_});
-                        push @valuesList, $item;
+                        foreach $value(keys %{$option->{valuesList}})
+                        {
+                            my $item = {
+                                           value => $value,
+                                           displayed => $option->{valuesList}->{$value}
+                                       };
+                            $item->{displayed} = $module->getLang->{$item->{displayed}}
+                                if ($module->getLang->{$item->{displayed}});
+                            push @valuesList, $item;
+                        }
+                    }
+                    else
+                    {
+                        my @values;
+                        @values=split m/,/,$option->{valuesList} if(scalar($option->{valuesList}));
+                        @values=@{$option->{valuesList}} if (UNIVERSAL::isa( $option->{valuesList}, "ARRAY" ));
+                          print ref $option->{valuesList};
+                        foreach $value(@values)
+                        {
+                            my $item = {
+                                           value => $value,
+                                           displayed => $value
+                                       };
+                            $item->{displayed} = $module->getLang->{$item->{displayed}}
+                                if ($module->getLang->{$item->{displayed}});
+                            push @valuesList, $item;
+                        }
                     }
                     $widget->setValues(\@valuesList);
                     if ($option->{changedCallback})
@@ -302,6 +328,17 @@ use GCDialogs;
                         push @widgetSignals, [$widget, 'changed'];
                     }
                 }
+                elsif ($type eq 'history text')
+                {
+                    $widget = new GCHistoryText;
+                    my @initValues = @{$option->{initValues}} if $option->{initValues};
+                    $widget->setValues(\@initValues);
+                }
+                if ($option->{changedCallback})
+                {
+                    $widget->signal_connect('changed' => $option->{changedCallback}, [$self,$widget]);
+                    push @widgetSignals, [$widget, 'changed'];
+                }
                 if ($option->{buttonLabel})
                 {
                     my $button = Gtk2::Button->new($module->getLang->{$option->{buttonLabel}});
