@@ -2,7 +2,7 @@ package GCImport::GCImportBase;
 
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -123,7 +123,7 @@ use GCExportImport;
         my ($self, $options) = @_;
         $self->{options} = $options;
 
-        $options->{parent}->{items}->updateCurrent;
+        $options->{parent}->{items}->updateSelectedItemInfoFromPanel;
         my $alreadySaved = 0;
         if ($options->{newList})
         {
@@ -160,7 +160,7 @@ use GCExportImport;
         $options->{parent}->checkPanelVisibility;
         $options->{parent}->selectFirst;
         $options->{parent}->markAsUpdated;
-        $options->{parent}->allItems;
+        $options->{parent}->viewAllItems;
         return $self->getEndInfo;
     }
 
