@@ -15,7 +15,7 @@
 #	
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -319,6 +319,13 @@ mbnoimi@gmail.com',
 		'OptionsAskPlugins' => 'سؤال جميع المواقع',
 		'OptionsPluginsMulti' => 'عدد معيّن من المواقع',
 		'OptionsPluginsMultiAsk' => 'سؤال عدد معين من المواقع',
+        'OptionsPluginsMultiPerField' => 'Many sites (per field)',
+        'OptionsPluginsMultiPerFieldWindowTitle' => 'Many sites per field order selection',
+        'OptionsPluginsMultiPerFieldDesc' => 'For each field we will fill the field with the first non empty information beginning from left',
+        'OptionsPluginsMultiPerFieldFirst' => 'First',
+        'OptionsPluginsMultiPerFieldLast' => 'Last',
+        'OptionsPluginsMultiPerFieldRemove' => 'Remove',
+        'OptionsPluginsMultiPerFieldClearSelected' => 'Empty selected field list',
 		'OptionsPluginsList' => 'تخصيص قائمة المواقع',
         'OptionsAskImport' => 'حدد الحقول التي سيتم إستيرادها',
 		'OptionsProxy' => 'إستعمل البروكسي',
@@ -444,6 +451,10 @@ mbnoimi@gmail.com',
 
         'PanelSearchButton' => 'جلب المعلومات',
         'PanelSearchTip' => 'البحث بالإنترنت عن المعلومات التي تحمل هذا الإسم',
+        'PanelSearchContextChooseOne' => 'Choose a site ...',
+        'PanelSearchContextMultiSite' => 'Use "Many sites"',
+        'PanelSearchContextMultiSitePerField' => 'Use "Many sites per field"',
+        'PanelSearchContextOptions' => 'Change options ...',
         'PanelImageTipOpen' => 'إنقر على الصورة من أجل تحديد واحدة أخرى ',
         'PanelImageTipView' => ' إنقر على الصورة من أجل مشاهدة القياس الأصلي',
         'PanelImageTipMenu' => ' إنقر على الزر الأيمن للفأرة من أجل مزيد من الخيارات',
@@ -464,6 +475,7 @@ mbnoimi@gmail.com',
         'PanelUnknown' => 'غير معروف',
         'PanelAdded' => 'إضافة التاريخ',
         'PanelRating' => 'تقييم',
+        'PanelPressRating' => 'Press Rating',
         'PanelLocation' => 'المكان',
 
         'PanelLending' => 'إعارة',
@@ -535,6 +547,8 @@ mbnoimi@gmail.com',
 
         'SearchTooltip' => 'البحث بعن عنصر',
         'SearchTitle' => 'البحث عن عنصر',
+        'SearchNoField' => 'No field have been selected for the search box.
+Add some of them in the Filters tab of the collection settings.',
 
         'QueryReplaceField' => 'حقل سيتم إستبداله',
         'QueryReplaceOld' => 'القيمة الحالية',
