@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -306,6 +306,13 @@ http://le-spektre.org',
 		'OptionsAskPlugins' => 'Питане (Всички сайтове)',
 		'OptionsPluginsMulti' => 'Много сайтове',
 		'OptionsPluginsMultiAsk' => 'Питане (Много сайтове)',
+        'OptionsPluginsMultiPerField' => 'Много сайтове (per field)',
+        'OptionsPluginsMultiPerFieldWindowTitle' => 'Many sites per field order selection',
+        'OptionsPluginsMultiPerFieldDesc' => 'For each selected field we will return the first non empty information beginning from left',
+        'OptionsPluginsMultiPerFieldFirst' => 'First',
+        'OptionsPluginsMultiPerFieldLast' => 'Last',
+        'OptionsPluginsMultiPerFieldRemove' => 'Remove',
+        'OptionsPluginsMultiPerFieldClearSelected' => 'Empty selected field list',
 		'OptionsPluginsList' => 'Установяване на списък',
         'OptionsAskImport' => 'Избор на полета, които да бъдат импортирани',
 		'OptionsProxy' => 'Използване на proxy',
@@ -427,6 +434,10 @@ http://le-spektre.org',
 
         'PanelSearchButton' => 'Добиване на информация',
         'PanelSearchTip' => 'Търсене в уеб за информация относно това заглавие',
+        'PanelSearchContextChooseOne' => 'Choose a site ...',
+        'PanelSearchContextMultiSite' => 'Use "Many sites"',
+        'PanelSearchContextMultiSitePerField' => 'Use "Many sites per field"',
+        'PanelSearchContextOptions' => 'Change options ...',
         'PanelImageTipOpen' => 'Щракнете върху изображението за да изберете друго.',
         'PanelImageTipView' => 'Click on the picture to view it in real size.',
         'PanelImageTipMenu' => ' Десен бутон за повече възможности.',
@@ -447,6 +458,7 @@ http://le-spektre.org',
         'PanelUnknown' => 'Неизвестен',
         'PanelAdded' => 'Add date',
         'PanelRating' => 'Рейтинг',
+        'PanelPressRating' => 'Press Rating',
         'PanelLocation' => 'Местоположение',
 
         'PanelLending' => 'Заемане',
@@ -517,6 +529,8 @@ http://le-spektre.org',
 
         'SearchTooltip' => 'Търсене на всички филми',
         'SearchTitle' => 'Търсене на филм',
+        'SearchNoField' => 'No field have been selected for the search box.
+Add some of them in the Filters tab of the collection settings.',
 
         'QueryReplaceField' => 'Field to replace',
         'QueryReplaceOld' => 'Текущо име',
