@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -305,6 +305,13 @@ http://le-spektre.org',
         'OptionsAskPlugins' => 'Pregunta',
         'OptionsPluginsMulti' => 'Diversos llocs',
         'OptionsPluginsMultiAsk' => 'Pregunta (Diversos llocs)',
+        'OptionsPluginsMultiPerField' => 'Diversos llocs (per field)',
+        'OptionsPluginsMultiPerFieldWindowTitle' => 'Many sites per field order selection',
+        'OptionsPluginsMultiPerFieldDesc' => 'For each selected field we will return the first non empty information beginning from left',
+        'OptionsPluginsMultiPerFieldFirst' => 'First',
+        'OptionsPluginsMultiPerFieldLast' => 'Last',
+        'OptionsPluginsMultiPerFieldRemove' => 'Remove',
+        'OptionsPluginsMultiPerFieldClearSelected' => 'Empty selected field list',
         'OptionsPluginsList' => 'Defineix la llista',
         'OptionsAskImport' => 'Tria els camps que han d\'importar-se',	
         'OptionsProxy' => 'Empra un proxy',	
@@ -427,6 +434,10 @@ http://le-spektre.org',
 
         'PanelSearchButton' => 'Cerca informació',
         'PanelSearchTip' => 'Cerca informació al web sobre aquest nom',
+        'PanelSearchContextChooseOne' => 'Choose a site ...',
+        'PanelSearchContextMultiSite' => 'Use "Many sites"',
+        'PanelSearchContextMultiSitePerField' => 'Use "Many sites per field"',
+        'PanelSearchContextOptions' => 'Change options ...',
         'PanelImageTipOpen' => 'Feu clic a la imatge per triar-ne una altre.',
         'PanelImageTipView' => 'Feu clic a la imatge per veure-la a mida real.',
         'PanelImageTipMenu' => 'Feu clic amb el botó dret per a més opcions.',
@@ -447,6 +458,7 @@ http://le-spektre.org',
         'PanelUnknown' => 'Desconegut',	
         'PanelAdded' => 'Afegeix una data',
         'PanelRating' => 'Valoració',
+        'PanelPressRating' => 'Valoració de la premsa',
         'PanelLocation' => 'Lloc',
 
         'PanelLending' => 'Préstec',
@@ -517,6 +529,8 @@ http://le-spektre.org',
 
         'SearchTooltip' => 'Cerca a tots els elements',
         'SearchTitle' => 'Cerca elements',	
+        'SearchNoField' => 'No heu seleccionat cap camp a la finestra de cerca.
+Afegiu-ne alguns a la pestanya de filtres de la configuració de col·lecció.',
                 
         'QueryReplaceField' => 'Camp per canviar',
         'QueryReplaceOld' => 'Nom actual',	
