@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -304,6 +304,13 @@ http://le-spektre.org',
 		'OptionsAskPlugins' => 'Zeptat se (všechny servery)',
 		'OptionsPluginsMulti' => 'Více serverů',
 		'OptionsPluginsMultiAsk' => 'Zeptat se (více serverů)',
+        'OptionsPluginsMultiPerField' => 'Více serverů (per field)',
+        'OptionsPluginsMultiPerFieldWindowTitle' => 'Many sites per field order selection',
+        'OptionsPluginsMultiPerFieldDesc' => 'For each selected field we will return the first non empty information beginning from left',
+        'OptionsPluginsMultiPerFieldFirst' => 'First',
+        'OptionsPluginsMultiPerFieldLast' => 'Last',
+        'OptionsPluginsMultiPerFieldRemove' => 'Remove',
+        'OptionsPluginsMultiPerFieldClearSelected' => 'Empty selected field list',
 		'OptionsPluginsList' => 'Nastavit seznam',
         'OptionsAskImport' => 'Vyberte pole, která se importují',
 		'OptionsProxy' => 'Použít proxy',
@@ -425,6 +432,10 @@ http://le-spektre.org',
 
         'PanelSearchButton' => 'Stáhnout Informace',
         'PanelSearchTip' => 'Hledá informace o tomto názvu na webu',
+        'PanelSearchContextChooseOne' => 'Choose a site ...',
+        'PanelSearchContextMultiSite' => 'Use "Many sites"',
+        'PanelSearchContextMultiSitePerField' => 'Use "Many sites per field"',
+        'PanelSearchContextOptions' => 'Change options ...',
         'PanelImageTipOpen' => 'Pro výběr jiného obrázku na obrázek klikněte.',
         'PanelImageTipView' => 'Pro zobrazení skutečné velikosti obrázku na něj klikněte.',
         'PanelImageTipMenu' => 'Pod pravým tlačítkem je více voleb.',
@@ -445,6 +456,7 @@ http://le-spektre.org',
         'PanelUnknown' => 'Neznámý',
         'PanelAdded' => 'Přidáno',
         'PanelRating' => 'Hodnocení',
+        'PanelPressRating' => 'Press Rating',
         'PanelLocation' => 'Umístění',
 
         'PanelLending' => 'Zápůjčky',
@@ -515,6 +527,8 @@ http://le-spektre.org',
 
         'SearchTooltip' => 'Prohledává celý seznam',
         'SearchTitle' => 'Hledání',
+        'SearchNoField' => 'No field have been selected for the search box.
+Add some of them in the Filters tab of the collection settings.',
 
         'QueryReplaceField' => 'Nahradit v poli',
         'QueryReplaceOld' => 'Současné jméno',
