@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -303,6 +303,13 @@ http://le-spektre.org',
 		'OptionsAskPlugins' => 'Fragen (Alle Seiten)',
 		'OptionsPluginsMulti' => 'Mehrere...',
 		'OptionsPluginsMultiAsk' => 'Fragen (Mehrere...)',
+        'OptionsPluginsMultiPerField' => 'Mehrere... (per field)',
+        'OptionsPluginsMultiPerFieldWindowTitle' => 'Many sites per field order selection',
+        'OptionsPluginsMultiPerFieldDesc' => 'For each selected field we will return the first non empty information beginning from left',
+        'OptionsPluginsMultiPerFieldFirst' => 'Anfang',
+        'OptionsPluginsMultiPerFieldLast' => 'Ende',
+        'OptionsPluginsMultiPerFieldRemove' => 'Entfernen',
+        'OptionsPluginsMultiPerFieldClearSelected' => 'Ausgewählte Feldliste leeren',
 		'OptionsPluginsList' => 'Sammlung bearbeiten',
         'OptionsAskImport' => 'Zu importierende Felder wählen',
 		'OptionsProxy' => 'Proxy verwenden',
@@ -438,6 +445,10 @@ http://le-spektre.org',
 
         'PanelSearchButton' => 'Internetsuche',
         'PanelSearchTip' => 'Im Internet nach Informationen zu diesem Titel suchen',
+        'PanelSearchContextChooseOne' => 'Wähle eine Seite ...',
+        'PanelSearchContextMultiSite' => 'Verwende "Viele Seiten"',
+        'PanelSearchContextMultiSitePerField' => 'Verwende "Viele Seiten pro Feld"',
+        'PanelSearchContextOptions' => 'Optionen ändern ...',
         'PanelImageTipOpen' => 'Klicken, um das Bild zu ändern.',
         'PanelImageTipView' => 'Klicken, um das Bild in Orginalgröße anzuzeigen.',
         'PanelImageTipMenu' => ' Rechtsklick für weitere Optionen.',
@@ -458,6 +469,7 @@ http://le-spektre.org',
         'PanelUnknown' => 'Unbekannt',
         'PanelAdded' => 'Hinzufügedatum',
         'PanelRating' => 'Bewertung',
+        'PanelPressRating' => 'Press Rating',
         'PanelLocation' => 'Ort',
 
         'PanelLending' => 'Verleih',
@@ -473,7 +485,7 @@ http://le-spektre.org',
         'PanelFavourite' => 'Favoriten',
         'TagsAssigned' => 'Zugeordnete Tags', 
 
-        'PanelUser' => 'User fields',
+        'PanelUser' => 'Nutzerfeld',
 
         'CheckUndef' => 'Egal',
         'CheckYes' => 'Ja',
@@ -489,7 +501,7 @@ http://le-spektre.org',
         'ToolbarSeparator' => ' Trenner',
         
         'PluginsTitle' => 'Nach einem Element suchen',
-        'PluginsQuery' => 'Query',
+        'PluginsQuery' => 'Abfrage',
         'PluginsFrame' => 'Eine Website durchsuchen',
         'PluginsLogo' => 'Logo',
         'PluginsName' => 'Name',
@@ -528,6 +540,8 @@ http://le-spektre.org',
 
         'SearchTooltip' => 'Alle Elemente durchsuchen',
         'SearchTitle' => 'Titelsuche',
+        'SearchNoField' => 'Es wurden keine Felder für die Suchanfrage ausgewählt.
+Füge einige davon in der Filtersektion unter Einstellungen hinzu.',
 
         'QueryReplaceField' => 'Felder zu ersetzen',
         'QueryReplaceOld' => 'Bisheriger Name',
@@ -568,7 +582,7 @@ http://le-spektre.org',
         'PropertiesFileSize' => 'Dateigröße',
         'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Eigenschaften der Sammlung',
-        'PropertiesDefaultPicture' => 'Default picture',
+        'PropertiesDefaultPicture' => 'Standardbild',
 
         'MailProgramsTitle' => 'Programm zum senden von Emails',
         'MailProgramsName' => 'Name',
