@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -305,6 +305,13 @@ http://le-spektre.org',
 		'OptionsAskPlugins' => 'Αναζήτηση (Όλα τα sites)',
 		'OptionsPluginsMulti' => 'Πολλαπλά sites',
 		'OptionsPluginsMultiAsk' => 'Αναζήτηση (Μερικά sites)',
+        'OptionsPluginsMultiPerField' => 'Πολλαπλά sites (per field)',
+        'OptionsPluginsMultiPerFieldWindowTitle' => 'Many sites per field order selection',
+        'OptionsPluginsMultiPerFieldDesc' => 'For each selected field we will return the first non empty information beginning from left',
+        'OptionsPluginsMultiPerFieldFirst' => 'First',
+        'OptionsPluginsMultiPerFieldLast' => 'Last',
+        'OptionsPluginsMultiPerFieldRemove' => 'Remove',
+        'OptionsPluginsMultiPerFieldClearSelected' => 'Empty selected field list',
 		'OptionsPluginsList' => 'Ορισμός λίστας',
         'OptionsAskImport' => 'Επιλεξτε τα πεδια για εισαγωγή',
 		'OptionsProxy' => 'Χρήση proxy',
@@ -427,6 +434,10 @@ http://le-spektre.org',
 
         'PanelSearchButton' => 'Λήψη στοιχείων',
         'PanelSearchTip' => 'Αναζήτηση στο Internet πληροφορίες γι\' αυτό το όνομα',
+        'PanelSearchContextChooseOne' => 'Choose a site ...',
+        'PanelSearchContextMultiSite' => 'Use "Many sites"',
+        'PanelSearchContextMultiSitePerField' => 'Use "Many sites per field"',
+        'PanelSearchContextOptions' => 'Change options ...',
         'PanelImageTipOpen' => 'Πατήστε στην εικόνα για να επιλέξτε άλλη.',
         'PanelImageTipView' => 'Πατήστε στην εικόνα για να τη δείτε σε πραγματικό μέγεθος.',
         'PanelImageTipMenu' => ' Δεξί κλικ για περισσότερες επιλογές.',
@@ -447,6 +458,7 @@ http://le-spektre.org',
         'PanelUnknown' => 'Άγνωστος',
         'PanelAdded' => 'Ημερομηνία προσθήκης',
         'PanelRating' => 'Βαθμολογία',
+        'PanelPressRating' => 'Βαθμολόγηση ανά κλικ',
         'PanelLocation' => 'Τοποθεσία',
 
         'PanelLending' => 'Δανεισμοί',
@@ -517,6 +529,8 @@ http://le-spektre.org',
 
         'SearchTooltip' => 'Αναζήτηση σε όλα τα στοιχεία',
         'SearchTitle' => 'Αναζήτηση',
+        'SearchNoField' => 'Δεν έχετε επιλέξει κάποιο πεδίο για το κουτί αναζήτησης.
+Προσθέστε μερικά στην καρτέλα με τα φίλτρα στις ρυθμίσεις της συλλογής.',
 
         'QueryReplaceField' => 'Πεδία προς επεξεργασία',
         'QueryReplaceOld' => 'Τρέχουσα τιμή',
