@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -46,7 +46,7 @@ Any redistribution is forbidden without the site\'s
 To determine which site owns the information, you
 may use the <b>button below item details</b>.',
         
-        'AllItemsFiltered' => 'No item matches your filtering criteria',
+        'AllItemsFiltered' => 'No item matches your filter criteria',
         
 #Installation
         'InstallDirInfo' => 'Installing in ',
@@ -56,7 +56,7 @@ may use the <b>button below item details</b>.',
         'InstallPrompt' => 'Base directory for installation [/usr/local]: ',
         'InstallEnd' => 'End of the installation',
         'InstallNoError' => 'No error',
-        'InstallLaunch' => 'To use this application, one can launch ',
+        'InstallLaunch' => 'To use this application you can launch ',
         'InstallDirectory' => 'Base directory',
         'InstallTitle' => 'GCstar installation',
         'InstallDependencies' => 'Dependencies',
@@ -67,7 +67,7 @@ may use the <b>button below item details</b>.',
         'InstallWithMenu' => 'Add GCstar to Applications menu',
         'InstallNoPermission' => 'Error: You don\'t have permission to write in the selected directory',
         'InstallMissingMandatory' => 'Mandatory dependencies are missing. You won\'t be able to install GCstar until they have been added to your system.',
-        'InstallMissingOptional' => 'Some optional dependencies are missing. These are listed below. GCstar may be installed but some features won\'t be available.',
+        'InstallMissingOptional' => 'Some optional dependencies are missing. These are listed below. GCstar can be installed but some features won\'t be available.',
         'InstallMissingNone' => 'There are no missing dependencies. You may continue and install GCstar.',
         'InstallOK' => 'OK',
         'InstallMissing' => 'Missing',
@@ -79,18 +79,18 @@ may use the <b>button below item details</b>.',
 #Update
         'UpdateUseProxy' => 'Proxy to use (just press enter if none): ',
         'UpdateNoPermission' => 'Write permission denied in this directory: ',
-        'UpdateNone' => 'No update have been found',
+        'UpdateNone' => 'No updates have been found',
         'UpdateFileNotFound' => 'File not found',
 
 #Splash
-        'SplashInit' => 'Initialization',
+        'SplashInit' => 'Initializing',
         'SplashLoad' => 'Loading Collection',
         'SplashDisplay' => 'Displaying Collection',
         'SplashSort' => 'Sorting Collection',
         'SplashDone' => 'Ready',
 
 #Import from GCfilms
-        'GCfilmsImportQuestion' => 'It seems you were using GCfilms before. What do you want to import from GCfilms to GCstar (it won\'t impact GCfilms if you still want to use it)?',
+        'GCfilmsImportQuestion' => 'It seems you were previously using GCfilms. What do you want to import from GCfilms to GCstar (it won\'t impact GCfilms if you still want to use it)?',
         'GCfilmsImportOptions' => 'Settings',
         'GCfilmsImportData' => 'Movies list',
 
@@ -109,9 +109,9 @@ may use the <b>button below item details</b>.',
             'MenuEditLockItems' => '_Lock Collection',
     
         'MenuDisplay' => 'F_ilter',
-            'MenuSavedSearches' => 'Saved searches',
-                'MenuSavedSearchesSave' => 'Save current search',
-                'MenuSavedSearchesEdit' => 'Modify saved searches',
+            'MenuSavedSearches' => 'Saved Searches',
+                'MenuSavedSearchesSave' => 'Save Current Search',
+                'MenuSavedSearchesEdit' => 'Modify Saved Searches',
             'MenuAdvancedSearch' => 'A_dvanced Search',
             'MenuViewAllItems' => 'Show _All Items',
             'MenuNoFilter' => '_Any',
@@ -178,11 +178,11 @@ may use the <b>button below item details</b>.',
         'ErrorModelNotFound' => 'Model not found: ',
         'ErrorModelUserDir' => 'User defined models are in: ',
         
-        'RandomTooltip' => 'What to see this evening ?',
-        'RandomError'=> 'You have no item that could be selected',
+        'RandomTooltip' => 'What to see this evening?',
+        'RandomError'=> 'You have no items which could be chosen',
         'RandomEnd'=> 'There are no more items',
         'RandomNextTip'=> 'Next suggestion',
-        'RandomOkTip'=> 'Accept this item',
+        'RandomOkTip'=> 'Accept this suggestion',
         
         'AboutTitle' => 'About GCstar',
         'AboutDesc' => 'Personal collections manager',
@@ -200,6 +200,8 @@ http://le-spektre.org',
         'AboutDesign' => 'Logo and webdesign by le Spektre',
 
         'UnsavedCollection' => 'Unsaved Collection',
+
+#Collection models
         'ModelsSelect' => 'Select a collection type',
         'ModelsPersonal' => 'Personal models',
         'ModelsDefault' => 'Default models',
@@ -272,12 +274,36 @@ http://le-spektre.org',
         'ModelTooltipTagging' => 'This will add some fields to manage tags',
         'ModelTooltipNumeric' => 'Should the values be considered as numbers for comparison',
         'ModelTooltipQuick' => 'This will add a submenu in the Filters one',
-        
+
+#Web searches
+        'PluginsTitle' => 'Search an item',
+        'PluginsQuery' => 'Query',
+        'PluginsFrame' => 'Search site',
+        'PluginsLogo' => 'Logo',
+        'PluginsName' => 'Name',
+        'PluginsSearchFields' => 'Search fields',
+        'PluginsAuthor' => 'Author',
+        'PluginsLang' => 'Language',
+        'PluginsUseSite' => 'Use selected site for future searches',
+
         'ResultsTitle' => 'Select an item',
         'ResultsNextTip' => 'Search in next site',
         'ResultsPreview' => 'Preview',
         'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them',
-        
+
+        'ImportWindowTitle' => 'Select Fields to be Imported',
+        'ImportViewPicture' => 'View Picture',
+        'ImportSelectAll' => 'Select All',
+        'ImportSelectNone' => 'Select None',
+
+        'MultiSiteTitle' => 'Sites to use for searches',
+        'MultiSiteUnused' => 'Unused plugins',
+        'MultiSiteUsed' => 'Plugins to be used',
+        'MultiSiteLang' => 'Fill List with English Plugins',
+        'MultiSiteEmptyError' => 'You have an empty site list',
+        'MultiSiteClear' => 'Clear List',
+
+#Settings
         'OptionsTitle' => 'Preferences',
 		'OptionsExpertMode' => 'Expert Mode',
         'OptionsPrograms' => 'Specify applications to use for different media, leave blank to use system defaults',
@@ -299,14 +325,21 @@ http://le-spektre.org',
         'OptionsTearoffMenus' => 'Enable tear-off menus',
         'OptionsSpellCheck' => 'Use spelling checker for long text fields',
         'OptionsProgramTitle' => 'Select the program to be used',
-		'OptionsPlugins' => 'Site to retrieve data from',
-		'OptionsAskPlugins' => 'Ask (All sites)',
-		'OptionsPluginsMulti' => 'Many sites',
-		'OptionsPluginsMultiAsk' => 'Ask (Many sites)',
-		'OptionsPluginsList' => 'Set list',
+        'OptionsPlugins' => 'Site to retrieve data from',
+        'OptionsAskPlugins' => 'Ask (All sites)',
+        'OptionsPluginsMulti' => 'Many sites',
+        'OptionsPluginsMultiAsk' => 'Ask (Many sites)',
+        'OptionsPluginsMultiPerField' => 'Many sites (per field)',
+        'OptionsPluginsMultiPerFieldWindowTitle' => 'Many sites per field order selection',
+        'OptionsPluginsMultiPerFieldDesc' => 'For each field we will fill the field with the first non empty information beginning from left',
+        'OptionsPluginsMultiPerFieldFirst' => 'First',
+        'OptionsPluginsMultiPerFieldLast' => 'Last',
+        'OptionsPluginsMultiPerFieldRemove' => 'Remove',
+        'OptionsPluginsMultiPerFieldClearSelected' => 'Empty selected field list',
+        'OptionsPluginsList' => 'Set list',
         'OptionsAskImport' => 'Select fields to be imported',
-		'OptionsProxy' => 'Use a proxy',
-		'OptionsCookieJar' => 'Use this cookie jar file',
+        'OptionsProxy' => 'Use a proxy',
+        'OptionsCookieJar' => 'Use this cookie jar file',
         'OptionsLang' => 'Language',
         'OptionsMain' => 'Main',
         'OptionsPaths' => 'Paths',
@@ -330,17 +363,17 @@ http://le-spektre.org',
         'OptionsTransform' => 'Place articles at the end of titles',
         'OptionsArticles' => 'Articles (Comma separated)',
         'OptionsSearchStop' => 'Allow search to be aborted',
-        'OptionsBigPics' => 'Use big pictures when available',
+        'OptionsBigPics' => 'Download hi-res artwork when available',
         'OptionsAlwaysOriginal' => 'Use main title as the original title if none present',
-        'OptionsRestoreAccelerators' => 'Restore accelerators',
+        'OptionsRestoreAccelerators' => 'Restore Accelerators',
         'OptionsHistory' => 'Size of history',
-        'OptionsClearHistory' => 'Clear history',
+        'OptionsClearHistory' => 'Clear History',
 		'OptionsStyle' => 'Skin',
         'OptionsDontAsk' => 'Don\'t ask anymore',
         'OptionsPathProgramsGroup' => 'Applications',
         'OptionsProgramsSystem' => 'Use programs defined by system',
         'OptionsProgramsUser' => 'Override default programs',
-        'OptionsProgramsSet' => 'Set programs',
+        'OptionsProgramsSet' => 'Set Programs',
         'OptionsPathImagesGroup' => 'Images',
         'OptionsInternetDataGroup' => 'Data import',
         'OptionsInternetSettingsGroup' => 'Settings',
@@ -356,8 +389,9 @@ http://le-spektre.org',
         'OptionsPicturesWorkingDir' => '%WORKING_DIR% or . will be replaced with collection directory (use only on beginning of path)',
         'OptionsPicturesFileBase' => '%FILE_BASE% will be replaced by collection file name without suffix (.gcs)',
         'OptionsPicturesWorkingDirError' => '%WORKING_DIR% could only be used on the beginning of the path for pictures',
-        'OptionsConfigureMailers' => 'Configure mailing programs',
+        'OptionsConfigureMailers' => 'Configure Mailing Programs',
 
+#Image list settings
         'ImagesOptionsButton' => 'Settings',
         'ImagesOptionsTitle' => 'Settings for images list',
         'ImagesOptionsSelectColor' => 'Select a color',
@@ -371,7 +405,8 @@ http://le-spektre.org',
         'ImagesOptionsSizeLabel' => 'Size',
         'ImagesOptionsSizeList' => {0 => 'Very Small', 1 => 'Small', 2 => 'Medium', 3 => 'Large', 4 => 'Extra Large'},
         'ImagesOptionsSizeTooltip' => 'Select image size',
-		        
+
+#Detailed list settings
         'DetailedOptionsTitle' => 'Settings for detailed list',
         'DetailedOptionsImageSize' => 'Images size',
         'DetailedOptionsGroupItems' => 'Group items by',
@@ -380,15 +415,23 @@ http://le-spektre.org',
         'DetailedOptionsGroupedFirst' => 'Keep together orphaned items',
         'DetailedOptionsAddCount' => 'Add number of elements on categories',
 
+#Fields to display
+        'DisplayOptionsTitle' => 'Items to display',
+        'DisplayOptionsAll' => 'Select all',
+        'DisplayOptionsSearch' => 'Search button',
+
+#Extract plugins
         'ExtractButton' => 'Information',
         'ExtractTitle' => 'File information',
         'ExtractImport' => 'Use values',
 
+#Fields list
         'FieldsListOpen' => 'Load a fields list from a file',
         'FieldsListSave' => 'Save fields list to a file',
         'FieldsListError' => 'This fields list cannot be used with this kind of collection',
         'FieldsListIgnore' => '--- Ignore',
 
+#Export plugins
         'ExportTitle' => 'Export item list',
         'ExportFilter' => 'Export only displayed items',
         'ExportFieldsTitle' => 'Fields to be exported',
@@ -397,6 +440,7 @@ http://le-spektre.org',
         'ExportSortBy' => 'Sort by',
         'ExportOrder' => 'Order',
 
+#Import plugins
         'ImportListTitle' => 'Import another items list',
         'ImportExportData' => 'Data',
         'ImportExportFile' => 'File',
@@ -413,25 +457,31 @@ http://le-spektre.org',
         'ImportDropError' => 'There was an error opening at least one file. Previous list will be reloaded.',
         'ImportGenerateId' => 'Generate identifier for each item',
 
+#File chooser
         'FileChooserOpenFile' => 'Please select file to use',
         'FileChooserDirectory' => 'Directory',
         'FileChooserOpenDirectory' => 'Select a directory',
         'FileChooserOverwrite' => 'This file already exists. Do you want to overwrite it?',
 
-        #Some default panels
+#Some default panels
         'PanelCompact' => 'Compact',
         'PanelReadOnly' => 'Read Only',
         'PanelForm' => 'Tabs',
 
+#Default labels used in panels
         'PanelSearchButton' => 'Fetch Information',
         'PanelSearchTip' => 'Search web for information on this name',
+        'PanelSearchContextChooseOne' => 'Choose a site ...',
+        'PanelSearchContextMultiSite' => 'Use "Many sites"',
+        'PanelSearchContextMultiSitePerField' => 'Use "Many sites per field"',
+        'PanelSearchContextOptions' => 'Change options ...',
         'PanelImageTipOpen' => 'Click on the picture to select different one.',
         'PanelImageTipView' => 'Click on the picture to view it in real size.',
         'PanelImageTipMenu' => ' Right click for more options.',
         'PanelImageTitle' => 'Select a picture',
         'PanelImageNoImage' => 'No image',
         'PanelSelectFileTitle' => 'Select a file',
-        'PanelRestoreDefault' => 'Restore default',
+        'PanelRestoreDefault' => 'Restore Default',
 
         'PanelFrom' =>'From',
         'PanelTo' =>'To',
@@ -445,6 +495,7 @@ http://le-spektre.org',
         'PanelUnknown' => 'Unknown',
         'PanelAdded' => 'Add date',
         'PanelRating' => 'Rating',
+        'PanelPressRating' => 'Press Rating',
         'PanelLocation' => 'Location',
 
         'PanelLending' => 'Lending',
@@ -466,6 +517,7 @@ http://le-spektre.org',
         'CheckYes' => 'Yes',
         'CheckNo' => 'No',
 
+#Toolbar
         'ToolbarRandom' => 'Tonight',
         'ToolbarAll' => 'View All',
         'ToolbarAllTooltip' => 'View all items',
@@ -475,17 +527,8 @@ http://le-spektre.org',
         'ToolbarQuickSearchLabel' => 'Search',
         'ToolbarQuickSearchTooltip' => 'Select the field to search in. Enter the search terms and press Enter',
         'ToolbarSeparator' => ' Separator',
-        
-        'PluginsTitle' => 'Search an item',
-        'PluginsQuery' => 'Query',
-        'PluginsFrame' => 'Search site',
-        'PluginsLogo' => 'Logo',
-        'PluginsName' => 'Name',
-        'PluginsSearchFields' => 'Search fields',
-        'PluginsAuthor' => 'Author',
-        'PluginsLang' => 'Language',
-        'PluginsUseSite' => 'Use selected site for future searches',
 
+#Borrowers
         'BorrowersTitle' => 'Borrower Configuration',
         'BorrowersList' => 'Borrowers',
         'BorrowersName' => 'Name',
@@ -507,6 +550,7 @@ http://le-spektre.org',
         'BorrowedDate' => 'Since',
         'BorrowedDisplayInPanel' => 'Show item in main window',
 
+#Mail
         'MailTitle' => 'Send an e-mail',
         'MailFrom' => 'From: ',
         'MailTo' => 'To: ',
@@ -514,37 +558,30 @@ http://le-spektre.org',
         'MailSmtpError' => 'Problem when connecting to SMTP server',
         'MailSendmailError' => 'Problem when launching sendmail',
 
+#Search dialog
         'SearchTooltip' => 'Search all items',
         'SearchTitle' => 'Item Search',
+        'SearchNoField' => 'No field have been selected for the search box.
+Add some of them in the Filters tab of the collection settings.',
 
+        'AdvancedSearchType' => 'Type of search',
+        'AdvancedSearchTypeAnd' => 'Items matching all criteria',
+        'AdvancedSearchTypeOr' => 'Items matching at least one criterion',
+        'AdvancedSearchCriteria' => 'Criteria',
+        'AdvancedSearchAnyField' => 'Any field',
+        'AdvancedSearchSaveTitle' => 'Save search',
+        'AdvancedSearchSaveName' => 'Name',
+        'AdvancedSearchSaveOverwrite' => 'A saved search already exists with that name. Please use a different one.',
+        'AdvancedSearchUseCase' => 'Case sensitive',
+        'AdvancedSearchIgnoreDiacritics' => 'Ignore accents and other diacritics',
+
+#Query replace
         'QueryReplaceField' => 'Field to replace',
         'QueryReplaceOld' => 'Current value',
         'QueryReplaceNew' => 'New value',
         'QueryReplaceLaunch' => 'Replace',
-        
-        'ImportWindowTitle' => 'Select Fields to be Imported',
-        'ImportViewPicture' => 'View picture',
-        'ImportSelectAll' => 'Select all',
-        'ImportSelectNone' => 'Select none',
-
-        'MultiSiteTitle' => 'Sites to use for searches',
-        'MultiSiteUnused' => 'Unused plugins',
-        'MultiSiteUsed' => 'Plugins to be used',
-        'MultiSiteLang' => 'Fill list with English plugins',
-        'MultiSiteEmptyError' => 'You have an empty site list',
-        'MultiSiteClear' => 'Clear list',
-        
-        'DisplayOptionsTitle' => 'Items to display',
-        'DisplayOptionsAll' => 'Select all',
-        'DisplayOptionsSearch' => 'Search button',
-
-        'GenresTitle' => 'Genre Conversion',
-        'GenresCategoryName' => 'Genre to use',
-        'GenresCategoryMembers' => 'Genre to replace',
-        'GenresLoad' => 'Load a list',
-        'GenresExport' => 'Save list to a file',
-        'GenresModify' => 'Edit conversion',
 
+#Collection properties
         'PropertiesName' => 'Collection name',
         'PropertiesLang' => 'Language code',
         'PropertiesOwner' => 'Owner',
@@ -558,6 +595,7 @@ http://le-spektre.org',
         'PropertiesCollection' => 'Collection properties',
         'PropertiesDefaultPicture' => 'Default picture',
 
+#Mail sending
         'MailProgramsTitle' => 'Programs for mail sending',
         'MailProgramsName' => 'Name',
         'MailProgramsCommand' => 'Command line',
@@ -569,28 +607,27 @@ http://le-spektre.org',
  %s is replaced with the subject of the message.
  %b is replaced with the body of the message.',
 
+#Bookmarks
         'BookmarksBookmarks' => 'Bookmarks',
         'BookmarksFolder' => 'Folders',
         'BookmarksLabel' => 'Label',
         'BookmarksPath' => 'Path',
         'BookmarksNewFolder' => 'New folder',
 
-        'AdvancedSearchType' => 'Type of search',
-        'AdvancedSearchTypeAnd' => 'Items matching all criteria',
-        'AdvancedSearchTypeOr' => 'Items matching at least one criterion',
-        'AdvancedSearchCriteria' => 'Criteria',
-        'AdvancedSearchAnyField' => 'Any field',
-        'AdvancedSearchSaveTitle' => 'Save search',
-        'AdvancedSearchSaveName' => 'Name',
-        'AdvancedSearchSaveOverwrite' => 'A saved search already exists with that name. Please use a different one.',
-        'AdvancedSearchUseCase' => 'Case sensitive',
-        'AdvancedSearchIgnoreDiacritics' => 'Ignore accents and other diacritics',
-
+#Bug report
         'BugReportSubject' => 'Bug report generated from GCstar',
         'BugReportVersion' => 'Version',
         'BugReportPlatform' => 'Operating system',
         'BugReportMessage' => 'Error message',
         'BugReportInformation' => 'Additional information',
+
+#Not used yet
+        'GenresTitle' => 'Genre Conversion',
+        'GenresCategoryName' => 'Genre to use',
+        'GenresCategoryMembers' => 'Genre to replace',
+        'GenresLoad' => 'Load a list',
+        'GenresExport' => 'Save list to a file',
+        'GenresModify' => 'Edit conversion',
     );
 }
 1;
