@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -305,6 +305,13 @@ http://le-spektre.org',
         'OptionsAskPlugins' => 'Preguntar',
         'OptionsPluginsMulti' => 'Varios sitios',
         'OptionsPluginsMultiAsk' => 'Preguntar (Algunos sitios)',
+        'OptionsPluginsMultiPerField' => 'Varios sitios (per field)',
+        'OptionsPluginsMultiPerFieldWindowTitle' => 'Many sites per field order selection',
+        'OptionsPluginsMultiPerFieldDesc' => 'For each selected field we will return the first non empty information beginning from left',
+        'OptionsPluginsMultiPerFieldFirst' => 'First',
+        'OptionsPluginsMultiPerFieldLast' => 'Last',
+        'OptionsPluginsMultiPerFieldRemove' => 'Remove',
+        'OptionsPluginsMultiPerFieldClearSelected' => 'Empty selected field list',
         'OptionsPluginsList' => 'Definir la lista',
         'OptionsAskImport' => 'Elegir los campos que deben importarse',
         'OptionsProxy' => 'Utilizar un proxy',
@@ -426,6 +433,10 @@ http://le-spektre.org',
 
         'PanelSearchButton' => 'Descargar',
         'PanelSearchTip' => 'Buscar información relativa a la película',
+        'PanelSearchContextChooseOne' => 'Choose a site ...',
+        'PanelSearchContextMultiSite' => 'Use "Many sites"',
+        'PanelSearchContextMultiSitePerField' => 'Use "Many sites per field"',
+        'PanelSearchContextOptions' => 'Change options ...',
         'PanelImageTipOpen' => 'Pulse en la imagen para elegir otra.',
         'PanelImageTipView' => 'Pulse en la imagen para verla en su tamaño real...',
         'PanelImageTipMenu' => 'Click con el botón derecho para mas opciones.',
@@ -446,6 +457,7 @@ http://le-spektre.org',
         'PanelUnknown' => 'Desconocido',	
         'PanelAdded' => 'Añadida el (fecha)',
         'PanelRating' => 'Nota',
+        'PanelPressRating' => 'Press Rating',
         'PanelLocation' => 'Sitio',
 
         'PanelLending' => 'Préstamo',
@@ -516,6 +528,8 @@ http://le-spektre.org',
 
         'SearchTooltip' => 'Buscar en todas las películas',	
         'SearchTitle' => 'Búsqueda de películas',	
+        'SearchNoField' => 'No field have been selected for the search box.
+Add some of them in the Filters tab of the collection settings.',
                 
         'QueryReplaceField' => 'Campo a sustituir',
         'QueryReplaceOld' => 'Nombre actual',	
