@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -39,6 +39,10 @@
         NewItem => 'Nouvel épisode',
         NewSeries => 'Nouvelle série',
         Episode => 'Épisode',
+        
+        General => 'Fiche de l\'épisode',
+        Writer => 'Scénariste',
+        Seen => 'Épisode déjà vu',
     );
     # Both of them are required as importTranslation doesn't recurse
     importTranslation('films');
