@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -304,6 +304,13 @@ http://le-spektre.org',
 		'OptionsAskPlugins' => 'Demander (Tous les sites)',
 		'OptionsPluginsMulti' => 'Plusieurs sites',
 		'OptionsPluginsMultiAsk' => 'Demander (Certains sites)',
+        'OptionsPluginsMultiPerField' => 'Plusieurs sites (par champs)',
+        'OptionsPluginsMultiPerFieldWindowTitle' => 'Choix de l\'ordre pour plusieurs sites par champs',
+        'OptionsPluginsMultiPerFieldDesc' => 'Pour chaque champs sélectionné, on remplira avec la première information non vide trouvée, en partant de gauche.',
+        'OptionsPluginsMultiPerFieldFirst' => 'En premier',
+        'OptionsPluginsMultiPerFieldLast' => 'En dernier',
+        'OptionsPluginsMultiPerFieldRemove' => 'Supprimer',
+        'OptionsPluginsMultiPerFieldClearSelected' => 'Vider les listes sélectionnées',
 		'OptionsPluginsList' => 'Définir la liste',		
         'OptionsAskImport' => 'Choisir les champs à importer',
 		'OptionsProxy' => 'Utiliser un proxy',
@@ -425,6 +432,10 @@ http://le-spektre.org',
 
         'PanelSearchButton' => 'Télécharger',
         'PanelSearchTip' => 'Rechercher les informations concernant l\'élément dont le nom a été saisi',
+        'PanelSearchContextChooseOne' => 'Choisir un site ...',
+        'PanelSearchContextMultiSite' => 'Utiliser "plusieurs sites"',
+        'PanelSearchContextMultiSitePerField' => 'Utiliser "plusieurs sites par champs"',
+        'PanelSearchContextOptions' => 'Changer les options ...',
         'PanelImageTipOpen' => 'Cliquez sur l\'image pour en choisir une autre.',
         'PanelImageTipView' => 'Cliquez sur l\'image pour la voir en taille réelle.',
         'PanelImageTipMenu' => ' Clic droit pour plus d\'options.',
@@ -445,6 +456,7 @@ http://le-spektre.org',
         'PanelUnknown' => 'Inconnu',
         'PanelAdded' => 'Date d\'ajout',
         'PanelRating' => 'Note',
+        'PanelPressRating' => 'Note Presse',
         'PanelLocation' => 'Emplacement',
 
         'PanelLending' => 'Emprunts',
@@ -456,7 +468,7 @@ http://le-spektre.org',
         'PanelLendedYes' => 'Prêté',
         'PanelLendedNo' => 'Disponible',
 
-        'PanelTags' => 'Etiquettes',
+        'PanelTags' => 'Étiquettes',
         'PanelFavourite' => 'Favori',
         'TagsAssigned' => 'Mots-clés associés',
 
@@ -516,6 +528,8 @@ http://le-spektre.org',
                 
         'SearchTooltip' => 'Rechercher dans tous les éléments',
         'SearchTitle' => 'Recherche d\'éléments',
+        'SearchNoField' => 'Aucun champ n\'a été sélectionné pour la fenêtre de recherche.
+Ils peuvent être ajoutés dans l\'onglet Filtres des réglages de la collection.',
         
         'QueryReplaceField' => 'Champs à modifier',
         'QueryReplaceOld' => 'Valeur actuelle',
@@ -576,8 +590,8 @@ http://le-spektre.org',
         'BookmarksNewFolder' => 'Nouveau répertoire',
 
         'AdvancedSearchType' => 'Type de recherche',
-        'AdvancedSearchTypeAnd' => 'Eléments correspondants à tous les critères',
-        'AdvancedSearchTypeOr' => 'Eléments correspondants à au moins un critère',
+        'AdvancedSearchTypeAnd' => 'Éléments correspondants à tous les critères',
+        'AdvancedSearchTypeOr' => 'Éléments correspondants à au moins un critère',
         'AdvancedSearchCriteria' => 'Critères',
         'AdvancedSearchAnyField' => 'N\'importe quel champ',
         'AdvancedSearchSaveTitle' => 'Sauvegarder la recherche',
