@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -305,6 +305,13 @@ http://le-spektre.org',
 		'OptionsAskPlugins' => 'Preguntar (Todos os sitios web)',
 		'OptionsPluginsMulti' => 'Algúns sitios',
 		'OptionsPluginsMultiAsk' => 'Preguntar (Algúns sitios web)',
+        'OptionsPluginsMultiPerField' => 'Algúns sitios (per field)',
+        'OptionsPluginsMultiPerFieldWindowTitle' => 'Many sites per field order selection',
+        'OptionsPluginsMultiPerFieldDesc' => 'For each selected field we will return the first non empty information beginning from left',
+        'OptionsPluginsMultiPerFieldFirst' => 'First',
+        'OptionsPluginsMultiPerFieldLast' => 'Last',
+        'OptionsPluginsMultiPerFieldRemove' => 'Remove',
+        'OptionsPluginsMultiPerFieldClearSelected' => 'Empty selected field list',
 		'OptionsPluginsList' => 'Definir a listaxe',
         'OptionsAskImport' => 'Seleccione os campos para importar',
 		'OptionsProxy' => 'Usar un proxy',
@@ -427,6 +434,10 @@ http://le-spektre.org',
 
         'PanelSearchButton' => 'Buscar información',
         'PanelSearchTip' => 'Buscar na web información sobre este nome',
+        'PanelSearchContextChooseOne' => 'Choose a site ...',
+        'PanelSearchContextMultiSite' => 'Use "Many sites"',
+        'PanelSearchContextMultiSitePerField' => 'Use "Many sites per field"',
+        'PanelSearchContextOptions' => 'Change options ...',
         'PanelImageTipOpen' => 'Preme na imaxe para seleccionar unha diferente.',
         'PanelImageTipView' => 'Preme na imaxe para vela no seu tamaño real.',
         'PanelImageTipMenu' => ' Botón dereito para máis opcións.',
@@ -447,6 +458,7 @@ http://le-spektre.org',
         'PanelUnknown' => 'Descoñecido',
         'PanelAdded' => 'Engadir data',
         'PanelRating' => 'Puntuación',
+        'PanelPressRating' => 'Press Rating',
         'PanelLocation' => 'Localidade',
 
         'PanelLending' => 'Prestamo',
@@ -517,6 +529,8 @@ http://le-spektre.org',
 
         'SearchTooltip' => 'Procurar todos os elementos',
         'SearchTitle' => 'Procura de elementos',
+        'SearchNoField' => 'No field have been selected for the search box.
+Add some of them in the Filters tab of the collection settings.',
 
         'QueryReplaceField' => 'Campo a reemprazar',
         'QueryReplaceOld' => 'Valor actual',
