@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -305,6 +305,13 @@ http://le-spektre.org',
 		'OptionsAskPlugins' => 'Keres (Minden oldalon)',
 		'OptionsPluginsMulti' => 'Több oldalon',
 		'OptionsPluginsMultiAsk' => 'Keres (Több oldalon)',
+        'OptionsPluginsMultiPerField' => 'Több oldalon (per field)',
+        'OptionsPluginsMultiPerFieldWindowTitle' => 'Many sites per field order selection',
+        'OptionsPluginsMultiPerFieldDesc' => 'For each selected field we will return the first non empty information beginning from left',
+        'OptionsPluginsMultiPerFieldFirst' => 'First',
+        'OptionsPluginsMultiPerFieldLast' => 'Last',
+        'OptionsPluginsMultiPerFieldRemove' => 'Remove',
+        'OptionsPluginsMultiPerFieldClearSelected' => 'Empty selected field list',
 		'OptionsPluginsList' => 'Lista beállítása',
         'OptionsAskImport' => 'Importálandó mezők kiválasztása',
 		'OptionsProxy' => 'Proxy használata',
@@ -427,6 +434,10 @@ http://le-spektre.org',
 
         'PanelSearchButton' => 'Internetes keresés',
         'PanelSearchTip' => 'Keresés az interneten erre a névre',
+        'PanelSearchContextChooseOne' => 'Choose a site ...',
+        'PanelSearchContextMultiSite' => 'Use "Many sites"',
+        'PanelSearchContextMultiSitePerField' => 'Use "Many sites per field"',
+        'PanelSearchContextOptions' => 'Change options ...',
         'PanelImageTipOpen' => 'Kattins a képre a változtatáshoz.',
         'PanelImageTipView' => 'Eredeti mérethez kattints a képre.',
         'PanelImageTipMenu' => ' Jobb klikk a további beállításokhoz.',
@@ -447,6 +458,7 @@ http://le-spektre.org',
         'PanelUnknown' => 'Ismeretlen',
         'PanelAdded' => 'Dátum hozzáadása',
         'PanelRating' => 'Értékelés',
+        'PanelPressRating' => 'Press Rating',
         'PanelLocation' => 'Hely',
 
         'PanelLending' => 'Kölcsönzés',
@@ -517,6 +529,8 @@ http://le-spektre.org',
 
         'SearchTooltip' => 'Elemek keresése',
         'SearchTitle' => 'Elem keresése',
+        'SearchNoField' => 'No field have been selected for the search box.
+Add some of them in the Filters tab of the collection settings.',
 
         'QueryReplaceField' => 'Mezőcsere',
         'QueryReplaceOld' => 'Jelenlegi érték',
