@@ -305,6 +305,13 @@ http://le-spektre.org',
 		'OptionsAskPlugins' => 'Tanya (Semua situs)',
 		'OptionsPluginsMulti' => 'Banyak situs',
 		'OptionsPluginsMultiAsk' => 'Tanya (Banyak situs)',
+        'OptionsPluginsMultiPerField' => 'Banyak situs (per field)',
+        'OptionsPluginsMultiPerFieldWindowTitle' => 'Many sites per field order selection',
+        'OptionsPluginsMultiPerFieldDesc' => 'For each selected field we will return the first non empty information beginning from left',
+        'OptionsPluginsMultiPerFieldFirst' => 'First',
+        'OptionsPluginsMultiPerFieldLast' => 'Last',
+        'OptionsPluginsMultiPerFieldRemove' => 'Remove',
+        'OptionsPluginsMultiPerFieldClearSelected' => 'Empty selected field list',
 		'OptionsPluginsList' => 'Set daftar',
         'OptionsAskImport' => 'Select fields to be imported',
 		'OptionsProxy' => 'Menggunakan proxy',
@@ -427,6 +434,10 @@ http://le-spektre.org',
 
         'PanelSearchButton' => 'Fetch Information',
         'PanelSearchTip' => 'Search web for information on this name',
+        'PanelSearchContextChooseOne' => 'Choose a site ...',
+        'PanelSearchContextMultiSite' => 'Use "Many sites"',
+        'PanelSearchContextMultiSitePerField' => 'Use "Many sites per field"',
+        'PanelSearchContextOptions' => 'Change options ...',
         'PanelImageTipOpen' => 'Click on the picture to select different one.',
         'PanelImageTipView' => 'Click on the picture to view it in real size.',
         'PanelImageTipMenu' => ' Right click for more options.',
@@ -447,6 +458,7 @@ http://le-spektre.org',
         'PanelUnknown' => 'Tidak diketahui',
         'PanelAdded' => 'Add date',
         'PanelRating' => 'Rating',
+        'PanelPressRating' => 'Press Rating',
         'PanelLocation' => 'Location',
 
         'PanelLending' => 'Lending',
@@ -517,6 +529,8 @@ http://le-spektre.org',
 
         'SearchTooltip' => 'Search all items',
         'SearchTitle' => 'Item Search',
+        'SearchNoField' => 'No field have been selected for the search box.
+Add some of them in the Filters tab of the collection settings.',
 
         'QueryReplaceField' => 'Field to replace',
         'QueryReplaceOld' => 'Current value',
