@@ -4,7 +4,7 @@
     use utf8;
 ######################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -311,6 +311,13 @@ Andreas Troschka - <swsolutions@om.it.eu.org>',
 		'OptionsAskPlugins' => 'Chiedi (Tutti i siti)',
 		'OptionsPluginsMulti' => 'Diversi siti',
 		'OptionsPluginsMultiAsk' => 'Chiedi (Diversi siti)',
+        'OptionsPluginsMultiPerField' => 'Diversi siti (per field)',
+        'OptionsPluginsMultiPerFieldWindowTitle' => 'Many sites per field order selection',
+        'OptionsPluginsMultiPerFieldDesc' => 'For each selected field we will return the first non empty information beginning from left',
+        'OptionsPluginsMultiPerFieldFirst' => 'First',
+        'OptionsPluginsMultiPerFieldLast' => 'Last',
+        'OptionsPluginsMultiPerFieldRemove' => 'Remove',
+        'OptionsPluginsMultiPerFieldClearSelected' => 'Empty selected field list',
 		'OptionsPluginsList' => 'Configura la lista',
         'OptionsAskImport' => 'Seleziona i campi da importare',
 		'OptionsProxy' => 'Usa un proxy',
@@ -432,6 +439,10 @@ Andreas Troschka - <swsolutions@om.it.eu.org>',
 
         'PanelSearchButton' => 'Recupera informazioni',
         'PanelSearchTip' => 'Cerca informazioni secondo il titolo dell\'articolo inserito',
+        'PanelSearchContextChooseOne' => 'Choose a site ...',
+        'PanelSearchContextMultiSite' => 'Use "Many sites"',
+        'PanelSearchContextMultiSitePerField' => 'Use "Many sites per field"',
+        'PanelSearchContextOptions' => 'Change options ...',
         'PanelImageTipOpen' => 'Clicca sull\'immagine per sceglierne un\'altra.',
         'PanelImageTipView' => 'Clicca sull\'immagine per visualizzare in grandezza naturale.',
         'PanelImageTipMenu' => 'Clicca tasto destro per piu\' opzioni.',
@@ -452,6 +463,7 @@ Andreas Troschka - <swsolutions@om.it.eu.org>',
         'PanelUnknown' => 'Sconosciuta',
         'PanelAdded' => 'Aggiungi data',
         'PanelRating' => 'Valutazione',
+        'PanelPressRating' => 'Press Rating',
         'PanelLocation' => 'Luogo',
         
         'PanelLending' => 'Prestiti',
@@ -522,6 +534,8 @@ Andreas Troschka - <swsolutions@om.it.eu.org>',
 
         'SearchTooltip' => 'Cerca nella collezione',
         'SearchTitle' => 'Cerca',
+        'SearchNoField' => 'No field have been selected for the search box.
+Add some of them in the Filters tab of the collection settings.',
         
         'QueryReplaceField' => 'Campo da sostituire',
         'QueryReplaceOld' => 'Nome corrente',
