@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -305,6 +305,13 @@ http://le-spektre.org',
 		'OptionsAskPlugins' => 'Pytaj (Wszystkie witryny)',
 		'OptionsPluginsMulti' => 'Wiele witryn',
 		'OptionsPluginsMultiAsk' => 'Pytaj (Wiele witryn)',
+        'OptionsPluginsMultiPerField' => 'Wiele witryn (per field)',
+        'OptionsPluginsMultiPerFieldWindowTitle' => 'Many sites per field order selection',
+        'OptionsPluginsMultiPerFieldDesc' => 'For each selected field we will return the first non empty information beginning from left',
+        'OptionsPluginsMultiPerFieldFirst' => 'First',
+        'OptionsPluginsMultiPerFieldLast' => 'Last',
+        'OptionsPluginsMultiPerFieldRemove' => 'Remove',
+        'OptionsPluginsMultiPerFieldClearSelected' => 'Empty selected field list',
 		'OptionsPluginsList' => 'Ustaw listę',
         'OptionsAskImport' => 'Wybierz pola do importu',
 		'OptionsProxy' => 'Używaj proxy',
@@ -426,6 +433,10 @@ http://le-spektre.org',
 
         'PanelSearchButton' => 'Pobierz informacje',
         'PanelSearchTip' => 'Szukaj w internecie informacji o tym tytule',
+        'PanelSearchContextChooseOne' => 'Choose a site ...',
+        'PanelSearchContextMultiSite' => 'Use "Many sites"',
+        'PanelSearchContextMultiSitePerField' => 'Use "Many sites per field"',
+        'PanelSearchContextOptions' => 'Change options ...',
         'PanelImageTipOpen' => 'Kliknij na zdjęciu aby wybrać inne.',
         'PanelImageTipView' => 'Kliknij na zdjęciu aby obejrzeć go w naturalnym rozmiarze.',
         'PanelImageTipMenu' => ' Prawy przycisk myszy - więcej opcji.',
@@ -446,6 +457,7 @@ http://le-spektre.org',
         'PanelUnknown' => 'Nieznany',
         'PanelAdded' => 'Dodano',
         'PanelRating' => 'Ocena',
+        'PanelPressRating' => 'Ocena prasy',
         'PanelLocation' => 'Lokalizacja',
 
         'PanelLending' => 'Pożyczanie',
@@ -516,6 +528,8 @@ http://le-spektre.org',
 
         'SearchTooltip' => 'Szukaj we wszystkich pozycjach',
         'SearchTitle' => 'Wyszukiwanie',
+        'SearchNoField' => 'Nie wybrano żadnego pola dla wyszukiwania.
+Dodaj kilka w zakładce Filtry okienka ustawień Zbioru.',
 
         'QueryReplaceField' => 'Zamień w polu:',
         'QueryReplaceOld' => 'Znajdź',
