@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -305,6 +305,13 @@ http://le-spektre.org',
         'OptionsAskPlugins' => 'Perguntar (Todos os sites)',
         'OptionsPluginsMulti' => 'Vários sites',
         'OptionsPluginsMultiAsk' => 'Perguntar (Alguns sites)',
+        'OptionsPluginsMultiPerField' => 'Vários sites (per field)',
+        'OptionsPluginsMultiPerFieldWindowTitle' => 'Many sites per field order selection',
+        'OptionsPluginsMultiPerFieldDesc' => 'For each selected field we will return the first non empty information beginning from left',
+        'OptionsPluginsMultiPerFieldFirst' => 'First',
+        'OptionsPluginsMultiPerFieldLast' => 'Last',
+        'OptionsPluginsMultiPerFieldRemove' => 'Remove',
+        'OptionsPluginsMultiPerFieldClearSelected' => 'Empty selected field list',
         'OptionsPluginsList' => 'Definir lista',
         'OptionsAskImport' => 'Escolher os campos a importar',
         'OptionsProxy' => 'Utilizar um proxy',
@@ -427,6 +434,10 @@ http://le-spektre.org',
 
         'PanelSearchButton' => 'Baixar informação',
         'PanelSearchTip' => 'Buscar informação na Internet para este nome',
+        'PanelSearchContextChooseOne' => 'Choose a site ...',
+        'PanelSearchContextMultiSite' => 'Use "Many sites"',
+        'PanelSearchContextMultiSitePerField' => 'Use "Many sites per field"',
+        'PanelSearchContextOptions' => 'Change options ...',
         'PanelImageTipOpen' => 'Click na imagem para selecionar outra',
         'PanelImageTipView' => 'Click na imagem para vê-la em tamanho real...',
         'PanelImageTipMenu' => 'Click com o botão direito para mais opções.',
@@ -447,6 +458,7 @@ http://le-spektre.org',
         'PanelUnknown' => 'Desconhecido',	
         'PanelAdded' => 'Adicionar data',
         'PanelRating' => 'Nota',
+        'PanelPressRating' => 'Press Rating',
         'PanelLocation' => 'Localidade',
 
         'PanelLending' => 'Emprestar',
@@ -517,6 +529,8 @@ http://le-spektre.org',
 
         'SearchTooltip' => 'Buscar em todos itens',	
         'SearchTitle' => 'Busca de itens',	
+        'SearchNoField' => 'No field have been selected for the search box.
+Add some of them in the Filters tab of the collection settings.',
                 
         'QueryReplaceField' => 'Campo para substituição',
         'QueryReplaceOld' => 'Nome atual',	
