@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -305,6 +305,13 @@ http://le-spektre.org',
 		'OptionsAskPlugins' => 'Întreabă (toate siturile)',
 		'OptionsPluginsMulti' => 'Multe situri',
 		'OptionsPluginsMultiAsk' => 'Întreabă (multe situri)',
+        'OptionsPluginsMultiPerField' => 'Multe situri (per field)',
+        'OptionsPluginsMultiPerFieldWindowTitle' => 'Many sites per field order selection',
+        'OptionsPluginsMultiPerFieldDesc' => 'For each selected field we will return the first non empty information beginning from left',
+        'OptionsPluginsMultiPerFieldFirst' => 'First',
+        'OptionsPluginsMultiPerFieldLast' => 'Last',
+        'OptionsPluginsMultiPerFieldRemove' => 'Remove',
+        'OptionsPluginsMultiPerFieldClearSelected' => 'Empty selected field list',
 		'OptionsPluginsList' => 'Setează lista',
         'OptionsAskImport' => 'Selectează câmpurile ce vor fi importate',
 		'OptionsProxy' => 'Foloseşte un proxy',
@@ -426,6 +433,10 @@ http://le-spektre.org',
 
         'PanelSearchButton' => 'Obţine informaţii',
         'PanelSearchTip' => 'Caută pe web informaţii despre acest titlu',
+        'PanelSearchContextChooseOne' => 'Choose a site ...',
+        'PanelSearchContextMultiSite' => 'Use "Many sites"',
+        'PanelSearchContextMultiSitePerField' => 'Use "Many sites per field"',
+        'PanelSearchContextOptions' => 'Change options ...',
         'PanelImageTipOpen' => 'Clic pe imagine pentru a selecta alta.',
         'PanelImageTipView' => 'Clic pe image pentru a o vedea la dimensiunea originală.',
         'PanelImageTipMenu' => ' Clic dreapta pentru mai multe opţiuni.',
@@ -446,6 +457,7 @@ http://le-spektre.org',
         'PanelUnknown' => 'Necunoscut',
         'PanelAdded' => 'Adaugă dată',
         'PanelRating' => 'Evaluare',
+        'PanelPressRating' => 'Press Rating',
         'PanelLocation' => 'Locaţie',
 
         'PanelLending' => 'Împrumuturi',
@@ -516,6 +528,8 @@ http://le-spektre.org',
 
         'SearchTooltip' => 'Caută toate elementele',
         'SearchTitle' => 'Căutare element',
+        'SearchNoField' => 'No field have been selected for the search box.
+Add some of them in the Filters tab of the collection settings.',
 
         'QueryReplaceField' => 'Câmp pentru înlocuire',
         'QueryReplaceOld' => 'Numele actual',
