@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -305,6 +305,13 @@ http://le-spektre.org',
 		'OptionsAskPlugins' => 'Спрашивать (Все сайты)',
 		'OptionsPluginsMulti' => 'Несколько сайтов',
 		'OptionsPluginsMultiAsk' => 'Спрашивать (Несколько сайтов)',
+        'OptionsPluginsMultiPerField' => 'Несколько сайтов (per field)',
+        'OptionsPluginsMultiPerFieldWindowTitle' => 'Many sites per field order selection',
+        'OptionsPluginsMultiPerFieldDesc' => 'For each selected field we will return the first non empty information beginning from left',
+        'OptionsPluginsMultiPerFieldFirst' => 'First',
+        'OptionsPluginsMultiPerFieldLast' => 'Last',
+        'OptionsPluginsMultiPerFieldRemove' => 'Remove',
+        'OptionsPluginsMultiPerFieldClearSelected' => 'Empty selected field list',
 		'OptionsPluginsList' => 'Задать список',
         'OptionsAskImport' => 'Выберите поля для импортирования',
 		'OptionsProxy' => 'Использовать прокси',
@@ -426,6 +433,10 @@ http://le-spektre.org',
 
         'PanelSearchButton' => 'Получить информацию',
         'PanelSearchTip' => 'Искать в Инетрнет информацию по этому заголовку',
+        'PanelSearchContextChooseOne' => 'Choose a site ...',
+        'PanelSearchContextMultiSite' => 'Use "Many sites"',
+        'PanelSearchContextMultiSitePerField' => 'Use "Many sites per field"',
+        'PanelSearchContextOptions' => 'Change options ...',
         'PanelImageTipOpen' => 'Щёлкните на картинке для выбора другой.',
         'PanelImageTipView' => 'Нажмите на картинке для просмотра её в оригинальном размере.',
         'PanelImageTipMenu' => ' Правый щелчок - еще опции',
@@ -446,6 +457,7 @@ http://le-spektre.org',
         'PanelUnknown' => 'Неизвестно',
         'PanelAdded' => 'Добавить дату',
         'PanelRating' => 'Рейтинг',
+        'PanelPressRating' => 'Press Rating',
         'PanelLocation' => 'Размещение',
 
         'PanelLending' => 'На руках',
@@ -516,6 +528,8 @@ http://le-spektre.org',
 
         'SearchTooltip' => 'Искать все фильмы',
         'SearchTitle' => 'Поиск фильмов',
+        'SearchNoField' => 'No field have been selected for the search box.
+Add some of them in the Filters tab of the collection settings.',
 
         'QueryReplaceField' => 'Поле для замены',
         'QueryReplaceOld' => 'Текущее имя',
