@@ -302,6 +302,13 @@ http://le-spektre.org',
 		'OptionsAskPlugins' => 'Pitaj me (Svi sajtovi)',
 		'OptionsPluginsMulti' => 'Neki sajtovi',
 		'OptionsPluginsMultiAsk' => 'Pitaj me (Neki sajtovi)',
+        'OptionsPluginsMultiPerField' => 'Neki sajtovi (per field)',
+        'OptionsPluginsMultiPerFieldWindowTitle' => 'Many sites per field order selection',
+        'OptionsPluginsMultiPerFieldDesc' => 'For each selected field we will return the first non empty information beginning from left',
+        'OptionsPluginsMultiPerFieldFirst' => 'First',
+        'OptionsPluginsMultiPerFieldLast' => 'Last',
+        'OptionsPluginsMultiPerFieldRemove' => 'Remove',
+        'OptionsPluginsMultiPerFieldClearSelected' => 'Empty selected field list',
 		'OptionsPluginsList' => 'Zadaj listu',
         'OptionsAskImport' => 'Odaberite polja za uvoženje',
 		'OptionsProxy' => 'Koristi proxy',
@@ -423,6 +430,10 @@ http://le-spektre.org',
 
         'PanelSearchButton' => 'Prikupi informacije',
         'PanelSearchTip' => 'Pretraži internet za informacije o ovom filmu',
+        'PanelSearchContextChooseOne' => 'Choose a site ...',
+        'PanelSearchContextMultiSite' => 'Use "Many sites"',
+        'PanelSearchContextMultiSitePerField' => 'Use "Many sites per field"',
+        'PanelSearchContextOptions' => 'Change options ...',
         'PanelImageTipOpen' => 'Klikni na sliku da odabereš neku drugu.',
         'PanelImageTipView' => 'Click on the picture to view it in real size.',
         'PanelImageTipMenu' => ' Desni klik za više opcija.',
@@ -443,6 +454,7 @@ http://le-spektre.org',
         'PanelUnknown' => 'Nepoznat',
         'PanelAdded' => 'Add date',
         'PanelRating' => 'Ocena',
+        'PanelPressRating' => 'Press Rating',
         'PanelLocation' => 'Lokacija',
 
         'PanelLending' => 'Pozajmljivanje',
@@ -513,6 +525,8 @@ http://le-spektre.org',
 
         'SearchTooltip' => 'Pretraži sve filmove',
         'SearchTitle' => 'Traži film',
+        'SearchNoField' => 'No field have been selected for the search box.
+Add some of them in the Filters tab of the collection settings.',
 
         'QueryReplaceField' => 'Field to replace',
         'QueryReplaceOld' => 'Trenutno ime',
