@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -301,6 +301,13 @@ http://le-spektre.org',
         'OptionsAskPlugins' => 'Fråga (Alla hemsidor)',
         'OptionsPluginsMulti' => 'Många hemsidor',
         'OptionsPluginsMultiAsk' => 'Fråga (Många hemsidor)',
+        'OptionsPluginsMultiPerField' => 'Många hemsidor (per field)',
+        'OptionsPluginsMultiPerFieldWindowTitle' => 'Many sites per field order selection',
+        'OptionsPluginsMultiPerFieldDesc' => 'For each selected field we will return the first non empty information beginning from left',
+        'OptionsPluginsMultiPerFieldFirst' => 'First',
+        'OptionsPluginsMultiPerFieldLast' => 'Last',
+        'OptionsPluginsMultiPerFieldRemove' => 'Remove',
+        'OptionsPluginsMultiPerFieldClearSelected' => 'Empty selected field list',
         'OptionsPluginsList' => 'Ställ in lista',
         'OptionsAskImport' => 'Välj fält som ska importeras',
         'OptionsProxy' => 'Använd en proxy',
@@ -424,6 +431,10 @@ http://le-spektre.org',
 
         'PanelSearchButton' => 'Hämta Information',
         'PanelSearchTip' => 'Sök webben för information om detta namn',
+        'PanelSearchContextChooseOne' => 'Choose a site ...',
+        'PanelSearchContextMultiSite' => 'Use "Many sites"',
+        'PanelSearchContextMultiSitePerField' => 'Use "Many sites per field"',
+        'PanelSearchContextOptions' => 'Change options ...',
         'PanelImageTipOpen' => 'Klicka på bilden för att välja en annan.',
         'PanelImageTipView' => 'Klicka på bilden för att visa den i dess riktiga storlek.',
         'PanelImageTipMenu' => ' Högerklicka för ytterligare alternativ.',
@@ -444,6 +455,7 @@ http://le-spektre.org',
         'PanelUnknown' => 'Okänd',
         'PanelAdded' => 'Lägg till datum',
         'PanelRating' => 'Betyg',
+        'PanelPressRating' => 'Klicka i betyg',
         'PanelLocation' => 'Lokalisering',
 
         'PanelLending' => 'Utlåning',
@@ -514,6 +526,8 @@ http://le-spektre.org',
 
         'SearchTooltip' => 'Sök alla artiklar',
         'SearchTitle' => 'Artikelsökning',
+        'SearchNoField' => 'Inget fält har markerats för sökrutan. Lägg till några av dem i fliken  
+Filter under samlingens inställningar.',
 
         'QueryReplaceField' => 'Fält att ersätta',
         'QueryReplaceOld' => 'Aktuellt värde',
