@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -309,6 +309,13 @@ http://le-spektre.org\'a aittir.',
 		'OptionsAskPlugins' => 'Sor (Tüm Siteler)',
 		'OptionsPluginsMulti' => 'Seçtiğim Siteler',
 		'OptionsPluginsMultiAsk' => 'Sor (Seçtiğim Siteler)',
+        'OptionsPluginsMultiPerField' => 'Seçtiğim Siteler (per field)',
+        'OptionsPluginsMultiPerFieldWindowTitle' => 'Many sites per field order selection',
+        'OptionsPluginsMultiPerFieldDesc' => 'For each selected field we will return the first non empty information beginning from left',
+        'OptionsPluginsMultiPerFieldFirst' => 'First',
+        'OptionsPluginsMultiPerFieldLast' => 'Last',
+        'OptionsPluginsMultiPerFieldRemove' => 'Remove',
+        'OptionsPluginsMultiPerFieldClearSelected' => 'Empty selected field list',
 		'OptionsPluginsList' => 'Listeyi oluşturun',
         'OptionsAskImport' => 'Alınacak bilgi alanları',
 		'OptionsProxy' => 'Proxy Kullan',
@@ -431,6 +438,10 @@ http://le-spektre.org\'a aittir.',
 
         'PanelSearchButton' => 'Bilgi Al',
         'PanelSearchTip' => 'Bu film için internetten bilgi al',
+        'PanelSearchContextChooseOne' => 'Choose a site ...',
+        'PanelSearchContextMultiSite' => 'Use "Many sites"',
+        'PanelSearchContextMultiSitePerField' => 'Use "Many sites per field"',
+        'PanelSearchContextOptions' => 'Change options ...',
         'PanelImageTipOpen' => 'Başka bir kapak resmi seçmek için tıklayınız.',
         'PanelImageTipView' => 'Click on the picture to view it in real size.',
         'PanelImageTipMenu' => ' Daha fazla seçenek için sağ tıklayınız.',
@@ -451,6 +462,7 @@ http://le-spektre.org\'a aittir.',
         'PanelUnknown' => 'Bilinmiyor',
         'PanelAdded' => 'Add date',
         'PanelRating' => 'Puan',
+        'PanelPressRating' => 'Press Rating',
         'PanelLocation' => 'Yer',
 
         'PanelLending' => 'Ödünç',
@@ -521,6 +533,8 @@ http://le-spektre.org\'a aittir.',
 
         'SearchTooltip' => 'Detaylı arama için tıklayınız',
         'SearchTitle' => 'Film Arama',
+        'SearchNoField' => 'No field have been selected for the search box.
+Add some of them in the Filters tab of the collection settings.',
 
         'QueryReplaceField' => 'Değiştirilecek alan',
         'QueryReplaceOld' => 'Şimdiki değer',
