@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -305,6 +305,13 @@ http://le-spektre.org',
 		'OptionsAskPlugins' => 'Питати (Всі сайти)',
 		'OptionsPluginsMulti' => 'Декілька сайтів',
 		'OptionsPluginsMultiAsk' => 'Питати (Декілька сайтів)',
+        'OptionsPluginsMultiPerField' => 'Декілька сайтів (per field)',
+        'OptionsPluginsMultiPerFieldWindowTitle' => 'Many sites per field order selection',
+        'OptionsPluginsMultiPerFieldDesc' => 'For each selected field we will return the first non empty information beginning from left',
+        'OptionsPluginsMultiPerFieldFirst' => 'First',
+        'OptionsPluginsMultiPerFieldLast' => 'Last',
+        'OptionsPluginsMultiPerFieldRemove' => 'Remove',
+        'OptionsPluginsMultiPerFieldClearSelected' => 'Empty selected field list',
 		'OptionsPluginsList' => 'Встановити список',
         'OptionsAskImport' => 'Виберіть поля для імпортування',
 		'OptionsProxy' => 'Використовувати проксі',
@@ -428,6 +435,10 @@ http://le-spektre.org',
 
         'PanelSearchButton' => 'Отримати інформацію',
         'PanelSearchTip' => 'Пошук в інтернеті інформації за цим іменем',
+        'PanelSearchContextChooseOne' => 'Choose a site ...',
+        'PanelSearchContextMultiSite' => 'Use "Many sites"',
+        'PanelSearchContextMultiSitePerField' => 'Use "Many sites per field"',
+        'PanelSearchContextOptions' => 'Change options ...',
         'PanelImageTipOpen' => 'Клацніть на зображенні для вибору іншого.',
         'PanelImageTipView' => 'Клацніть на зображенні для перегляду його справжнього розміру.',
         'PanelImageTipMenu' => ' Клацніть правою клавішею для інших варіантів.',
@@ -448,6 +459,7 @@ http://le-spektre.org',
         'PanelUnknown' => 'Невідомий',
         'PanelAdded' => 'Дата додавання',
         'PanelRating' => 'Оцінка',
+        'PanelPressRating' => 'Press Rating',
         'PanelLocation' => 'Місце',
 
         'PanelLending' => 'Позичка',
@@ -518,6 +530,8 @@ http://le-spektre.org',
 
         'SearchTooltip' => 'Шукати всі записи',
         'SearchTitle' => 'Пошук запису',
+        'SearchNoField' => 'No field have been selected for the search box.
+Add some of them in the Filters tab of the collection settings.',
 
         'QueryReplaceField' => 'Поля для заміни',
         'QueryReplaceOld' => 'Поточне значення',
