@@ -2,7 +2,7 @@ package GCMenu;
 
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -791,14 +791,14 @@ use strict;
         $self->{menuDisplay}->append(new Gtk2::SeparatorMenuItem);
         ############################
 
-        my $allItems = Gtk2::ImageMenuItem->new_with_mnemonic($parent->{lang}->{MenuViewAllItems});
-        $allItems->set_accel_path('<main>/Display/All');
+        my $viewAllItems = Gtk2::ImageMenuItem->new_with_mnemonic($parent->{lang}->{MenuViewAllItems});
+        $viewAllItems->set_accel_path('<main>/Display/All');
         my $refreshImage = Gtk2::Image->new_from_stock('gtk-refresh', 'menu');
-        $allItems->set_image($refreshImage);
-        $allItems->signal_connect('activate' , sub {
+        $viewAllItems->set_image($refreshImage);
+        $viewAllItems->signal_connect('activate' , sub {
                 $self->selectAll
         });
-        $self->{menuDisplay}->append($allItems);
+        $self->{menuDisplay}->append($viewAllItems);
 
         $self->{displayItem} = Gtk2::MenuItem->new_with_mnemonic($parent->{lang}->{MenuDisplay});
         $self->{displayItem}->set_submenu($self->{menuDisplay});
@@ -1085,7 +1085,7 @@ use strict;
             },
             'gtk-refresh' => {
                            tooltip => $self->{lang}->{ToolbarAllTooltip},
-                           callback => sub {$parent->allItems}
+                           callback => sub {$parent->viewAllItems}
             },
             'gtk-execute' => {
                            tooltip => $self->{lang}->{RandomTooltip},
@@ -1162,6 +1162,14 @@ use strict;
             if (/^gtk-/)
             {
                 $self->{controls}->{$_} = Gtk2::ToolButton->new_from_stock($_);
+                
+                # Set the important property on the add and save buttons
+                # (shows text in toolbar, depending on gtk settings)
+                if (/add|save/)
+                {
+                    $self->{controls}->{$_}->set_is_important(1);
+                }
+
                 $self->{controls}->{$_}->signal_connect('clicked' => $self->{stockIdToWidget}->{$_}->{callback});
                 $self->{parent}->{tooltips}->set_tip($self->{controls}->{$_}, $self->{stockIdToWidget}->{$_}->{tooltip}, '')
                     if $self->{stockIdToWidget}->{$_}->{tooltip};
@@ -1186,7 +1194,7 @@ use strict;
                         $self->{parent}->setGrouping($field);
                     });
                     my $groupVBox = new Gtk2::VBox(0,0);
-                    $groupVBox->set_border_width($GCUtils::halfMargin);
+                    $groupVBox->set_border_width(0);
                     $groupVBox->pack_start($self->{controls}->{groupOption}, 1, 0, 0);
                     $self->{parent}->{tooltips}->set_tip($self->{controls}->{groupOption}, $self->{lang}->{ToolbarGroupByTooltip}, '');
                     my $groupBox = new Gtk2::HBox(0,0);
@@ -1221,7 +1229,7 @@ use strict;
                     $self->{controls}->{layoutOption}->signal_connect('changed' => sub {
                         return if $self->{blocked};
                         $self->{model}->{preferences}->layout($self->{controls}->{layoutOption}->getValue);
-                        $self->{parent}->changePanel;
+                        $self->{parent}->changePanel(0, 0);
                     });
                     my $layoutBox = new Gtk2::VBox(0,0);
                     $layoutBox->set_border_width(0);
@@ -1230,6 +1238,31 @@ use strict;
                     $layoutItem->add($layoutBox);
                     $self->insert($layoutItem, -1);
                 }
+                elsif ($_ eq 'MenuSavedSearches')
+                {                    
+                    $self->{controls}->{userFiltersOption} = new GCMenuList;
+                    $self->{controls}->{userFiltersOption}->setTitle($self->{parent}->{lang}->{MenuSavedSearches});
+                    $self->{controls}->{userFiltersOption}->signal_connect('changed' => sub {
+                        return if $self->{blocked};
+                        my $idx = $self->{controls}->{userFiltersOption}->getValue;
+                        if ($idx == -1)
+                        {
+                            $self->{parent}->removeSearch(0);
+                        }
+                        else
+                        {
+                            $self->{parent}->removeSearch(1);
+                            $self->{parent}->setSearchWithTypes(%{$self->{userFilters}->[$idx]});
+                        }
+                    });
+                    
+                    my $filterBox = new Gtk2::VBox(0,0);
+                    $filterBox->set_border_width(0);
+                    $filterBox->pack_start($self->{controls}->{userFiltersOption}, 1, 0, 0);
+                    my $filterItem = new Gtk2::ToolItem;
+                    $filterItem->add($filterBox);
+                    $self->insert($filterItem, -1);
+                }
                 elsif ($_ eq 'ToolbarQuickSearch')
                 {
                     my $quickBox = new Gtk2::HBox(0,0);
@@ -1290,7 +1323,7 @@ use strict;
 
         my $logoPixbuf = Gtk2::Gdk::Pixbuf->new_from_file($self->{parent}->{logosDir}.'/button.png');
         my ($width, $height) = Gtk2::IconSize->lookup($self->get_icon_size);
-        $logoPixbuf = GCUtils::scaleMaxPixbuf($logoPixbuf, $width * 1.7, $height * 1.7);
+        $logoPixbuf = GCUtils::scaleMaxPixbuf($logoPixbuf, $width, $height);
         
         my $logo = Gtk2::Image->new_from_pixbuf($logoPixbuf);
         my $logoButton = new Gtk2::Button;
@@ -1308,6 +1341,22 @@ use strict;
         $self->insert($logoItem, -1);
     }
 
+    sub createUserFilters
+    {
+        my ($self, $model) = @_;
+        $self->{blocked} = 1;
+        if ($self->{controls}->{userFiltersOption})
+        {
+            $self->{userFilters} = $model->getUserFilters;
+            my $i = 0;
+            my @filters = map {{value => $i++,
+                               displayed => $model->getDisplayedText($_->{name})}}
+                             @{$self->{userFilters}};
+            $self->{controls}->{userFiltersOption}->setValues(\@filters);
+        }
+        $self->{blocked} = 0;
+    }
+
     sub setShowFieldsSelection
     {
         my ($self, $value) = @_;
@@ -1371,6 +1420,8 @@ use strict;
             $self->{controls}->{layoutOption}->setValues(\@panels);
         }
 
+        $self->createUserFilters($model);
+
         # Hide tonight button if needed
         if ($self->{controls}->{'gtk-execute'})
         {
@@ -1492,6 +1543,7 @@ use strict;
             'gtk-dnd', 'gtk-delete', 'gtk-find-and-replace',
             'gtk-help',
             'ToolbarGroupBy', 'ToolbarQuickSearch', 'OptionsView', 'OptionsLayout',
+            'MenuSavedSearches'
         ], 1);
     }
     
