@@ -2,7 +2,7 @@ package GCModel;
 
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -79,9 +79,9 @@ our $linkNameSeparator = '##';
         $self->{defaultImage} = $ENV{GCS_SHARE_DIR}.'/logos/'.$self->{options}->{defaults}->{image};
         $self->{userFiltersDir} = $ENV{GCS_DATA_HOME}.'/Filters/'.$self->getName;
         $self->{random} = $self->{collection}->{random}->{filter};
-        my $langName = $self->{parent}->{options}->lang;
         if (exists $self->{collection}->{lang})
         {
+            my $langName = $self->{parent}->{options}->lang;
             my $lang = $self->{collection}->{lang};
             my %tmpLang;
             # The string should be splitted to avoid considering some scopped variables
@@ -426,8 +426,13 @@ our $linkNameSeparator = '##';
                 my $xs = XML::Simple->new;
                 my $filter = $xs->XMLin($filterFile,
                                         ForceArray => ['info', 'filter']);
-                push @filters, $filter;
                 $self->{isUserFilterSaved}->{$filter->{name}} = 1;
+                foreach my $info (@{$filter->{info}})
+                {
+                    $info->{filter}->[1] = 0 if ref $info->{filter}->[1] eq 'HASH';
+                    $info->{filter}->[2] = undef if ref $info->{filter}->[2] eq 'HASH';
+                }
+                push @filters, $filter;
             }
             $self->{userFilters} = \@filters;
         }
@@ -572,7 +577,12 @@ our $linkNameSeparator = '##';
         return if ! scalar @{$model->{fieldsNames}};
 
         # Groups part
-        push @{$self->{groups}}, @{$model->{groups}};
+        my %groups = map { $_->{id} => 1 } @{$self->{groups}};
+        foreach (@{$model->{groups}})
+        {
+            push @{$self->{groups}}, $_
+                if !exists $groups{$_->{id}};
+        }
 
         # initFields part
         foreach(@{$model->{fieldsNames}})
@@ -1195,6 +1205,7 @@ our $linkNameSeparator = '##';
         {
             return $self->getDisplayedText($_->{displayed}) if $_->{content} eq $value;
         }
+        return "";
     }
 
     sub getDisplayedItems
@@ -1431,6 +1442,79 @@ our $linkNameSeparator = '##';
         $self->saveUserFilters;
     }
 }
+{
+    package GCModelsChanges;
+
+    use File::Basename;
+    use GCUtils 'glob';
+    my %versionwithchanges;
+
+    sub new
+    {
+        my ($proto, $parent,$model) = @_;
+        my $class = ref($proto) || $proto;
+        my $self  = {
+            parent => $parent,
+            cache => {},
+            lang => $parent->{lang},
+            persoDirectory => $ENV{GCS_DATA_HOME}.'/GCModels/',
+            defaultDirectory => $ENV{GCS_LIB_DIR}.'/GCModels/',
+            modelsSuffix => $GCModel::modelsSuffix,
+            model => $model
+        };
+
+        $self->{modelsDirectories} = [$self->{persoDirectory}, $self->{defaultDirectory}],
+
+        bless $self, $class;
+        $self->loadChangedVersionNumber;
+        return $self;
+    }
+
+    sub applyChanges
+    {
+        my($self,$data,$fileversion,$gcstarversion)=@_;
+        my @fileVersionSplited=split /\./,$fileversion;
+        my @gcstarVersionSplited=split /\./,$gcstarversion;
+        my $modelChanges=$versionwithchanges{$self->{model}};
+        sub compare
+        {
+            my ($arr1,$arr2,$i)=@_;
+            return 0 if ($i>$#$arr1 && $i>$#$arr2);
+            return -(0>$arr2->[$i])if ($i>$#$arr1);
+            return (0>$arr1->[$i]) if ($i>$#$arr2);
+            
+            return -1 if $arr1->[$i]<$arr2->[$i];
+            return 1 if $arr1->[$i]>$arr2->[$i];
+            return compare($arr1,$arr2,$i+1);
+        }
+        # Warning : we assume that versions are sorted ascend
+        for my $vers(keys %$modelChanges)
+        {
+            my @versSplited=split /\./,$vers;
+            my $isConcerned=(compare \@fileVersionSplited,\@versSplited)<0;
+            $isConcerned&=(compare \@versSplited,\@gcstarVersionSplited)<=0;
+            foreach my $item(@$data)
+            {
+                $modelChanges->{$vers}($item);
+            }
+            
+        }
+    }
+
+    sub loadChangedVersionNumber
+    {
+        my($self)=@_;
+        # TODO load from files
+        
+        # Here is, for each model, a hash "versionNumber"=>sub
+        # example : "1.4.4"=>sub {
+        #                        $_[0]->{title}=lc $_[0]->{title};
+        #                    };
+        $versionwithchanges{GCfilms}={
+            };
+        # TODO sort version changes asc
+    }
+}
 
 {
     package GCModelsCache;
@@ -1961,12 +2045,13 @@ use Gtk2;
         {
             if ($self->{personal})
             {
-                push @$groups, {id => 'Main', label => 'OptionsMain',
+                push @$groups, {id => $self->{parent}->{lang}->{OptionsMain}, label => 'OptionsMain',
                                 displayed => $self->{parent}->{lang}->{OptionsMain}};
             }
             else
             {
-                push @$groups, {id => 'User', label => 'PanelUser',
+                push @$groups, {id => $self->{parent}->{lang}->{PanelUser},
+                                label => 'PanelUser',
                                 displayed => $self->{parent}->{lang}->{PanelUser}};
             }
         }
@@ -1974,7 +2059,7 @@ use Gtk2;
         foreach (@{$self->{fields}})
         {
             $_->{group} = $defaultGroup if ! $_->{group};
-        }        
+        }
         return $groups;
     }
 
@@ -2420,11 +2505,11 @@ use Gtk2;
         $self->{scrollPanelFields}->add($self->{fieldsList});
         $vboxFieldsList->pack_start($self->{scrollPanelFields},1,1,0);
         my $hboxFieldsActions = new Gtk2::HBox(0,0);
-        my $addButton = Gtk2::Button->new_from_stock('gtk-add');
+        my $addButton = GCButton->newFromStock('gtk-add', 0);
         $addButton->signal_connect('clicked' => sub {
                 $self->addField;
             });
-        $self->{removeButton} = Gtk2::Button->new_from_stock('gtk-remove');
+        $self->{removeButton} = GCButton->newFromStock('gtk-remove', 0);
         $self->{removeButton}->signal_connect('clicked' => sub {
                 $self->removeCurrent;
             });
@@ -2433,11 +2518,11 @@ use Gtk2;
         $vboxFieldsList->pack_start($hboxFieldsActions,0,0,$GCUtils::halfMargin);
 
         my $vboxMove = new Gtk2::VBox(0,0);
-        $self->{toUp} =GCButton->newFromStock('gtk-go-up', 1);
+        $self->{toUp} =GCButton->newFromStock('gtk-go-up', 0);
         $self->{toUp}->signal_connect('clicked' => sub {
             $self->moveDownUp(-1);
         });
-        $self->{toDown} =GCButton->newFromStock('gtk-go-down', 1);
+        $self->{toDown} =GCButton->newFromStock('gtk-go-down', 0);
         $self->{toDown}->signal_connect('clicked' => sub {
             $self->moveDownUp(1);
         });
