@@ -2,7 +2,7 @@ package GCOptions;
 
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -156,8 +156,9 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
                 from             => "",
                 subject          => "GCstar email",
                 smtp             => "",
-                template         => "Hello %1,<br/><br/>You borrowed me %2 since %3. I\'d like to get it back shortly.",
+                template         => "Hello %1,<br/><br/>You have borrowed my %2 since %3. I\'d like to get it back shortly.",
                 history          => "none|none|none|none|none",
+                historysize      => "5",
                 useRelativePaths => 0,
                 useTitleForPics  => 1,
                 expandersMode    => 'cut',
@@ -652,6 +653,8 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
                   ($currentBgPicture != $self->{options}->listBgPicture)
                   ||
                   ($currentUseOverlays != $self->{options}->useOverlays)
+                  ||
+                  ($currentGroupBy ne $self->{model}->{preferences}->groupBy)
                 )
              )
              ||
@@ -787,15 +790,17 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
     sub show
     {
         my $self = shift;
+        my $tabToShow= shift;
 
         $self->initValues;
         $self->show_all if !$self->{allShown};
-
+        $self->{optionstabs}->set_current_page ($tabToShow) if $tabToShow;
         $self->activateInternetOptions(! $self->{model}->isPersonal);
 
         $self->{hboxSMTP}->hide if $self->{options}->mailer ne 'SMTP';
         $self->{pluginList}->hide
             if (($self->{model}->{preferences}->plugin ne 'multi')
+             && ($self->{model}->{preferences}->plugin ne 'multiperfield')
              && ($self->{model}->{preferences}->plugin ne 'multiask'));
 
         while (1)
@@ -850,6 +855,7 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
                             {value => 'ask', displayed => $self->{parent}->{lang}->{OptionsAskPlugins}},
                             {value => 'multiask', displayed => $self->{parent}->{lang}->{OptionsPluginsMultiAsk}},
                             {value => 'multi', displayed => $self->{parent}->{lang}->{OptionsPluginsMulti}},
+                            {value => 'multiperfield', displayed => $self->{parent}->{lang}->{OptionsPluginsMultiPerField}},
                           );
         $self->{pluginOption}->setValues(\@plugins);
 
@@ -1176,11 +1182,14 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
         $self->{pluginOption} = new GCMenuList;
         $self->{pluginList} = new Gtk2::Button($parent->{lang}->{OptionsPluginsList});
         $self->{pluginList}->signal_connect('clicked' => sub {
-            $parent->selectMultiPluginsList;
+            $parent->getDialog('MultiSite')->show if (($self->{pluginOption}->getValue eq 'multi') 
+             || ($self->{pluginOption}->getValue eq 'multiask'));
+            $parent->getDialog('MultiSitePerField')->show if (($self->{pluginOption}->getValue eq 'multiperfield'));
         });
         $self->{pluginOption}->signal_connect('changed' => sub {
             if (($self->{pluginOption}->getValue eq 'multi') 
-             || ($self->{pluginOption}->getValue eq 'multiask'))
+             || ($self->{pluginOption}->getValue eq 'multiask') 
+             || ($self->{pluginOption}->getValue eq 'multiperfield'))
             {
                 $self->{pluginList}->show;
             }
@@ -1344,6 +1353,10 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
 
         $vboxConvenience->pack_start($tableFeature,0,0,0);
 
+        ###################
+        # Tab Gesture Stuff
+        ###################
+
         my $tabs = Gtk2::Notebook->new();
         $tabs->set_name('GCOptionsTabs');
         $tabs->set_tab_pos('left');
@@ -1381,13 +1394,13 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
         $tabs->set_tab_label_packing ($vboxConvenience, 1, 0, 'start');
 
         $self->vbox->pack_start($tabs, 1, 1, 0);
-
+        $self->{optionstabs}=$tabs;
         $self->{expert} = new Gtk2::CheckButton($parent->{lang}->{OptionsExpertMode});
         $self->{expert}->signal_connect('toggled' => sub {
             $self->show_all;
         });
         $self->{expert}->set_border_width($GCUtils::margin);
-        $self->vbox->pack_start($self->{expert}, 1, 1, 0);
+        $self->vbox->pack_start($self->{expert}, 0, 1, 0);
 
         $self->{lang} = $parent->{lang};
 
@@ -1414,6 +1427,7 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
         $self->activateColors(! $self->{parent}->{listBgPicture});
         $self->{mlbg} = $self->{parent}->{mlbg};
         $self->{mlfg} = $self->{parent}->{mlfg};
+        $self->{groupByOption}->setValue($self->{parent}->{groupBy});
     }
     
     sub saveValues
@@ -1428,6 +1442,7 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
         $self->{parent}->{mlfg} = $self->{mlfg};
         $self->{parent}->{listBgPicture} = (($self->{listBgPicture}->get_active) ? 1 : 0);
         $self->{parent}->{useOverlays} = (($self->{useOverlays}->get_active) ? 1 : 0);
+        $self->{parent}->{groupBy} =  $self->{groupByOption}->getValue;
     }
     
     sub show
@@ -1482,7 +1497,7 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
                                        $parent->{lang}->{ImagesOptionsTitle},
                                       );
 
-        my $tableLayout = new Gtk2::Table(11,4);
+        my $tableLayout = new Gtk2::Table(12,4);
         $tableLayout->set_row_spacings($GCUtils::halfMargin);
         $tableLayout->set_col_spacings($GCUtils::margin);
         $tableLayout->set_border_width($GCUtils::margin);
@@ -1538,6 +1553,10 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
         $parent->{tooltips}->set_tip($self->{buttonFg},
                                      $parent->{lang}->{ImagesOptionsFgTooltip});
 
+        $self->{groupItems} = new GCLabel($parent->{lang}->{DetailedOptionsGroupItems});
+        $self->{groupByOption} = new GCFieldSelector(0, undef, 1);
+        $self->{groupByOption}->setModel($parent->{parent}->{model});
+
         my $imagesDisplayGroupLabel = new GCHeaderLabel($parent->{lang}->{OptionsImagesDisplayGroup});
         $tableLayout->attach($imagesDisplayGroupLabel, 0, 4, 0, 1, 'fill', 'fill', 0, 0);
         $tableLayout->attach($self->{resizeImgList}, 2, 4, 1, 2, 'fill', 'fill', 0, 0);
@@ -1545,17 +1564,19 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
         $tableLayout->attach($self->{columns}, 3, 4, 2, 3, 'fill', 'fill', 0, 0);
         $tableLayout->attach($imgSizeLabel, 2, 3, 3, 4, 'fill', 'fill', 0, 0);
         $tableLayout->attach($self->{imgSizeOption}, 3, 4, 3, 4, 'fill', 'fill', 0, 0);
+        $tableLayout->attach($self->{groupItems}, 2, 3, 4, 5, 'fill', 'fill', 0, 0);
+        $tableLayout->attach($self->{groupByOption}, 3, 4, 4, 5, 'fill', 'fill', 0, 0);
 
         my $imagesStyleGroupLabel = new GCHeaderLabel($parent->{lang}->{OptionsImagesStyleGroup});
-        $tableLayout->attach($imagesStyleGroupLabel, 0, 4, 5, 6, 'fill', 'fill', 0, 0);
-        $tableLayout->attach($self->{useOverlays}, 2, 4, 6, 7, 'fill', 'fill', 0, 0);
-        $tableLayout->attach($self->{listBgPicture}, 2, 4, 7, 8, 'fill', 'fill', 0, 0);
-        $tableLayout->attach($self->{labelStyle}, 2, 3, 8, 9, 'fill', 'fill', 0, 0);
-        $tableLayout->attach($self->{optionStyle}, 3, 4, 8, 9, 'fill', 'fill', 0, 0);
-        $tableLayout->attach($self->{labelBg}, 2, 3, 9, 10, 'fill', 'fill', 0, 0);
-        $tableLayout->attach($self->{buttonBg}, 3, 4, 9, 10, 'fill', 'fill', 0, 0);
-        $tableLayout->attach($self->{labelFg}, 2, 3, 10, 11, 'fill', 'fill', 0, 0);
-        $tableLayout->attach($self->{buttonFg}, 3, 4, 10, 11, 'fill', 'fill', 0, 0);
+        $tableLayout->attach($imagesStyleGroupLabel, 0, 4, 6, 7, 'fill', 'fill', 0, 0);
+        $tableLayout->attach($self->{useOverlays}, 2, 4, 7, 8, 'fill', 'fill', 0, 0);
+        $tableLayout->attach($self->{listBgPicture}, 2, 4, 8, 9, 'fill', 'fill', 0, 0);
+        $tableLayout->attach($self->{labelStyle}, 2, 3, 9, 10, 'fill', 'fill', 0, 0);
+        $tableLayout->attach($self->{optionStyle}, 3, 4, 9, 10, 'fill', 'fill', 0, 0);
+        $tableLayout->attach($self->{labelBg}, 2, 3, 10, 11, 'fill', 'fill', 0, 0);
+        $tableLayout->attach($self->{buttonBg}, 3, 4, 10, 11, 'fill', 'fill', 0, 0);
+        $tableLayout->attach($self->{labelFg}, 2, 3, 11, 12, 'fill', 'fill', 0, 0);
+        $tableLayout->attach($self->{buttonFg}, 3, 4, 11, 12, 'fill', 'fill', 0, 0);
 
         $tableLayout->show_all;
 
@@ -1792,7 +1813,7 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
         $self->{parent} = $parent;
 
         $self->{lang} = $parent->{lang};
-        
+        $self->set_default_size(-1,480);
         return $self;
     }
     
@@ -1891,7 +1912,12 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
             $frame->set_label_align(1.0, 0.0);
             my $vbox = new Gtk2::VBox(0,0);
             $self->initBox($vbox, $_->{items});
-            $frame->add($vbox);
+            my $scroll = new Gtk2::ScrolledWindow;
+            $scroll->set_policy ('automatic', 'automatic');
+            $frame->add($scroll);
+            $scroll->add_with_viewport($vbox);
+            $scroll->set_shadow_type('none');
+            $scroll->child->set_shadow_type('none');
             $self->{tabs}->append_page($frame, $_->{title});
         }
 		
