@@ -2,7 +2,7 @@ package GCPanel;
 
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -70,7 +70,7 @@ use strict;
         $self->{viewAllVBox}->pack_start($self->{viewAll},0,0,0);
         $self->{viewAllBox}->add($self->{viewAllVBox});
         $self->{viewAllButton}->signal_connect('clicked' => sub {
-            $self->{parent}->allItems;
+            $self->{parent}->viewAllItems;
         });
 
         $self->{margin} = $GCUtils::margin;
@@ -394,7 +394,7 @@ use strict;
         {
             $self->$name($self->formatLabel($label->{format}));
             # We store here the value so it could be used by caller if needed
-            # The user is GCData::updateCurrent
+            # The user is GCData::updateSelectedItemInfoFromPanel
             $info->{$name} = $self->$name if defined $info;
         }
     }
@@ -1067,13 +1067,24 @@ use strict;
         push @{$self->{toDestroy}}, $self->{mailButton};
 
         $self->{searchButton} = GCButton->newFromStock('gtk-jump-to');
-        $self->{searchButton}->signal_connect('activate' => sub {
+        $self->{searchButton}->signal_connect('clicked' => sub {
             $self->searchItem;
         });
-        $self->{searchButton}->signal_connect('button_release_event' => sub {
-            my ($widget, $event) = @_;
-            $self->searchItem($event->button == 3);
-        });
+        my @subMenuSearch;
+        $subMenuSearch[0]=Gtk2::ImageMenuItem->new_with_mnemonic($self->{parent}->{lang}->{PanelSearchContextChooseOne});
+        $subMenuSearch[0]->signal_connect("activate" , sub {$self->searchItem('ask')});
+        
+        $subMenuSearch[1]=Gtk2::ImageMenuItem->new_with_mnemonic($self->{parent}->{lang}->{PanelSearchContextMultiSite});
+        $subMenuSearch[1]->signal_connect("activate" ,sub {$self->searchItem('multi')});
+        
+        $subMenuSearch[2]=Gtk2::ImageMenuItem->new_with_mnemonic($self->{parent}->{lang}->{PanelSearchContextMultiSitePerField});
+        $subMenuSearch[2]->signal_connect("activate" ,sub {$self->searchItem('multiperfield')});
+        
+        $subMenuSearch[3]=Gtk2::ImageMenuItem->new_with_mnemonic($self->{parent}->{lang}->{PanelSearchContextOptions});
+        $subMenuSearch[3]->signal_connect("activate" ,sub {$self->{parent}->options(0,3)});
+        
+        $self->{searchButton}->setContextMenu(\@subMenuSearch);
+        $self->{searchButton}->enableContextMenu;
         $self->{tooltips}->set_tip($self->{searchButton}, $self->{parent}->{lang}->{PanelSearchTip}, '');
         push @{$self->{toDestroy}}, $self->{searchButton};
         
@@ -1125,10 +1136,10 @@ use strict;
 
     sub searchItem
     {
-        my ($self, $forceSelection) = @_;
+        my ($self, $pluginType) = @_;
 
         #$self->{parent}->searchItemForPanel($self->{$self->{model}->{commonFields}->{title}}->getValue, $self);
-        $self->{parent}->searchItemForPanel($self, $forceSelection);
+        $self->{parent}->searchItemForPanel($self, $pluginType);
 
         $self->showMe;
     }
@@ -1197,8 +1208,11 @@ use strict;
         $locked = 1 if $self->{parent}->{items}->getLock;
         return if $self->{locked} == $locked;
         $self->{locked} = $locked;
+        my $info;
         foreach (@{$self->{parent}->{model}->{fieldsNames}})
         {
+            $info = $self->{model}->{fieldsInfo}->{$_};
+            next if $info->{type} eq 'button';
             $self->{$_}->lock($locked) if ($self->{$_});
         }
 
@@ -1312,12 +1326,16 @@ use strict;
             my $number;
             my $readonly = 0;
             my $withHistory = 1;
+            my @types;
             my @labels;
             $withHistory = 0
                 if (exists $info->{history}) && ($info->{history} eq 'false');
             $readonly = 1
                 if $info->{value} eq $self->{model}->{commonFields}->{borrower}->{history};
             $number = GCUtils::listNameToNumber($info->{type});
+            @types=split / / ,$info->{subtypes} if $info->{subtypes};
+            my $typesRef = \@types;
+            undef $typesRef if scalar(@types)!=$number;
             if ($number == 1)
             {
                 @labels = ($self->{model}->getDisplayedText($info->{label}));
@@ -1329,7 +1347,7 @@ use strict;
                     push @labels, $self->{model}->getDisplayedText($info->{'label'.$i});
                 }
             }
-            $widget = new GCMultipleList($self, $number, \@labels, $withHistory, $readonly);
+            $widget = new GCMultipleList($self, $number, \@labels, $withHistory, $readonly,0,$typesRef);
         }
 		elsif ($info->{type} eq 'checked text')
 		{
@@ -1429,7 +1447,9 @@ use strict;
     sub getValues
     {
         my ($self, $field) = @_;
-        return $self->{$field}->getValues;
+        return $self->{$field}->getValues
+            if exists $self->{$field};
+        return [];
     }
     
     sub AUTOLOAD
