@@ -3,7 +3,7 @@
     
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -145,6 +145,11 @@ sub loadAllPlugins
                     $plugin->{nextUrl} = $info->{nextUrl};
 
                     $plugin->load;
+                    
+                    # Remove the user agent part of the data, otherwise the Storable lib complains
+                    # about not being able to store the sub's stored in it.
+                    undef($plugin->{ua});
+                    
                     local $Storable::forgive_me = 1;
                     store_fd $plugin, $self->{data};
                 }
@@ -275,11 +280,13 @@ sub loadAllPlugins
                $self->{query}->setValue($query);
                $self->{queries} = $queries;
                $self->{fieldsList}->signal_connect('changed' => sub {
-                   $self->{query}->setValue(
-                       $self->{queries}->{
-                           $self->{fieldsList}->getValue
-                       }
-                   );
+                   # Only change the search query if it's not empty, otherwise keep existing value 
+                   if ($self->{queries}->{$self->{fieldsList}->getValue})
+                   {    
+                       $self->{query}->setValue(
+                           $self->{queries}->{$self->{fieldsList}->getValue}
+                       );
+                   }
                });
                #$self->{fieldsList}->setDefaultValues(shift);
                #$self->{searchField} = shift;
@@ -609,6 +616,487 @@ sub loadAllPlugins
         }
     }
     
+    {
+        #Class that is used to let user select
+        #plugin order he wants to use for each imported fields
+        package GCMultiSitePerFieldDialog;
+        use base 'GCModalDialog';
+        
+        our $removeValue = 'GCListRemove';
+        my $startColMenus=1;
+        
+        my $pluginListOrderPerField;
+        my $fieldsToFetch;
+        my $remainingSourcesOrderPerField;
+
+        sub show
+        {
+            my $self = shift;
+    
+            $self->SUPER::show();
+            $self->show_all;
+            
+            my $response = $self->run;
+            $self->hide;
+            $self->cleanListOrder;
+            $self->savePrefOrderListFromForm if ($response eq 'ok');
+            $self->loadPrefOrderListInForm if ($response ne 'ok');
+            return ($response eq 'ok');
+        }
+
+        sub getSourcesListMenu
+        {
+            my ($self,$withRemoveItem) = @_;
+            return new GCMenuList($self->{sourcesList}) if !$withRemoveItem;
+            return new GCMenuList($self->{sourcesListWithRemoveItem}) if $withRemoveItem;
+        }
+
+        sub createRowForField
+        {
+            my ($self, $field, $row, $mandatory) = @_;
+            my $fieldsInfo = $self->{parent}->{model}->{fieldsInfo};
+            $self->{fields}->{$field}->{row}=$row;
+            $self->{fields}->{$field}->{'Cb'} = new GCCheckBox($self->{parent}->{model}->getDisplayedText($fieldsInfo->{$field}->{label}));
+            if ($mandatory)
+            {
+                $self->{fields}->{$field}->{'Cb'}->lock(1);
+                $self->{fields}->{$field}->{'Cb'}->setValue(1);
+                $self->{fields}->{$field}->{'Cb'}->{mandatory} = 1;
+            }
+            $self->{table}->attach($self->{fields}->{$field}->{'Cb'}, 0, 1, $row, $row + 1, 'fill', ['fill', 'expand'], 0, 0);
+            
+            my $curNbSite=0;
+            $self->{fields}->{$field}->{'SiteListMenus'}=[];
+            $self->{fields}->{$field}->{'SiteListAddLast'}=new Gtk2::Button("+");
+            $self->{fields}->{$field}->{'SiteListAddLast'}->signal_connect('clicked' => sub {
+                    $self->addSiteListToField($field,-1);
+            });
+            $self->{fields}->{$field}->{'SiteListAddLast'}->set_no_show_all(1);
+            
+            $self->{fields}->{$field}->{'SiteListAddFirst'}=new Gtk2::Button("+");
+            $self->{fields}->{$field}->{'SiteListAddFirst'}->signal_connect('clicked' => sub {
+                    $self->addSiteListToField($field,0);
+            });
+            $self->{table}->attach($self->{fields}->{$field}->{'SiteListAddFirst'}, $startColMenus, 1+$startColMenus, $row, $row + 1, 'fill', 'fill', 0, 0);
+            
+            my $Align = new Gtk2::Alignment(0.0, 0.5, 0.0, 0.0);
+            my $Hbox = new Gtk2::HBox();
+            $self->{fields}->{$field}->{'Hbox'}=$Hbox;
+            $Hbox->pack_start($self->{fields}->{$field}->{'SiteListAddLast'},1,0,0);
+            $Align->add($Hbox);
+            $self->{table}->attach($Align, 1+$startColMenus, 2+$startColMenus, $row, $row + 1, ['expand','fill'], 'fill', 0, 0);
+        }
+
+        sub addSiteListToField
+        {
+            my ($self, $field, $position,$value) = @_;
+            my $curListMenus=$self->{fields}->{$field}->{'SiteListMenus'};
+            my $curNbSite=scalar @{$curListMenus};
+            $curNbSite++;
+            $position=$curNbSite-1 if $position==-1;
+            my $Hbox = $self->{fields}->{$field}-> {'Hbox'};
+            my $newSiteList = $self->getSourcesListMenu(1);
+            $value=$self->{bottomline}->{siteAddToAll}->getValue(1) if !$value;
+            $newSiteList->setValue($value);
+            $newSiteList->{orderInList}=$position;
+            $newSiteList->signal_connect('changed' => sub {
+                if ($newSiteList->getValue eq $removeValue)
+                {
+                    $self->removeSiteListFromField($field, $newSiteList->{orderInList})
+                }
+            });
+            #insert the new siteList
+            splice @{$curListMenus}, $position, 0, $newSiteList;
+            $Hbox->pack_start($newSiteList,0,0,0);
+            $Hbox->reorder_child($newSiteList,$position);
+            $newSiteList->show;
+            #move other siteList on this row to the right
+            for (my $idx=$position;$idx<$curNbSite;$idx++)
+            {
+                $curListMenus->[$idx]->{orderInList}=$idx;
+            }
+            if($curNbSite==1)
+            {
+                $self->{fields}->{$field}->{'SiteListAddLast'}->set_no_show_all(0);
+                $self->{fields}->{$field}->{'SiteListAddLast'}->show;
+            }
+       }
+
+        sub removeSiteListFromField
+        {
+            my ($self, $field, $position) = @_;
+            my $curListMenus=$self->{fields}->{$field}->{'SiteListMenus'};
+            my $curNbSite=scalar @{$curListMenus};
+            $position=$curNbSite-1 if $position==-1;
+            my $oldSiteList=splice @{$curListMenus}, $position, 1;
+            my $Hbox = $self->{fields}->{$field}-> {'Hbox'};
+            $Hbox->remove($oldSiteList);
+            $curNbSite--;
+            #move other siteList on this row to the left
+            for (my $idx=$position;$idx<$curNbSite;$idx++)
+            {
+                $curListMenus->[$idx]->{orderInList}=$idx;
+            }
+            if($curNbSite==0)
+            {
+                $self->{fields}->{$field}->{'SiteListAddLast'}->set_no_show_all(1);
+                $self->{fields}->{$field}->{'SiteListAddLast'}->hide;
+            }
+        }
+
+        sub removeAllSourceListFromField
+        {
+            my ($self, $field) = @_;
+            my $curNbSite=scalar @{$self->{fields}->{$field}->{'SiteListMenus'}};
+            for (my $i=0;$i<$curNbSite;$i++)
+            {
+                $self->removeSiteListFromField($field,-1);
+            }
+        }
+
+        sub new
+        {
+            my ($proto, $parent, $model,$usePlugins,$otherSources) = @_;
+            my $class = ref($proto) || $proto;
+            my $self  = $class->SUPER::new($parent,
+                                           $parent->{lang}->{OptionsPluginsMultiPerFieldWindowTitle}
+                                          );
+    
+            bless ($self, $class);
+            $model=$parent->{model} if !$model;
+            $self->{parent} = $parent;
+     
+            $self->set_modal(1);
+            $self->set_position('center');
+            $self->set_default_size(1,500);
+            my $layoutHbox = new Gtk2::HBox(0,0);
+            $self->{layoutVBox} = new Gtk2::VBox(0,0);
+            $self->vbox->pack_start($layoutHbox, 1,1,0);
+            $layoutHbox->pack_start($self->{layoutVBox},0,0,$GCUtils::margin);
+    
+            $self->{table} = new Gtk2::Table(1, 3, 0);
+            $self->{table}->set_row_spacings($GCUtils::halfMargin);
+            $self->{table}->set_col_spacings($GCUtils::margin);
+            $self->{table}->set_border_width($GCUtils::margin);
+    
+            $self->{scrollPanelList} = new Gtk2::ScrolledWindow;
+            $self->{scrollPanelList}->set_policy ('never', 'automatic');
+            $self->{scrollPanelList}->set_shadow_type('none');
+            $self->{scrollPanelList}->add_with_viewport($self->{table});
+    
+            $self->{descriptionLabel}=new GCLabel($parent->{lang}->{OptionsPluginsMultiPerFieldDesc});
+            $self->{layoutVBox}->pack_start($self->{descriptionLabel},0,0,$GCUtils::margin);
+    
+            $self->{layoutVBox}->pack_start($self->{scrollPanelList},1,1,$GCUtils::margin);
+    
+            $self->setModel($model);
+            
+            $self->setSourceList($usePlugins,$otherSources);
+            $self->initForm;
+            if (! $self->{model}->{preferences}->exists('multisiteperfield'))
+            {
+                $self->savePrefOrderListFromForm;
+            }
+            else
+            {
+                $self->loadPrefOrderListInForm;
+            }
+            return $self;
+        }
+
+        sub setSourceList
+        {
+            my ($self,$usePlugins,$otherSourcesList) = @_;
+            $#{$self->{sourcesList}}=-1;
+            $#{$self->{sourcesListWithRemoveItem}}=-1;
+            if ($usePlugins)
+            {
+                foreach (@{$self->{model}->getPluginsNames})
+                {
+                    push @{$self->{sourcesList}},{value=>$_,
+                                        displayed=>$_};
+                }
+            }
+            if ($otherSourcesList && scalar (@$otherSourcesList))
+            {
+                foreach (@{$otherSourcesList})
+                {
+                    push @{$self->{sourcesList}},Storable::dclone($_);
+                }
+            }
+            $self->{sourcesListWithRemoveItem}=Storable::dclone($self->{sourcesList});
+            unshift @{$self->{sourcesListWithRemoveItem}}, {value=>$removeValue,displayed=>$self->{parent}->{lang}->{OptionsPluginsMultiPerFieldRemove}};
+        }
+
+        sub setModel
+        {
+            my ($self, $model) = @_;
+            
+            
+            my $parent = $self->{parent};
+            return if $self->{model} == $model;
+            $self->{model} = $model;
+        }
+
+        sub initForm
+        {
+            my ($self) = @_;
+            
+            my $parent = $self->{parent};
+            my $fieldsInfo = $self->{model}->{fieldsInfo};
+            $self->{urlField} = $self->{parent}->{model}->{commonFields}->{url};
+    
+            foreach ($self->{table}->get_children)
+            {
+                $self->{table}->remove($_);
+                $_->destroy;
+            }
+            
+            my $row = 0;
+            my $field;
+            foreach $field(@{$self->{model}->{fieldsNames}})
+            {
+                next if $fieldsInfo->{$field}->{imported} ne 'true';
+                next if ($field eq $self->{urlField});
+                $self->createRowForField($field, $row);
+                $row++;
+            }
+            
+            $row++;
+            if($self->{bottomline})
+            {
+                foreach($self->{bottomline}->get_children)
+                {
+                    $self->{bottomline}->remove($_);
+                    $_->destroy;
+                }
+                $self->{bottomline}->destroy;
+                undef $self->{bottomline};
+            }
+            $self->{bottomline}=new Gtk2::HBox;
+            
+            $self->{bottomline}->{selectAll}=new Gtk2::Button($parent->{lang}->{ImportSelectAll});
+            $self->{bottomline}->{selectAll}->signal_connect('clicked' => sub {
+                while ( my ($field, $row) = each(%{$self->{fields}}) ) {
+                     $row->{'Cb'}->setValue(1);
+                }
+            });
+            $self->{bottomline}->pack_start($self->{bottomline}->{selectAll},0,0,0);
+            
+            $self->{bottomline}->{selectNone}=new Gtk2::Button($parent->{lang}->{ImportSelectNone});
+            $self->{bottomline}->{selectNone}->signal_connect('clicked' => sub {
+                while ( my ($field, $row) = each(%{$self->{fields}}) ) {
+                     $row->{'Cb'}->setValue(0);
+                }
+            });
+            $self->{bottomline}->pack_start($self->{bottomline}->{selectNone},0,0,0);
+            
+            $self->{bottomline}->{clear}=new Gtk2::Button($parent->{lang}->{OptionsPluginsMultiPerFieldClearSelected});
+            $self->{bottomline}->{clear}->signal_connect('clicked' => sub {
+                while ( my ($field, $row) = each(%{$self->{fields}}) ) {
+                     $self->removeAllSourceListFromField($field) if $row->{'Cb'}->getValue;
+                }
+            });
+            $self->{bottomline}->pack_start($self->{bottomline}->{clear},0,0,0);
+            
+            $self->{bottomline}->{positionAddToAll} = new GCMenuList([{value=>'First',displayed=>$parent->{lang}->{OptionsPluginsMultiPerFieldFirst}},
+                                                    {value=>'Last',displayed=>$parent->{lang}->{OptionsPluginsMultiPerFieldLast}}]);
+            $self->{bottomline}->pack_end($self->{bottomline}->{positionAddToAll},0,0,0);
+            
+            $self->{bottomline}->{siteAddToAll} = $self->getSourcesListMenu;
+            $self->{bottomline}->pack_end($self->{bottomline}->{siteAddToAll},0,0,0);
+            
+            $self->{bottomline}->{addToAll} = GCButton->newFromStock('gtk-add', 0);
+            $self->{bottomline}->{addToAll}->signal_connect('clicked' => sub {
+                    my $positionAdd=$self->{bottomline}->{positionAddToAll}->getValue(0) eq 'First' ? 0:-1;
+                    foreach $field(keys %{$self->{fields}})
+                    {
+                        $self->addSiteListToField($field,$positionAdd,$self->{bottomline}->{siteAddToAll}->getValue(0));
+                    }
+            });
+            $self->{bottomline}->pack_end($self->{bottomline}->{addToAll},0,0,0);
+            
+            $self->{layoutVBox}->pack_start($self->{bottomline},0,0,$GCUtils::margin);
+         }
+
+
+        sub loadPrefOrderListInForm
+        {
+            my $self = shift;
+            # load from preference string
+            undef $pluginListOrderPerField;
+            undef $fieldsToFetch;
+            my $valueStr = $self->{model}->{preferences}->multisiteperfield;
+            my @arrValues= split ';', $valueStr;
+            foreach (@arrValues)
+            {
+                my @line=split ',',$_;
+                my $field=shift @line;
+                $fieldsToFetch->{$field}=shift @line;
+                $pluginListOrderPerField->{$field}=\@line if scalar(@line);
+            }
+            # add values in form 
+            while ( my ($field, $row) = each(%{$self->{fields}}) ) {
+                $self->removeAllSourceListFromField($field);
+                $self->addSiteListToField($field,-1,$_) foreach (@{$pluginListOrderPerField->{$field}});
+                $self->{fields}->{$field}->{Cb}->setValue($fieldsToFetch->{$field});
+            }
+            $self->cleanListOrder;
+        }
+
+        sub savePrefOrderListFromForm
+        {
+            my $self = shift;
+            undef $pluginListOrderPerField;
+            undef $fieldsToFetch;
+            # load from form
+            $self->cleanListOrder;
+            while ( my ($field, $row) = each(%{$self->{fields}}) ) {
+                $fieldsToFetch->{$field}= $row->{'Cb'}->getValue;
+                push @{$pluginListOrderPerField->{$field}},$_->getValue foreach (@{$row->{'SiteListMenus'}});
+            }
+            # save to preference string
+            my $valueStrArr = [];
+            while ( my ($field, $row) = each(%{$self->{fields}}) ) {
+                my $value=$field.','.$fieldsToFetch->{$field};
+                $value=$value.','.join ',',@{$pluginListOrderPerField->{$field}} if $pluginListOrderPerField->{$field};
+                push @$valueStrArr,$value;
+            }
+            $self->{model}->{preferences}->multisiteperfield(join ';',@$valueStrArr);
+        }
+
+        sub cleanListOrder
+        {
+            my $self = shift;
+            # remove double sitename for each fields, keep the first one
+            for my $field (keys %{$self->{fields}} ) {
+                my $sites={};
+                my $row=$self->{fields}->{$field}->{SiteListMenus};
+                for (my $i = 0; $i <= $#$row; ++$i)
+                {
+                    if ($sites->{$row->[$i]->getValue})
+                    {
+                        $self->removeSiteListFromField($field,$i);
+                        $i--;
+                    }
+                    else
+                    {
+                        $sites->{$row->[$i]->getValue}=1;
+                    }
+                }
+                undef $sites;
+            }
+        }
+
+        sub resetCurrentFetchingStatus
+        {
+            undef $remainingSourcesOrderPerField;
+            foreach (keys %$fieldsToFetch)
+            {
+                $remainingSourcesOrderPerField->{$_}=Storable::dclone($pluginListOrderPerField->{$_}) if $fieldsToFetch->{$_} ;
+            
+            }
+        }
+
+        sub getNextSourceNeeded
+        {
+            my $self = shift;
+            foreach my $field(keys %$remainingSourcesOrderPerField)
+            {
+                if (scalar(@{$remainingSourcesOrderPerField->{$field}})>0)
+                {
+                    return $remainingSourcesOrderPerField->{$field}->[0];
+                }
+            }
+            return undef;
+        }
+
+        sub getPlugin
+        {
+            my ($self,$pluginName) = @_;
+            return $self->{model}->getPlugin($pluginName);
+        }
+
+        sub getNonEmptyFields
+        {
+            my ($self,$info)=@_;
+            my $nonEmptyFields=[];
+            foreach my $field(keys %$info)
+            {
+                push @$nonEmptyFields,$field if $self->isFieldNonEmpty($info->{$field});
+            }
+            return $nonEmptyFields;
+        }
+
+        sub isFieldNonEmpty
+        {
+            my ($self,$var)=@_;
+            return 0 if !defined $var;
+            my $reftype=ref $var;
+            if (!$reftype)
+            {
+                return $var ne '';
+            }
+            elsif ($reftype eq 'SCALAR')
+            {
+                return $$var ne '' && $var!=undef;
+            }
+            elsif ($reftype eq 'ARRAY')
+            {
+                return scalar($var)>0;
+            }
+            elsif ($reftype eq 'HASH')
+            {
+                return scalar(keys(%{$var}))>0;
+            }
+        }
+
+        sub doneWithSourceName
+        {
+            my ($self,$pluginName,$info) = @_;
+            foreach my $field(keys %$remainingSourcesOrderPerField)
+            {
+                foreach my $pluginIdx (0..$#{$remainingSourcesOrderPerField->{$field}})
+                {
+                    if ($remainingSourcesOrderPerField->{$field}->[$pluginIdx] eq $pluginName)
+                    {
+                        if ($self->isFieldNonEmpty($info->{$field}))
+                        {
+                            # if we have the field, so we wont need other info
+                            $#{$remainingSourcesOrderPerField->{$field}}=$pluginIdx-1;
+                            last;
+                        }
+                        else
+                        {
+                            # else we will still need the next one
+                            splice @{$remainingSourcesOrderPerField->{$field}},$pluginIdx,1;
+                            last;
+                        }
+                    }
+                }
+            }
+        }
+
+        sub joinInfo
+        {
+            my ($self,$infoPerPlugin) = @_;
+            my $info={};
+            my $fetchedSources=Storable::dclone($pluginListOrderPerField);
+            my %urls;
+            my $urlField=$self->{parent}->{model}->{commonFields}->{url};
+            foreach my $field(keys %$pluginListOrderPerField)
+            {
+                shift @{$fetchedSources->{$field}} while (scalar(@{$fetchedSources->{$field}}) && !$self->isFieldNonEmpty($infoPerPlugin->{$fetchedSources->{$field}->[0]}->{$field}));
+                if (scalar(@{$fetchedSources->{$field}})>0)
+                {
+                    $info->{$field}=$infoPerPlugin->{$fetchedSources->{$field}->[0]}->{$field} ;
+                    $urls{$fetchedSources->{$field}->[0]}=$infoPerPlugin->{$fetchedSources->{$field}->[0]}->{$urlField};
+                }
+            }
+            $info->{$urlField}=join ';',values %urls;
+            return $info;
+        }
+    }
 }
 
 {
@@ -649,7 +1137,7 @@ sub loadAllPlugins
             {
                 my @idx = $self->{results}->get_selected_indices;
                 my $itemIndex = $self->{items}->[$idx[0]]->{'#'};
-                $self->{parent}->getItemInfo($self->{plugin}, $itemIndex, 1);
+                $self->{parent}->downloadItemInfoFromPlugin($self->{plugin}, $itemIndex, 1);
             }
             $ended = 1 if ($code eq 'ok') || ($code eq 'cancel') || ($code eq 'delete-event') || ($code eq 'no');
         }
