@@ -2,7 +2,7 @@ package GCPlugins::GCPluginsBase;
 
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -42,6 +42,7 @@ use utf8;
 
         $ua->agent('Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.7.5) Gecko/20041111 Firefox/1.0');
         $ua->default_header('Accept-Encoding' => 'x-gzip');
+        $ua->default_header('Accept' => 'text/html');
         $self->{ua} = $ua;
         
         $self->{itemIdx} = -1;
@@ -76,7 +77,7 @@ use utf8;
         $self->{itemsList} = ();
 
         #my $word = uri_escape_utf8($self->{title});
-        my $title2 = encode($self->getCharset, $self->{title});
+        my $title2 = encode($self->getSearchCharset, $self->{title});
         my $word = uri_escape($title2);
         $word =~ s/%20/+/g;
 
@@ -118,8 +119,8 @@ use utf8;
     
     sub loadPage
     {
-        my ($self, $url, $post) = @_;
-        $self->{loadedUrl} = $url;
+        my ($self, $url, $post, $noSave) = @_;
+        $self->{loadedUrl} = $url if ! $noSave;
         my $response;
         if ($post)
         {
@@ -175,6 +176,7 @@ use utf8;
         return '';
     }
 
+    # Character set for web page text
     sub getCharset
     {
         my $self = shift;
@@ -182,6 +184,15 @@ use utf8;
         return "ISO-8859-1";
     }
     
+    # Character set for encoding search term, can sometimes be different
+    # to the page encoding, but we default to the same as the page set
+    sub getSearchCharset
+    {
+        my $self = shift;
+    
+        return getCharset;
+    }
+    
     sub getNotConverted
     {
         my $self = shift;
@@ -245,7 +256,6 @@ use utf8;
         my ($self, $url) = @_;
         $self->checkProxy;
         my $realUrl = $self->changeUrl($url);
-        
         my $html = $self->loadPage($realUrl);
         $self->{parsingList} = 0;
         #$html = $self->convertCharset($html);
