@@ -2,7 +2,7 @@ package GCPlugins::GCboardgames::GCboardgamesCommon;
 
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -24,9 +24,6 @@ package GCPlugins::GCboardgames::GCboardgamesCommon;
 
 use strict;
 
-our $MAX_ACTORS = 6;
-our $MAX_DIRECTORS = 4;
-
 use GCPlugins::GCPluginsBase;
 
 {
@@ -47,6 +44,15 @@ use GCPlugins::GCPluginsBase;
     {
         return ['name'];
     }
+    
+    sub loadUrl
+    {
+        my ($self, $url) = @_;
+        
+        $self->SUPER::loadUrl($url);
+
+        return $self->{curInfo};
+    }
 }
 
 1;
