@@ -1,8 +1,8 @@
-package GCPlugins::GCbooks::GCAlapage;
+﻿package GCPlugins::GCbooks::GCAlapage;
 
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -42,7 +42,7 @@ use GCPlugins::GCbooks::GCbooksCommon;
         if ($self->{parsingList})
         {
 
-            if (($tagname eq 'div') && ($attr->{class} eq 'pdt_detail_XL_Bigger'))
+            if (($tagname eq 'div') && ($attr->{class} eq 'infos_produit'))
             {
                 $self->{isBook} = 1 ;
                 $self->{isUrl} = 1 ;
@@ -58,7 +58,7 @@ use GCPlugins::GCbooks::GCbooksCommon;
                 $self->{itemsList}[$self->{itemIdx}]->{title} = $attr->{title};
                 $self->{isUrl} = 0 ;
             }
-            elsif (($tagname eq 'a') && ( index($attr->{href},"mot_auteurs") >= 0) && ($attr->{class} eq 'blacktxtbold') && ($self->{isBook}))
+            elsif (($tagname eq 'a') && ( index($attr->{href},"mot_auteurs") >= 0) && ($self->{isBook}))
             {
                 $self->{isAuthor} = 1 ;
             }
@@ -85,40 +85,50 @@ use GCPlugins::GCbooks::GCbooksCommon;
             {
                 $self->{isPage} = 2 ;
             }
-            elsif (($tagname eq 'h2') && ($attr->{class} eq 'big_black_title'))
+            elsif ($tagname eq 'h2')
             {
                 $self->{isTitle} = 1 ;
             }
-            elsif (($tagname eq 'a') && ( index($attr->{href},"mot_auteurs") >= 0) && ($attr->{class} eq 'greytxt'))
+            elsif (($tagname eq 'tpfcommentaire') && ($self->{isDescription} eq 1))
+            {
+                $self->{isDescription} = 2 ;
+            }
+            elsif (($tagname eq 'a') && ( index($attr->{href},"mot_auteurs") >= 0))
             {
                 $self->{isAuthor} = 1 ;
             }
-            elsif (($tagname eq 'a') && ($attr->{class} eq 'greytxt thickbox') && ($self->{curInfo}->{cover} eq ''))
+            elsif (($tagname eq 'a') && ($attr->{class} eq 'thickbox tooltip') && ($self->{curInfo}->{cover} eq ''))
             {
-                   my $html = $self->loadPage( "http://www.alapage.com" . $attr->{href} );
+                   my $html = $self->loadPage( "http://www.alapage.com" . $attr->{href}, 0, 1);
                    my $found = index($html,"\"laplusgrande\"");
                    if ( $found >= 0 )
                    {
+                      my $found2 = index($html,"&m=v");
                       $html = substr($html, $found +length('"laplusgrande"'),length($html)- $found -length('"laplusgrande"'));
 
-                         my @array = split(/"/,$html);
-                         #"
-                         $self->{curInfo}->{cover} = "http://www.alapage.com" . $array[1];
+                      my @array = split(/"/,$html);
+                      #"
+                      $self->{curInfo}->{cover} = "http://www.alapage.com" . $array[1];
+                      if ( $found2 >= 0 )
+                      {
+                         $self->{curInfo}->{backpic} = $self->{curInfo}->{cover};
+                         $self->{curInfo}->{backpic} =~ s|&m=r|&m=v|gi;
+                      }
                    }
             }
-            elsif (($tagname eq 'li') && ($attr->{class} eq 'borderright'))
+            elsif ($tagname eq 'li')
             {
                 $self->{isAnalyse} = 1 ;
             }
-            elsif (($tagname eq 'a') && ( index($attr->{href},"mot_cdu") >= 0) && ($attr->{class} eq 'greytxt'))
+            elsif (($tagname eq 'a') && ( index($attr->{href},"mot_cdu") >= 0))
             {
                 $self->{isGenre} = 1 ;
             }
-            elsif (($tagname eq 'a') && ( index($attr->{href},"mot_editeur") == -1) && ( index($attr->{href},"mot_coll_serie") >= 0) && ($attr->{class} eq 'greytxt'))
+            elsif (($tagname eq 'a') && ( index($attr->{href},"mot_coll_serie") >= 0))
             {
                 $self->{isSerie} = 1 ;
             }
-            elsif (($tagname eq 'a') && ( index($attr->{href},"mot_editeur") >= 0) && ( index($attr->{href},"mot_coll_serie") == -1) && ($attr->{class} eq 'greytxt'))
+            elsif (($tagname eq 'a') && ( index($attr->{href},"mot_editeur") >= 0) && ( index($attr->{href},"mot_coll_serie") == -1))
             {
                 $self->{isPublisher} = 1 ;
             }
@@ -134,6 +144,10 @@ use GCPlugins::GCbooks::GCbooksCommon;
             {
                 $self->{isDescription} = 0 ;
             }
+            elsif (($tagname eq 'div') && ($attr->{class} eq 'edito FP_commentaire'))
+            {
+                $self->{isDescription} = 1 ;
+            }
 
         }
     }
@@ -302,15 +316,23 @@ use GCPlugins::GCbooks::GCbooksCommon;
 
         if ($self->{parsingList})
         {
+            $html =~ s|<p>||gi;
+            $html =~ s|</p>||gi;
         }
         else
         {
             $html =~ s|<font style=&quot;font-size:13px;&quot;>||gi;
             $html =~ s|<font style="font-size:13px;">||gi;
             $html =~ s|</font>||gi;
+            $html =~ s|<strong>||gi;
+            $html =~ s|</strong>|</strong><tpfanalyse>|gi;
+            $html =~ s|</h3>|</h3><tpfcommentaire>|gi;
+            $html =~ s|<p>||gi;
+            $html =~ s|</p>||gi;
         }
-        
+
         return $html;
+
     }
     
     sub getSearchUrl
