@@ -2,7 +2,7 @@ package GCPlugins::GCbooks::GCAmazon;
 
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -60,6 +60,8 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
 
         if ($self->{parsingList})
         {
+            $self->{otherEditions} = 1 if ($tagname eq 'div') && ($attr->{class} eq 'otherEditions');
+            return if $self->{otherEditions};
             if ($tagname eq 'input')
             {
                 $self->{beginParsing} = 1
@@ -71,11 +73,25 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
                     if $attr->{name} eq 'quantity';
             }
             return if ! $self->{beginParsing};
+
+            if ($tagname eq 'srtitle')
+            {
+                $self->{isTitle} = 1;
+            }
+            elsif ($tagname eq 'format')
+            {
+                $self->{isFormat} = 1 ;
+            }
+            elsif ($tagname eq 'publication')
+            {
+                $self->{isPublication} = 1;
+            }
             if ($tagname eq 'a')
             {
                 my $urlId;
                 if ($urlId = $self->isItemUrl($attr->{href}))
                 {
+                    $self->{isTitle} = 2 if $self->{isTitle} eq '1';
                     return if $self->{alreadyRetrieved}->{$urlId};
                     $self->{alreadyRetrieved}->{$urlId} = 1;
                     $self->{currentRetrieved} = $urlId;
@@ -102,13 +118,16 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
     {
         my ($self, $tagname) = @_;
         $self->{inside}->{$tagname}--;
-        $self->{insideContent} = 0 if $tagname eq 'div';
+
+        $self->{insideContent} = $self->{otherEditions} = 0 if $tagname eq 'div';
+        $self->{isAuthor} = $self->{nextIsAuthor} eq 1 if $tagname eq 'a';   
     }
 
     sub text
     {
         my ($self, $origtext) = @_;
 
+        return if GCPlugins::GCstar::GCPluginAmazonCommon::text(@_);
         return if ($self->{parsingEnded});
 
         if ($self->{parsingList})
@@ -129,35 +148,35 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
             {
                 $self->{parsingEnded} = 1;
             }
-            if (
-                (($self->{inside}->{b})
-                || ($self->{inside}->{span}))            
-             && ($origtext =~ /Sort by/))
-            {
-                $self->{beginParsing} = 1;
-                return;
-            }
             
             return if ! $self->{beginParsing};
-            if ($self->{inside}->{srtitle})
+
+            if ($self->{isTitle})
             {
-                return if length($origtext) < 2;
                 $self->{itemsList}[$self->{itemIdx}]->{title} = $origtext;
+                $self->{isTitle} = 0;
+                $self->{nextIsAuthor} = 1;
                 return;
             }
-            elsif ($self->{inside}->{author})
+            elsif ($self->{isAuthor})
             {
+                $origtext =~ s/^\s*//;
+                $origtext =~ s/\s*$//;    
                 $origtext =~ s/by //;
                 $self->{itemsList}[$self->{itemIdx}]->{authors} = $origtext
                     if ! $self->{itemsList}[$self->{itemIdx}]->{authors};
+                $self->{nextIsAuthor} = 0;
+                $self->{isAuthor} = 0;
             }
-            elsif ($self->{inside}->{publication})
+            elsif ($self->{isPublication})
             {
                 $self->{itemsList}[$self->{itemIdx}]->{publication} = $origtext;
+                $self->{isPublication} = 0;
             }
-            elsif ($self->{inside}->{format})
+            elsif ($self->{isFormat})
             {
                 $self->{itemsList}[$self->{itemIdx}]->{format} = $origtext;
+                $self->{isFormat} = 0;
             }
         }
        	else
@@ -166,7 +185,6 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
             $origtext =~ s/\s*$//;
             if ($self->{inside}->{title})
             {
-                #$origtext =~ m/Amazon.com: (.*?): (.*)(: Books)?$/;
                 $origtext =~ m/Amazon.com\s*:\s*(.*?):\s*([^:]*)(:\s*Books)?\s*$/;
                 $self->{curInfo}->{title} = $1;
                 $self->{curInfo}->{authors} = $2;
@@ -207,6 +225,28 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
                 $self->{curInfo}->{pages} = $origtext;
                 $self->{insidePages} = 0;
             }
+            elsif ($self->{insideSeries})
+            {
+                $self->{curInfo}->{serie} = $origtext;
+                $self->{insideSeries} = 0;
+            }
+            elsif ($origtext eq "in")
+            {
+                $self->{insideSeries} = 1;
+            }            
+            elsif ($origtext eq 'Product Details')
+            {
+                $self->{insideDetails} = 1;
+            }
+            elsif (($origtext eq ">") && !($self->{curInfo}->{genre}))
+            {
+                $self->{insideGenre} = 1;
+            }
+            elsif ($self->{insideGenre} eq 1)
+            {
+                $self->{curInfo}->{genre} = $origtext;
+                $self->{insideGenre} = 0;
+            }
             elsif ($self->{inside}->{b})
             {
                 $self->{insideDesc} = 1 if ($origtext eq 'Book Description' 
@@ -223,7 +263,6 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
                     $self->{insidePages} = 1;
                     $self->{insideDetails} = 0;
                 }
-                $self->{insideDetails} = 1 if $origtext eq 'Product Details';
             }        
         }
     } 
@@ -277,8 +316,8 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
         $self->{parsingEnded} = 0;
         if ($self->{parsingList})
         {
-            $html =~ s|^\s+by(.*)$|<author>$1</author>|gm;
-            $html =~ s|<span class="bindingBlock">\(<span class="binding">(.*?)</span> - (.*?[0-9]{4})\)</span>|<format>$1</format><publication>$2</publication>|gsm;
+            $self->{otherEditions} = 0;
+            $html =~ s|<span class="binding">(.*?)</span> - (.*?[0-9]{4})\)</span>|<format>$1</format><publication>$2</publication>|gsm;
             $self->{parsingEnded} = 1
                 if $html !~ /<title>/;
         }
