@@ -2,7 +2,7 @@ package GCPlugins::GCbooks::GCAmazonDE;
 
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -60,6 +60,8 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
 
         if ($self->{parsingList})
         {
+            $self->{otherEditions} = 1 if ($tagname eq 'div') && ($attr->{class} eq 'otherEditions');
+            return if $self->{otherEditions};
             if ($tagname eq 'input')
             {
                 $self->{beginParsing} = 1
@@ -94,32 +96,25 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
     sub end
     {
 		my ($self, $tagname) = @_;
-
         $self->{inside}->{$tagname}--;
+        $self->{insideContent} = $self->{otherEditions} = 0 if $tagname eq 'div';
     }
 
     sub text
     {
         my ($self, $origtext) = @_;
 
+        return if GCPlugins::GCstar::GCPluginAmazonCommon::text(@_);
         return if ($self->{parsingEnded});
 
         if ($self->{parsingList})
         {
             if (($self->{inside}->{title})
             && ($origtext !~ /Amazon.com.*? B.+?cher/)
-            && ($origtext !~ /Amazon.de:?\s+.*?B.+?cher$/))
+            && ($origtext !~ /^Amazon.de*/))
             {
                 $self->{parsingEnded} = 1;
             }
-            if (
-                (($self->{inside}->{b})
-                || ($self->{inside}->{span}))            
-             && ($origtext =~ /Sortieren nach/))
-            {
-                $self->{beginParsing} = 1;
-                return;
-            }
             
             return if ! $self->{beginParsing};
             if ($self->{inside}->{srtitle})
@@ -149,7 +144,7 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
             $origtext =~ s/\s*$//;
             if ($self->{inside}->{title})
             {
-                $origtext =~ m/Amazon.de\s*:\s*(.*?):\s*([^:]*):\s*(B.+?cher|English Books)\s*$/;
+                $origtext =~ m/(.*?):\s*Amazon.de\s*:\s*([^:]*):\s*(B.+?cher|English Books)\s*$/;
                 $self->{curInfo}->{title} = $1;
                 $self->{curInfo}->{authors} = $2;
             }
@@ -182,6 +177,19 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
             {
                 $self->{curInfo}->{pages} = $origtext;
                 $self->{insidePages} = 0;
+            }        
+            elsif ($origtext eq 'Produktinformation')
+            {
+                $self->{insideDetails} = 1;
+            }
+            elsif (($origtext eq ">") && !($self->{curInfo}->{genre}))
+            {
+                $self->{insideGenre} = 1;
+            }
+            elsif ($self->{insideGenre} eq 1)
+            {
+                $self->{curInfo}->{genre} = $origtext;
+                $self->{insideGenre} = 0;
             }
             elsif ($self->{inside}->{b})
             {
@@ -198,7 +206,6 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
                     $self->{insidePages} = 1;
                     $self->{insideDetails} = 0;
                 }
-                $self->{insideDetails} = 1 if $origtext eq 'Produktinformation';
             }        
         }
     } 
@@ -267,6 +274,7 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
         $self->{parsingEnded} = 0;
         if ($self->{parsingList})
         {
+            $self->{otherEditions} = 0;
             $html =~ s|^\s+von(.*)$|<author>$1</author>|gm;
             $html =~ s|<span class="bindingBlock">\(<span class="binding">(.*?)</span> - (.*?[0-9]{4})\)</span>|<format>$1</format><publication>$2</publication>|gsm;
             $self->{parsingEnded} = 1
