@@ -2,7 +2,7 @@ package GCPlugins::GCbooks::GCAmazonUK;
 
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -60,22 +60,37 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
 
         if ($self->{parsingList})
         {
-            if (($tagname eq 'meta') && ($attr->{name} eq 'keywords'))
-            {
-                $self->{parsingEnded} = 1;
-            }
-            elsif ($tagname eq 'input')
+            $self->{otherEditions} = 1 if ($tagname eq 'div') && ($attr->{class} eq 'otherEditions');
+            return if $self->{otherEditions};
+            if ($tagname eq 'input')
             {
                 $self->{beginParsing} = 1
                     if $attr->{src} =~ /go-button-search/;
             }
+            elsif ($tagname eq 'select')
+            {
+                $self->{parsingEnded} = 1
+                    if $attr->{name} eq 'quantity';
+            }
             return if ! $self->{beginParsing};
+            if ($tagname eq 'srtitle')
+            {
+                $self->{isTitle} = 1;
+            }
+            elsif ($tagname eq 'format')
+            {
+                $self->{isFormat} = 1 ;
+            }
+            elsif ($tagname eq 'publication')
+            {
+                $self->{isPublication} = 1;
+            }
             if ($tagname eq 'a')
             {
                 my $urlId;
                 if ($urlId = $self->isItemUrl($attr->{href}))
-#                if ($attr->{href} =~ m|/dp/[A-Z0-9]*/sr=([0-3]-[0-9]*)/qid=[0-9]*|)
                 {
+                    $self->{isTitle} = 2 if $self->{isTitle} eq '1';
                     return if $self->{alreadyRetrieved}->{$urlId};
                     $self->{alreadyRetrieved}->{$urlId} = 1;
                     $self->{currentRetrieved} = $urlId;
@@ -91,6 +106,10 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
             {
                 $self->{curInfo}->{cover} = $self->extractImage($attr);
             }
+            elsif (($tagname eq 'div') && ($attr->{class} eq 'content'))
+            {
+                $self->{insideContent} = 1;
+            }
         }
     }
 
@@ -98,12 +117,15 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
     {
         my ($self, $tagname) = @_;
         $self->{inside}->{$tagname}--;
+        $self->{insideContent} = $self->{otherEditions} = 0 if $tagname eq 'div';
+        $self->{isAuthor} = $self->{nextIsAuthor} eq 1 if $tagname eq 'a';   
     }
 
     sub text
     {
         my ($self, $origtext) = @_;
 
+        return if GCPlugins::GCstar::GCPluginAmazonCommon::text(@_);
         return if ($self->{parsingEnded});
 
         if ($self->{parsingList})
@@ -114,35 +136,34 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
             {
                 $self->{parsingEnded} = 1;
             }
-            if (
-                (($self->{inside}->{b})
-                || ($self->{inside}->{span}))            
-             && ($origtext =~ /Sort by/))
-            {
-                $self->{beginParsing} = 1;
-                return;
-            }
             
             return if ! $self->{beginParsing};
-            if ($self->{inside}->{srtitle})
+            if ($self->{isTitle})
             {
-                return if length($origtext) < 2;
                 $self->{itemsList}[$self->{itemIdx}]->{title} = $origtext;
+                $self->{isTitle} = 0;
+                $self->{nextIsAuthor} = 1;
                 return;
             }
-            elsif ($self->{inside}->{author})
+            elsif ($self->{isAuthor})
             {
+                $origtext =~ s/^\s*//;
+                $origtext =~ s/\s*$//;    
                 $origtext =~ s/by //;
                 $self->{itemsList}[$self->{itemIdx}]->{authors} = $origtext
                     if ! $self->{itemsList}[$self->{itemIdx}]->{authors};
+                $self->{nextIsAuthor} = 0;
+                $self->{isAuthor} = 0;
             }
-            elsif ($self->{inside}->{publication})
+            elsif ($self->{isPublication})
             {
                 $self->{itemsList}[$self->{itemIdx}]->{publication} = $origtext;
+                $self->{isPublication} = 0;
             }
-            elsif ($self->{inside}->{format})
+            elsif ($self->{isFormat})
             {
                 $self->{itemsList}[$self->{itemIdx}]->{format} = $origtext;
+                $self->{isFormat} = 0;
             }
         }
        	else
@@ -151,7 +172,7 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
             $origtext =~ s/\s*$//;
             if ($self->{inside}->{title})
             {
-                $origtext =~ m/Amazon.co.uk\s*:\s*(.*?):\s*([^:]*)(:\s*Books)?\s*$/;
+                $origtext =~ m/(.*?):\s*Amazon.co.uk\s*:\s*([^:]*)(:\s*Books)?\s*$/;
                 $self->{curInfo}->{title} = $1;
                 $self->{curInfo}->{authors} = $2;
             }
@@ -185,13 +206,37 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
                 $self->{curInfo}->{pages} = $origtext;
                 $self->{insidePages} = 0;
             }
+            elsif ($self->{insideSeries})
+            {
+                $self->{curInfo}->{serie} = $origtext;
+                $self->{insideSeries} = 0;
+            }
+            elsif ($origtext eq "in")
+            {
+                $self->{insideSeries} = 1;
+            }            
+            elsif ($origtext eq 'Product details')
+            {
+                $self->{insideDetails} = 1;
+            }
+            elsif (($origtext eq ">") && !($self->{curInfo}->{genre}))
+            {
+                $self->{insideGenre} = 1;
+            }
+            elsif ($self->{insideGenre} eq 1)
+            {
+                $self->{curInfo}->{genre} = $origtext;
+                $self->{insideGenre} = 0;
+            }
             elsif ($self->{inside}->{b})
             {
-                $self->{insideDesc} = 1 if $origtext eq 'Book Description' 
-                                        || $origtext =~ /^Amazon\.co\.uk [^S]/;
+                $self->{insideDesc} = 1 if ($origtext eq 'Book Description' 
+                                        || $origtext =~ /^Amazon.com(?! (Sales|Delivers|Home))/)
+                                        && ($self->{insideContent});
                 $self->{insidePublisher} = 1 if $origtext =~ /Publisher:/;
-				$self->{insideLanguage} = 1 if $origtext =~ /Language:/;
-				$self->{insideIsbn} = 1 if $origtext =~ /ISBN(-[0-9]*)?:/;
+				$self->{insideLanguage} = 1 if $origtext =~ /Language/;
+                $self->{insideIsbn10} = 1 if $origtext =~ /ISBN(-10)?:/;
+                $self->{insideIsbn13} = 1 if $origtext =~ /ISBN-13:/;
 				if ($self->{insideDetails})
                 {
                     $origtext =~ s/:$//;
@@ -199,7 +244,6 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
                     $self->{insidePages} = 1;
                     $self->{insideDetails} = 0;
                 }
-				$self->{insideDetails} = 1 if $origtext eq 'Product Details';
             }        
         }
     } 
@@ -264,8 +308,8 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
         $self->{parsingEnded} = 0;
         if ($self->{parsingList})
         {
-            $html =~ s|^\s+by(.*)$|<author>$1</author>|gm;
-            $html =~ s|<span class="bindingBlock">\(<span class="binding">(.*?)</span> - (.*?[0-9]{4})\)</span>|<format>$1</format><publication>$2</publication>|gsm;
+            $self->{otherEditions} = 0;
+            $html =~ s|<span class="binding">(.*?)</span> - (.*?[0-9]{4})\)</span>|<format>$1</format><publication>$2</publication>|gsm;
             $self->{parsingEnded} = 1
                 if $html !~ /<title>/;
         }
