@@ -200,7 +200,7 @@ use GCPlugins::GCbooks::GCbooksCommon;
                    $origtext = substr($origtext, $found +length('if(sottogenere[k][numero].c=="'),length($origtext)- $found -length('if(sottogenere[k][numero].c=="'));
                    $origtext = substr($origtext, 0, index($origtext,"\""));
 
-                   my $html = $self->loadPage($self->{curInfo}->{$self->{urlField}});
+                   my $html = $self->loadPage($self->{curInfo}->{$self->{urlField}}, 0, 1);
                    my $found = index($html,"\"$origtext");
                    if ( $found >= 0 )
                    {
