@@ -94,7 +94,7 @@ use GCPlugins::GCbooks::GCbooksCommon;
             }
             elsif (($tagname eq 'iframe') && ($self->{curInfo}->{cover} eq ''))
             {
-                my $html = $self->loadPage( $attr->{src} );
+                my $html = $self->loadPage( $attr->{src}, 0, 1 );
                 my $found = index($html,"<img src=\"");
                 if ( $found >= 0 )
                 {
