@@ -2,7 +2,7 @@ package GCPlugins::GCfilms::GCAmazon;
 
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -33,7 +33,7 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
 
     sub start
     {
-        my ($self, $tagname, $attr, $attrseq, $origtext) = @_;	
+        my ($self, $tagname, $attr, $attrseq, $origtext) = @_;
         $self->{inside}->{$tagname}++;
         if ($self->{parsingEnded})
         {
@@ -53,23 +53,24 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
                     if $attr->{src} =~ /go-button-search/;
             }
             return if ! $self->{beginParsing};
-            if ($tagname eq "a")
+            if ($tagname eq 'a')
             {
-                my $urlId;
-                if ($urlId = $self->isItemUrl($attr->{href}))
-#                if ($attr->{href} =~ m|/dp/[A-Z0-9]*/sr=([0-3]-[0-9]*)/qid=[0-9]*|)
+                if (($self->{isItem} eq 1) && ($self->{isUrl}))
                 {
-                    return if $self->{alreadyRetrieved}->{$urlId};
-                    $self->{alreadyRetrieved}->{$urlId} = 1;
-                    my $url = $attr->{href}; 
                     $self->{itemIdx}++;
-                    $self->{itemsList}[$self->{itemIdx}]->{url} = $url;
+                    $self->{itemsList}[$self->{itemIdx}]->{url} = $attr->{href};
+                    $self->{isUrl} = 0 ;
                 }
             }
-            elsif ($tagname eq 'div')
+            elsif (($tagname eq 'div') && ($attr->{class} eq 'productTitle'))
             {
-                $self->{inside}->{actors} = 2 if $attr->{class} eq 'binding';
-                $self->{inside}->{srtitle} = 2 if $attr->{class} eq 'productTitle';
+                $self->{isItem} = 1 ;
+                $self->{isUrl} = 1 ;
+                $self->{isName} = 1 ;
+            }
+            elsif (($tagname eq 'span') && ($attr->{class} eq 'binding'))
+            {
+                $self->{inside}->{actors} = 1;
             }
             
         }
@@ -106,32 +107,23 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
     sub text
     {
         my ($self, $origtext) = @_;
-
+        return if GCPlugins::GCstar::GCPluginAmazonCommon::text(@_);
         return if length($origtext) < 2;
         return if ($self->{parsingEnded});
-
         if ($self->{parsingList})
         {
-            if (
-                (($self->{inside}->{b})
-                || ($self->{inside}->{span}))            
-             && ($origtext =~ /Sort by/))
-            {
-                $self->{beginParsing} = 1;
-                return;
-            }
             return if ! $self->{beginParsing};
-            if ($self->{inside}->{actors})
-            {
-                $self->{itemsList}[$self->{itemIdx}]->{actors} = $origtext
-                    if ! $self->{itemsList}[$self->{itemIdx}]->{actors};
-                $self->{inside}->{actors} = 0 if $self->{inside}->{actors} == 2;
-                return;
-            }
-            elsif ($self->{inside}->{srtitle})
+            if ($self->{isName} && $self->{inside}->{a})
             {
                 $self->{itemsList}[$self->{itemIdx}]->{title} = $origtext;
-                $self->{inside}->{srtitle} = 0 if $self->{inside}->{srtitle} == 2;
+                $self->{isName} = 0;
+            }
+            elsif ($self->{inside}->{actors})
+            {
+                $origtext =~ s/^\W*//;
+                $self->{itemsList}[$self->{itemIdx}]->{actors} = $origtext
+                    if ! $self->{itemsList}[$self->{itemIdx}]->{actors};
+                $self->{inside}->{actors} = 0;
                 return;
             }
         }
@@ -211,11 +203,10 @@ use GCPlugins::GCfilms::GCfilmsAmazonCommon;
     sub preProcess
     {
         my ($self, $html) = @_;
-
         $html = $self->SUPER::preProcess($html);
         if ($self->{parsingList})
         {
-            $html =~ s|^\s+~(.*)$|<actors>$1</actors>|gm;
+            $self->{isItem} = 0;
         }
         else
         {
