@@ -2,7 +2,7 @@ package GCPlugins::GCfilms::GCCinemotions;
 
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -87,16 +87,30 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                     && ($attr->{size} eq '2');
                 $self->{insideArtists} = 1 if ($attr->{face} eq 'verdana,geneva,arial')
                     && ($attr->{size} eq '2');
-                $self->{insideSynopsis} = 1 if $attr->{class} eq 'link6';
+                $self->{insideSynopsis} = 1 if ($attr->{class} eq 'link6')
+                                            && ($self->{inside}->{fieldset})
+                                            && (!$self->{curInfo}->{synopsis});
+            }
+            elsif ($tagname eq 'h2')
+            {
+                $self->{insideOrig} = 1 if $attr->{style}  eq 'color: #333333; font-size:13px';
+            }
+            elsif ($tagname eq 'br')
+            {
+                if ($self->{insideSynopsis})
+                {
+                    $self->{curInfo}->{synopsis} .= "\n";
+                }
             }
         }
     }
 
     sub end
     {
-		my ($self, $tagname) = @_;
+        my ($self, $tagname) = @_;
 		
         $self->{inside}->{$tagname}--;
+        $self->{insideSynopsis} = 0 if $tagname eq 'font';
 
     }
 
@@ -134,7 +148,8 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                 elsif ($origtext =~ /^\s*avec (.*)/)
                 {
                     $self->{itemsList}[$self->{itemIdx}]->{actors} = $1;
-                    $self->{isInfo} = 0;
+                    $self->{isInfo} = 0;        #$html =~ s|<br\s*/>|\n|g;
+
                 }
             }
         }
@@ -145,7 +160,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             {
                 $self->{curInfo}->{title} = $origtext;
             }
-            elsif ($self->{inside}->{h2} || $self->{insideOrig})
+            elsif ($self->{insideOrig})
             {
                 $self->{curInfo}->{original} = $origtext
                     if !$self->{curInfo}->{original};
@@ -153,11 +168,11 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             }
             if ($self->{insideInfos})
             {
-                if ($origtext =~ /([0-9]{4})- (\S*)- (\S*)- ([^<]*)/)
+                if ($origtext =~ /([0-9]{4})- (.*?)- ([^-]*)(?:- (.*))?/)
                 {
                     my $date = $1, my $nat = $2, my $type = $3, my $time = $4;
-                    $nat =~ s/\//, /g;
-                    $type =~ s/\//,/g;
+                    $nat =~ s|/|, |g;
+                    $type =~ s|/|,|g;
                     
                     $self->{curInfo}->{date} = $date;
                     $self->{curInfo}->{country} = $nat;
@@ -168,10 +183,8 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             }
             elsif ($self->{insideArtists})
             {
-                print "Testing $origtext\n";
                 if ($origtext =~ /R.alisation\s*:\s*(.*)/)
                 {
-                    print "Saving director $1\n";
                     $self->{curInfo}->{director} = $1 if !$self->{curInfo}->{director};
                 }
                 elsif ($origtext =~ /avec\s*:?\s*(.*)/i)
@@ -186,8 +199,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             }
             elsif ($self->{insideSynopsis})
             {
-                $self->{curInfo}->{synopsis} = $origtext if !$self->{curInfo}->{synopsis};
-                $self->{insideSynopsis} = 0;
+                $self->{curInfo}->{synopsis} .= $origtext;
             }
         }
     } 
@@ -226,6 +238,15 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         $html =~ s/<font class=link4dtext>([^<]*)<br>([^<]*)<\/TD>/<font class=link4dtext>$1 $2<\/font><\/TD>/gi;
         $html =~ s|<h1>Oops\!</h1>||gi;
 
+        $html =~ s|\x{92}|'|gi;
+        $html =~ s|&#146;|'|gi;
+        $html =~ s|&#149;|*|gi;
+        $html =~ s|&#156;|oe|gi;
+        $html =~ s|&#133;|...|gi;
+        $html =~ s|\x{85}|...|gi;
+        $html =~ s|\x{8C}|OE|gi;
+        $html =~ s|\x{9C}|oe|gi;
+
         return $html;
     }
     
@@ -233,7 +254,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     {
 		my ($self, $word) = @_;
 	
-		return "http://www.cinemotions.com/cinema-tv-dvd/film-serie-acteur-actrice-realisateur/$word.html"
+		return "http://www.cinemotions.com/recherche/$word.html"
     }
     
     sub getItemUrl
