@@ -3,6 +3,7 @@ package GCPlugins::GCfilms::GCFilmAffinityEN;
 ###################################################
 #
 #  Copyright 2005-2007 Tian
+#  Edited 2009 by FiXx
 #
 #  This file is part of GCstar.
 #
@@ -42,8 +43,8 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         {
             if ($self->{parsingEnded})
             {
-                if (($tagname eq 'img') && 
-                   ($attr->{src} =~ m{filmaffinity\.com/imgs/movies/full/[0-9]+/([0-9]*)}))
+                if (($tagname eq 'a') && 
+                   ($attr->{href} =~ /\/en\/.*\.php\?movie_id=([0-9]*)/))
                 {
                     $self->{hasUrl} = 'film'.$1.'.html';
                 }
@@ -79,11 +80,19 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             {
                 if ($attr->{src} =~ /^\/imgs\/countries/)
                 {
-                    $self->{curInfo}->{country} = $attr->{title};
+                    $self->{curInfo}->{country} = $attr->{alt};
                 }
-                elsif ($attr->{src} =~ /filmaffinity\.com\/imgs\/movies\/full/)
+                elsif ($attr->{src} =~ /pics\.filmaffinity\.com\/.*-full\.jpg/)
                 {
-                    $self->{curInfo}->{image} = $attr->{src};
+                    $self->{curInfo}->{image} = $attr->{src}
+                        if not exists $self->{curInfo}->{image};
+                }
+            }
+            elsif ($tagname eq 'a')
+            {
+                if ($attr->{href} =~ /pics\.filmaffinity\.com\/.*-large\.jpg/)
+                {
+                    $self->{curInfo}->{image} = $attr->{href};
                 }
             }
         }
@@ -176,6 +185,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             {
                 if ($self->{inside}->{a} && $origtext)
                 {
+                    $origtext =~ s/\n//g;
                     $self->{curInfo}->{actors} .= $origtext.', ';
                 }
             }
@@ -193,36 +203,36 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             
             if ($self->{inside}->{b})
             {
-                if ($origtext eq 'ORIGINAL TITLE:')
+                if ($origtext eq 'ORIGINAL TITLE')
                 {
                     $self->{isOrig} = 1;
                 }
-                elsif ($origtext eq 'YEAR:')
+                elsif ($origtext eq 'YEAR')
                 {
                     $self->{isDate} = 1;
                 }
-                elsif ($origtext eq 'RUNNING TIME:')
+                elsif ($origtext eq 'RUNNING TIME')
                 {
                     $self->{isTime} = 1;
                 }
-                elsif ($origtext eq 'DIRECTOR:')
+                elsif ($origtext eq 'DIRECTOR')
                 {
                     $self->{isDirector} = 1;
                 }
-                elsif ($origtext eq 'CAST:')
+                elsif ($origtext eq 'CAST')
                 {
                     $self->{isActors} = 1;
                 }
-                elsif ($origtext eq 'STUDIO/PRODUCER:')
+                elsif ($origtext eq 'STUDIO/PRODUCER')
                 {
                     $self->{curInfo}->{actors} =~ s/, $//;
                     $self->{isActors} = 0;
                 }
-                elsif ($origtext eq 'GENRE:')
+                elsif ($origtext eq 'GENRE')
                 {
                     $self->{isGenre} = 1;
                 }
-                elsif ($origtext eq 'SYNOPSIS:')
+                elsif ($origtext eq 'SYNOPSIS/PLOT')
                 {
                     $self->{isSynopsis} = 1;
                 }                
@@ -297,7 +307,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
 
     sub getAuthor
     {
-        return 'Tian & PIN';
+        return 'Tian & PIN edited by FiXx';
     }
     
     sub getLang
