@@ -2,7 +2,7 @@ package GCPlugins::GCfilms::GCFilmAffinityES;
 
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -81,7 +81,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                 {
                     $self->{curInfo}->{country} = $attr->{title};
                 }
-                elsif ($attr->{src} =~ /filmaffinity\.com\/imgs\/movies\/full/)
+                elsif ($attr->{src} =~ /pics\.filmaffinity\.com/)
                 {
                     $self->{curInfo}->{image} = $attr->{src};
                 }
