@@ -2,7 +2,7 @@ package GCPlugins::GCfilms::GCImdb;
 
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -34,7 +34,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     sub start
     {
         my ($self, $tagname, $attr, $attrseq, $origtext) = @_;
-	
+
         $self->{inside}->{$tagname}++;
 
         if ($self->{parsingEnded})
@@ -57,7 +57,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             {
                 my $url = $attr->{href};
                 if (($url =~ /^\/title\//)
-                 && (!$attr->{onclick})
+                 #&& (!$attr->{onclick})
                  && (!$self->{alreadyListed}->{$url}))
                 {
                     $self->{isMovie} = 1;
@@ -88,7 +88,12 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                       )
                    ))
                 {
-                    $self->{curInfo}->{image} = $attr->{src} if ! $self->{curInfo}->{image};
+                    if (! $self->{curInfo}->{image})
+                    {
+                        $self->{curInfo}->{image} = $attr->{src};
+                        $self->{curInfo}->{image} =~ s/SX[0-9]*_SY[0-9]*/SX1000_SY1000/
+                            if ($self->{bigPics});
+                    }
                 }
             }
             elsif ($tagname eq "a")
@@ -136,7 +141,19 @@ use GCPlugins::GCfilms::GCfilmsCommon;
 		my ($self, $tagname) = @_;
 		
 		$self->{inside}->{$tagname}--;
-
+        if ($self->{parsingList})
+        {
+            if ($self->{isMovie} && ($tagname eq 'a'))
+            {
+                $self->{isMovie} = 0;
+                my $url = $self->{itemsList}[$self->{itemIdx}]->{url};
+                if (!$self->{itemsList}[$self->{itemIdx}]->{title})
+                {
+                    $self->{alreadyListed}->{$url} = 0;
+                    $self->{itemIdx}--;
+                }
+            }
+        }
     }
 
     sub text
@@ -179,6 +196,11 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             $self->{insideOtherTitles} = 0 if $origtext =~ m/Runtime:|MPAA:/;
             $self->{insideSynopsis} = 0 if $origtext =~ m/(User Comments:)|(User Rating:)|(Plot Keywords:)/;
 
+            if ($self->{inside}->{rating})
+            {
+                $self->{ curInfo }->{rating} = int( $origtext + 0.5 );
+            }
+
             if ($self->{insideGenre})
             {
                 $origtext =~ s/\s*$//;
@@ -188,8 +210,12 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             }
             elsif ($self->{insideDirector})
             {
-                $self->{curInfo}->{director} = $origtext;
-                $self->{insideDirector} = 0;
+                if ($origtext)
+                {
+                    $origtext =~ s/^\s*//;
+                    $self->{curInfo}->{director} = $origtext;
+                    $self->{insideDirector} = 0;
+                }
             }
             elsif ($self->{insideSynopsis})
             {
@@ -254,7 +280,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             }
             elsif ($self->{inside}->{h5})
             {
-                $self->{insideDirector} = 1 if $origtext =~ m/(Directed by|Director)/;
+                $self->{insideDirector} = 1 if ($origtext =~ m/(Directed by|Director)/) && ! $self->{curInfo}->{director};
                 $self->{insideSynopsis} = 1 if ($origtext =~ m/Synopsis:|Plot Summary:|Plot Outline:|Plot:/);
                 $self->{insideOtherTitles} = 1 if ($origtext =~ m/Also Known As:/);
                 $self->{insideTime} = 1 if $origtext =~ m/Runtime:/;
@@ -288,12 +314,13 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     sub preProcess
     {
         my ($self, $html) = @_;
-        
+
         $self->{parsingEnded} = 0;
         
         $html =~ s/"&#34;/'"/g;
         $html =~ s/&#34;"/"'/g;
         $html =~ s|</a></b><br>|</a><br>|;
+        $html =~ s{<b>([.0-9]+)/10</b>}{<rating>$1</rating>}gi;
         $html =~ s{</?(?:b|small)>}{}gi;
         
         if ($self->{parsingList})
@@ -303,10 +330,12 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         else
         {
             $html =~ s|<a href="synopsis">[^<]*</a>||gi;
-            $html =~ s|<a href="/name/.*?">([^<]*)</a>|$1|gi;
+            $html =~ s|<a href="/name/.*?"[^>]*>([^<]*)</a>|$1|gi;
             $html =~ s|<a href="/character/ch[0-9]*/">([^<]*)</a>|$1|gi;
             #$html =~ s|<a href="/Sections/.*?">([^<]*)</a>|$1|gi;
-            $self->{curInfo}->{actors} = [];
+
+            # Commented out this line, causes bug #14420 when importing from named lists
+            #$self->{curInfo}->{actors} = [];
         }
         
         
