@@ -2,7 +2,7 @@ package GCPlugins::GCfilms::GCOFDb;
 
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -85,9 +85,7 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             {
                 if ($attr->{href} =~ m/view\.php\?page=blaettern&Kat=Land&Text=(.*)/)
                 {
-                    my $country = GCUtils::urlDecode($1);
-                    $self->{curInfo}->{country} .= ', ' if $self->{curInfo}->{country};
-                    $self->{curInfo}->{country} .= $country; 
+                    $self->{insideCountry} = 1;
                 }
                 $self->{curInfo}->{date} = $1
                     if ($attr->{href} =~ m/view\.php\?page=blaettern&Kat=Jahr&Text=([0-9]{4})/);
@@ -150,6 +148,12 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                 $self->{insideGenre} = 1 if $origtext =~ m/Genre\(s\):/;
                 $self->{insideInfosNames} = 0;
             }
+            elsif ($self->{insideCountry})
+            {
+                $self->{curInfo}->{country} .= ', ' if $self->{curInfo}->{country};
+                $self->{curInfo}->{country} .= $origtext; 
+                $self->{insideCountry} = 0;
+            }
             elsif ($self->{insideInfos} && $self->{inside}->{font})
             {
                 if ($self->{insideOrig})
@@ -158,35 +162,28 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                     $self->{insideOrig} = 0;
                     $self->{insideInfos} = 0;
                 }
-                elsif ($self->{insideNat})
-                {
-                    $self->{curInfo}->{country} = $origtext;
-                    $self->{insideNat} = 0;
-                    $self->{insideInfos} = 0;
-                }
                 elsif ($self->{insideDirector})
                 {
                     $self->{curInfo}->{director} .= $self->{curInfo}->{director} ? ', ' . $origtext : $origtext;
                 }
                 elsif ($self->{insideActors})
                 {
-                    $self->{curInfo}->{actors} .= $self->{curInfo}->{actors} ? ', ' . $origtext : $origtext
+                    push @{$self->{curInfo}->{actors}}, [$origtext]
                         if $self->{actorsCounter} < $GCPlugins::GCfilms::GCfilmsCommon::MAX_ACTORS;
                     $self->{actorsCounter}++;
                 }
                 elsif ($self->{insideGenre})
                 {
-                    $self->{curInfo}->{genre} .= $self->{curInfo}->{genre} ? ',' . $origtext : $origtext;
+                    push @{$self->{curInfo}->{genre}}, [$origtext];
                 }
             }
             elsif ($self->{insideSynopsis})
             {
                 $origtext =~ m/(http.*?)(\s|$)/;
-                my $page = $self->loadPage($1);
+                my $page = $self->loadPage($1, 0, 1);
                 $page =~ m|<font face="Arial,Helvetica,sans-serif" size="2" class="Blocksatz">.*?</a><br>[^<]*</b>(?:</b>)?<br><br>(.*?)</font>|ms;
                 $self->{curInfo}->{synopsis} = $1;
-                $self->{curInfo}->{synopsis} =~ s/<br \/>/<br>/gi;
-                $self->{curInfo}->{synopsis} =~ s/\n//gm;
+                $self->{curInfo}->{synopsis} =~ s/<br \/>/\n/gi;
                 $self->{insideSynopsis} = 0;
             }
         }
@@ -239,16 +236,30 @@ use GCPlugins::GCfilms::GCfilmsCommon;
     {
         my ($self, $word) = @_;
 	
-        return "http://www.ofdb.de/view.php?page=suchergebnis&Kat=DTitel&SText=$word";
+        return "http://www.ofdb.de/view.php?page=suchergebnis&Kat=Titel&SText=$word";
     }
     
     sub getItemUrl
     {
         my ($self, $url) = @_;
-		
+		utf8::decode ($url);
         return 'http://www.ofdb.de/' . $url;
     }
 
+    sub getCharset
+    {
+        my $self = shift;
+    
+        return "ISO-8859-1";
+    }
+    
+    sub getSearchCharset
+    {
+        my $self = shift;
+    
+        return "UTF-8";
+    }
+
     sub getName
     {
         return "OFDb.de";
