@@ -2,7 +2,7 @@
 
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -172,13 +172,13 @@ use GCPlugins::GCgames::GCgamesCommon;
                         $self->{NbrImage} = 0;
                     }
                 }
-                elsif (($attr->{href} =~ m|/etajvhtm/|) && ! ($self->{urlTips}))
+                elsif (($attr->{href} =~ m^/(etajvhtm|cheats)/^) && ! ($self->{urlTips}))
                 {
                     $self->{urlTips} = $attr->{href};
                 }
                 elsif (!$self->{curInfo}->{description} && ($attr->{href} =~ /[-_]test\.htm$/) && (!$self->{testLoaded}))
                 {
-                    my $html = $self->loadPage($attr->{href});
+                    my $html = $self->loadPage($attr->{href}, 0, 1);
                     my $found = index($html,"<p id=\"chapo\">");
                     if ( $found >= 0 )
                     {
@@ -287,8 +287,9 @@ use GCPlugins::GCgames::GCgamesCommon;
     sub getTipsUrl
     {
         my $self = shift;
+        print "RETURNING ",$self->{urlTips},"\n";
         return $self->{urlTips};
-        #my $html = $self->loadPage($self->{urlTips});
+        #my $html = $self->loadPage($self->{urlTips}, 0, 1);
         #$html =~ m|<div id="col1">(.*?)<div id="barre_outils">|ms;
         #$self->{curInfo}->{secrets} = $1;
         #return '';
