@@ -2,7 +2,7 @@ package GCPlugins::GCgames::GCMobyGames;
 
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -38,7 +38,7 @@ use GCPlugins::GCgames::GCgamesCommon;
         my ($self, $html_ini) = @_;
         my $answer = "";
         my @tmpAnswer = ();
-        my $html = $self->loadPage($html_ini);
+        my $html = $self->loadPage($html_ini, 0, 1);
         $html =~ s|<pre>||gi;
         $html =~ s|</pre>||gi;
         $html =~ s|<b>||gi;
@@ -247,7 +247,7 @@ use GCPlugins::GCgames::GCgamesCommon;
                         if $self->{bigPics};
                     $self->{curInfo}->{boxpic} = $attr->{src};
                     # From here we try to get back cover
-                    my $covers = $self->loadPage($self->{rootUrl}.'/cover-art');
+                    my $covers = $self->loadPage($self->{rootUrl}.'/cover-art', 0, 1);
                     $covers =~ m|<img alt=".*?Back Cover".*?src="([^"]*)"|;
                     $self->{curInfo}->{backpic} = $1;
                     $self->{curInfo}->{backpic} =~ s|/small/|/large/|
@@ -256,7 +256,7 @@ use GCPlugins::GCgames::GCgamesCommon;
             }
             elsif ($tagname eq 'html')
             {
-                my $html = $self->loadPage($self->{curInfo}->{$self->{urlField}}.'/techinfo');
+                my $html = $self->loadPage($self->{curInfo}->{$self->{urlField}}.'/techinfo', 0, 1);
                 my $player_offline = $self->extractPlayer($html, "Number&nbsp;of Players: Offline" );
                 my $player_online = $self->extractPlayer($html, "Number&nbsp;of Players: Online" );
                 my $player_total = $self->extractPlayer($html, "Number&nbsp;of Players Supported" );
@@ -284,7 +284,7 @@ use GCPlugins::GCgames::GCgamesCommon;
                     }
                 }
 
-                $html = $self->loadPage($self->{curInfo}->{$self->{urlField}}.'/screenshots');
+                $html = $self->loadPage($self->{curInfo}->{$self->{urlField}}.'/screenshots', 0, 1);
                 my $screen = 1;
                 while ($html =~ m|src="(http://www.mobygames.com/images/shots/thumbnail[^"]*?)"|g)
                 {
