@@ -2,7 +2,7 @@ package GCPlugins::GCmusics::GCDiscogs;
 
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -91,7 +91,9 @@ use GCPlugins::GCmusics::GCmusicsCommon;
                     if ($release->{type} eq 'release')
                     {
                        $self->{itemIdx}++;
-                       $self->{itemsList}[$self->{itemIdx}]->{url} = $release->{uri};
+                       $self->{itemsList}[$self->{itemIdx}]->{url} = $release->{uri};                    
+                       $self->{itemsList}[$self->{itemIdx}]->{release} = $release->{summary};
+                      
                        my $found = index($release->{title},"-");
                        if ( $found >= 0 )
                        {
@@ -102,6 +104,11 @@ use GCPlugins::GCmusics::GCmusicsCommon;
                           $self->{itemsList}[$self->{itemIdx}]->{artist} = substr($release->{title}, 0, $found);
                           # Enleve les blancs en fin de chaine
                           $self->{itemsList}[$self->{itemIdx}]->{artist} =~ s/\s+$//;
+                          
+                          # Clean up release summary
+                          my $tmpTitle = $release->{title};
+                          $tmpTitle =~ s/\- //;
+                          $self->{itemsList}[$self->{itemIdx}]->{release} =~ s/^$tmpTitle //;
                        }
                        else
                        {
@@ -114,14 +121,14 @@ use GCPlugins::GCmusics::GCmusicsCommon;
         else
         {
             $xml = $xs->XMLin($page,
-                              ForceArray => ['track', 'artist', 'image', 'label', 'genre'],
+                              ForceArray => ['track', 'artist', 'image', 'label', 'genre', 'format'],
                               KeyAttr => {'track' => ''});
             $self->{curInfo}->{title} = $xml->{release}->{title};
             $self->{curInfo}->{artist} = '';
             for my $art (@{$xml->{release}->{artists}->{artist}})
             {
                 $self->{curInfo}->{artist} .= $art->{name}.', ';
-            }
+            }     
             $self->{curInfo}->{artist} =~ s/, $//;
             $self->{curInfo}->{producer} = '';
             $self->{curInfo}->{composer} = '';
@@ -139,8 +146,14 @@ use GCPlugins::GCmusics::GCmusicsCommon;
             {
                 my $duree = $track->{duration};
                 $duree =~ /([0-9]+):([0-9]+)/;
-                my $duree2 = int($1*60 + $2) ;
-                $self->addTrack($track->{title}, $duree2, $track->{position});
+                my $duree2 = int($1*60 + $2);
+                my $position = "";
+                # Sometimes the position is missing, which causes it to be an array
+                if (!ref($track->{position}))
+                {
+                    $position = $track->{position};
+                }
+                $self->addTrack($track->{title}, $duree2, $position);
             }
             $self->{curInfo}->{tracks} = $self->getTracks;
             $self->{curInfo}->{running} = $self->getTotalTime;
@@ -160,11 +173,17 @@ use GCPlugins::GCmusics::GCmusicsCommon;
                 $self->{curInfo}->{genre} .= $genre.',';
             }
             $self->{curInfo}->{genre} =~ s/,$//;
-
             $self->{curInfo}->{origin} = $xml->{release}->{country}; 
             $self->{curInfo}->{origin} =~ s/,$//;
-            $self->{curInfo}->{format} = $xml->{release}->{formats}->{format}->{name};
-            $self->{curInfo}->{format} =~ s/,$//;
+            for my $format(@{$xml->{release}->{formats}->{format}})
+            {
+                if (  $self->{curInfo}->{format} eq '')
+                {
+                    $self->{curInfo}->{format} = $format->{name};
+                    $self->{curInfo}->{format} =~ s/,$//; 
+                }
+            }
+            $self->{curInfo}->{web} = 'http://www.discogs.com/release/' . $xml->{release}->{id};            
         }
     }
 
@@ -178,7 +197,7 @@ use GCPlugins::GCmusics::GCmusicsCommon;
         $self->{hasField} = {
             title => 1,
             artist => 1,
-            release => 0
+            release => 1
         };
 
         return $self;
@@ -188,7 +207,7 @@ use GCPlugins::GCmusics::GCmusicsCommon;
     {
         my ($self, $html) = @_;
 
-     return $html;
+        return $html;
     }
     
     sub decodeEntitiesWanted
@@ -198,7 +217,7 @@ use GCPlugins::GCmusics::GCmusicsCommon;
 
     sub getSearchUrl
     {
-		my ($self, $word) = @_;
+        my ($self, $word) = @_;
 	
         my $key = $self->{searchField};
         my $url;
@@ -214,13 +233,14 @@ use GCPlugins::GCmusics::GCmusicsCommon;
         {
             $url = "http://www.discogs.com/". $key ."/". $word ."?f=xml&api_key=e8f5ae8ba2"; 
         }
+        
         return $url;
 #        return "http://www.discogs.com/search?type=all&q=". $word ."&f=xml&api_key=e8f5ae8ba2";
     }
     
     sub getItemUrl
     {
-		my ($self, $url) = @_;
+        my ($self, $url) = @_;
 
         my $found = index(reverse($url),"/");
         if ( $found >= 0 )
