@@ -2,7 +2,7 @@ package GCPlugins::GCstar::GCAmazonCommon;
 
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -29,6 +29,33 @@ use GCPlugins::GCPluginsBase;
 {
     package GCPlugins::GCstar::GCPluginAmazonCommon;
 
+    sub text
+    {
+        my ($self, $origtext) = @_;
+        return 0 if ($self->{parsingEnded});
+
+        if ($self->{parsingList})
+        {
+            if (
+                (($self->{inside}->{b})
+                || ($self->{inside}->{span})
+                || ($self->{inside}->{label}))
+               )
+            {
+                my $suffix = $self->{suffix};
+                if ((($suffix =~ /^co/) && ($origtext =~ /Sort by/))
+                 || (($suffix eq 'fr' ) && ($origtext =~ /Trier par/))
+                 || (($suffix eq 'de' ) && ($origtext =~ /Sortieren nach/)))
+                {
+                    $self->{beginParsing} = 1;
+                    return 1;
+                }
+            }
+        }
+        
+        return 0;
+    }
+
     sub extractImage
     {
         my ($self, $attr) = @_;
@@ -63,6 +90,7 @@ use GCPlugins::GCPluginsBase;
         my ($self, $url) = @_;
         return $1
             if (($url =~ m|/dp/[A-Z0-9]*/sr=([0-3]-[0-9]*)/qid=[0-9]*|)
+             || ($url =~ m|/dp/[A-Z0-9]*/ref=(?:sr\|pd)_([a-z0-9_]*)/[0-9]*|)
              || ($url =~ m|/dp/[A-Z0-9]*/ref=(?:sr\|pd)_([a-z0-9_]*)/[0-9]*|));
         return undef;
     }
@@ -70,13 +98,7 @@ use GCPlugins::GCPluginsBase;
     sub getSearchUrl
     {
         my ($self, $word) = @_;
-        if ($self->{searchField} eq $self->{codeField})
-        {
-            (my $code = $word) =~ s/\D//g;
-            return ('http://s1.amazon.'.$self->{suffix}.'/exec/varzea/sdp/sai-condition/', ['sdp-sai-asin' => $code])
-                if $self->isEAN($code);
-                # =~ /^978/;
-        }
+        #return 'file:///home/tian/Developpement/GCstar/gcstar/bin/tmp.movies.us.html';
         return "http://www.amazon.".$self->{suffix}."/gp/search/?redirect=true&search-alias=".$self->{searchType}."&keywords=$word";
     }
     
