@@ -2,7 +2,7 @@ package GCUtils;
 
 ###################################################
 #
-#  Copyright 2005-2007 Tian
+#  Copyright 2005-2009 Tian
 #
 #  This file is part of GCstar.
 #
@@ -149,6 +149,33 @@ sub compactHistories
     }
 }
 
+use HTML::Entities; 
+# Strips readable text from RTF formatted strings
+sub RtfToString
+{
+    my ($rtfString) = @_;
+    
+    my $str = $rtfString;
+    
+    # First, decode any symbols present
+    $str = decode_entities($str);
+    # Strip leading {
+    $str =~ s/^\{//;
+    # Strip out all the formatting within {}'s
+    $str =~ s/\{(.)*;\}//gs;
+    # Strip trailing }
+    $str =~ s/\}$//;
+    # Get the text from "\'d5" type tags
+    $str =~ s/\\(.)d\d/$1/g;
+    # Strip out all the remaining formatting
+    $str =~ s/\\(\H)*[\s]//g;
+    # And any newlines, since they'll be randomly placed now
+    $str =~ s/\n//g;    
+                
+    return $str;
+}
+
+
 {
     package GCPreProcess;
 
@@ -251,7 +278,7 @@ sub compactHistories
         }
         else
         {
-            @result = split /,/, $value;
+            @result = split /,\s*/, $value;
         }
         return \@result;
     }
@@ -522,5 +549,4 @@ BEGIN {
 }
 
 
-
 1;
